package com.jiankangyouyi.cloud.assessment.enums;

import lombok.AllArgsConstructor;
import lombok.Getter;

import java.util.ArrayList;
import java.util.List;

/**
 * 活动强度Enum
 * <p>
 * 活动强度 0 未知 1 极轻 2 轻度 3 中度 4 重度
 *
 * @author yangsongbo
 */
@AllArgsConstructor
@Getter
public enum ActivityLevelEnum {

    /**
     * 未知
     */
    UNKNOWN("0", "未知",0,null),

    /**
     * 极轻
     */
    LEVEL_1("1", "极轻",1.2,"0"),

    /**
     * 轻度
     */
    LEVEL_2("2", "轻度",1.375,"1"),

    /**
     * 中度
     */
    LEVEL_3("3", "中度",1.55,"2"),

    /**
     * 重度
     */
    LEVEL_4("4", "重度",1.725,"3"),

    ;
    private String activityLevel;

    private String describe;

    /**
     * 体力活动系数
     */
    private double rate;

    /**
     * 关联到饮食推荐服务的疾病名称代码
     */
    private String externalCode;


    public static ActivityLevelEnum getEnum(String activityLevel) {
        ActivityLevelEnum[] values = values();
        if (activityLevel == null) {
            return null;
        }
        for (ActivityLevelEnum value : values) {
            if (activityLevel.equals(value.activityLevel)) {
                return value;
            }
        }
        return null;
    }

    public static List<String> getActivityLevels() {
        ActivityLevelEnum[] values = values();

        List<String> result = new ArrayList<>();

        for (ActivityLevelEnum value : values) {
            result.add(value.getActivityLevel());
        }

        return result;
    }
}
