package com.jiankangyouyi.cloud.assessment.enums;

import com.jiankangyouyi.cloud.assessment.model.entity.mongo.AssessmentCallbackConfigDO;
import lombok.AllArgsConstructor;
import org.apache.commons.lang3.ArrayUtils;
import org.apache.commons.lang3.StringUtils;


/**
 * Redis Key Enum
 *
 * @author yangsongbo
 */
@AllArgsConstructor
public enum RedisKeyEnum {

    /**
     * <p>测评基本信息</p>
     * {@link com.jiankangyouyi.cloud.assessment.model.entity.mongo.AssessmentInfoDO}
     */
    STRING_ASSESSMENT_INFO("string_assessment_info", "测评基本信息,后缀为bizType"),

    /**
     * <p>测评报告数量</p>
     * {@link com.jiankangyouyi.cloud.assessment.model.entity.mongo.AssessmentReportDO}
     */
    STRING_ASSESSMENT_REPORT_COUNT("string_assessment_report_count", "测评报告数量,后缀为appId+userId+bizType"),

    /**
     * <p>测评报告信息</p>
     * {@link com.jiankangyouyi.cloud.assessment.model.entity.mongo.AssessmentReportDO}
     */
    STRING_ASSESSMENT_REPORT("string_assessment_report", "测评报告信息,后缀为reportId"),

    /**
     * <p>测评回调地址配置信息</p>
     * {@link AssessmentCallbackConfigDO}
     */
    STRING_ASSESSMENT_CALLBACK_CONFIG("string_assessment_callback_config", "测评访问权限信息，后缀为appId + bizType + callbackType"),

    /**
     * <p>测评访问令牌</p>
     * {@link com.jiankangyouyi.cloud.assessment.model.entity.mongo.AssessmentAccessTokenDO}
     */
    STRING_ASSESSMENT_ACCESS_TOKEN("string_assessment_access_token", "测评访问令牌，后缀为tokenId"),


    /**
     * 测评访问令牌锁,后缀为tokenId
     */
    STRING_ASSESSMENT_ACCESS_TOKEN_LOCK("string_assessment_access_token_lock", "测评访问令牌锁，后缀为tokenId"),

    /**
     * <p>测评报告信息</p>
     * {@link com.jiankangyouyi.cloud.assessment.model.entity.mongo.AssessmentReportDO}
     */
    STRING_ASSESSMENT_REPORT_TOKENID("string_assessment_report_token_id", "测评报告信息,后缀为tokenId"),
    /**
     * <p>效果评估报告信息</p>
     * {@link com.jiankangyouyi.cloud.assessment.model.entity.mongo.effect.EffectReportDO}
     */
    STRING_EFFECT_REPORT("string_effect_report", "效果评估报告信息,后缀为reportId"),

    /**
     * 测评访问令牌锁,后缀为tokenId
     */
    STRING_EFFECT_ASSESSMENT_ACCESS_TOKEN_LOCK("string_effect_assessment_access_token_lock", "效果测评访问令牌锁，后缀为tokenId"),

    /**
     * 生活方式中心生成报告锁，appId_userId
     */
    STRING_LIFE_STYLE_REPROT_CREATE_LOCK("string_life_style_report_create_lock", "生活方式中心生成报告锁，后缀为appId_userId"),
    /**
     * 生活方式中心查看报告锁，appId_userId_日期
     */
    STRING_LIFE_STYLE_REPROT_LOCK("string_life_style_report_lock", "生活方式中心生成报告锁，后缀为appId_userId_日期"),
    /**
     * 生活方式中心生成/调整方案锁，appId_userId_reportId_日期
     */
    STRING_LIFE_STYLE_SCHEME_ADJUST_LOCK("string_life_style_scheme_adjust_lock", "生活方式中心生成/调整方案锁，后缀为appId_userId_reportId_日期"),
    /**
     * 生活方式中心查看方案详情锁，appId_userId_reportId
     */
    STRING_LIFE_STYLE_SCHEME_DETAIL_LOCK("string_life_style_scheme_detail_lock", "生活方式中心查看方案详情（实时生成）锁，后缀为appId_userId_reportId"),
    /**
     * 生活方式中心方案打卡锁，appId_userId_reportId
     */
    STRING_LIFE_STYLE_SCHEME_PUNCH_CARD_LOCK("string_life_style_scheme_punch_card_lock", "生活方式中心方案打卡锁，appId_userId_reportId"),



    ;


    /**
     * redis key
     */
    private String key;

    /**
     * 描述
     */
    private String describe;


    public String getDescribe() {
        return this.describe;
    }

    /**
     * 获取key
     *
     * @param keySuffixes key后缀
     * @return redis key
     */
    public String getKey(String... keySuffixes) {
        StringBuilder builder = new StringBuilder(this.key);

        if (ArrayUtils.isNotEmpty(keySuffixes)) {
            for (String keySuffix : keySuffixes) {
                if (StringUtils.isNotBlank(keySuffix)) {
                    builder.append("_").append(keySuffix);
                }
            }
        }
        return builder.toString();
    }


}



