package com.jiankangyouyi.cloud.assessment.enums.assessment190101;

import com.jiankangyouyi.cloud.assessment.enums.assessmentCentre.RiskLevelEnum;
import com.jiankangyouyi.cloud.core.constant.BaseEnum;
import com.jiankangyouyi.cloud.data.center.api.enums.HealthProblemEnum;
import lombok.AllArgsConstructor;
import lombok.Getter;

import java.util.Arrays;
import java.util.List;

/**
 * 生活方式 测评项目enum
 *
 * @author fengxuanjun
 */
@AllArgsConstructor
@Getter
public enum LifeStyleRightItemEnum implements BaseEnum {

    /**
     * 健康人群
     * 已病、高风险、低风险
     */
    HEALTHY_PERSON(HealthProblemEnum.HEALTHY_PERSON.getCode(), HealthProblemEnum.HEALTHY_PERSON.getName(), null, 1),

    /**
     * 肥胖
     * 已病、高风险、低风险
     */
    OBESITY(HealthProblemEnum.OBESITY.getCode(), HealthProblemEnum.OBESITY.getName(), Arrays.asList(RiskLevelEnum.CONFIRMED.getLevel(), RiskLevelEnum.HIGH.getLevel(), RiskLevelEnum.LOW.getLevel()), 2),
    /**
     * 2型糖尿病
     * 已病、高风险、低风险
     */
    DIABETES_TYPE_2(HealthProblemEnum.TYPE_2_DIABETES.getCode(), HealthProblemEnum.TYPE_2_DIABETES.getName(), Arrays.asList(RiskLevelEnum.CONFIRMED.getLevel(), RiskLevelEnum.HIGH.getLevel(), RiskLevelEnum.LOW.getLevel()), 3),
    /**
     * 高血压
     * 已病、高风险、中风险、低风险
     */
    HYPERTENSION(HealthProblemEnum.HYPERTENSION.getCode(), HealthProblemEnum.HYPERTENSION.getName(), Arrays.asList(RiskLevelEnum.CONFIRMED.getLevel(), RiskLevelEnum.HIGH.getLevel(), RiskLevelEnum.MIDDLE.getLevel(), RiskLevelEnum.LOW.getLevel()), 4),
    /**
     * 高血脂
     * 已病、高风险、中风险、低风险
     */
    HPYPERLIPIDEMIA(HealthProblemEnum.HPYPERLIPIDEMIA.getCode(), HealthProblemEnum.HPYPERLIPIDEMIA.getName(), Arrays.asList(RiskLevelEnum.CONFIRMED.getLevel(), RiskLevelEnum.HIGH.getLevel(), RiskLevelEnum.MIDDLE.getLevel(), RiskLevelEnum.LOW.getLevel()), 5),
    /**
     * 高尿酸血症
     * 已病、高风险、中风险、低风险
     */
    HYPERURICEMIA(HealthProblemEnum.HYPERURICEMIA.getCode(), HealthProblemEnum.HYPERURICEMIA.getName(), Arrays.asList(RiskLevelEnum.CONFIRMED.getLevel(), RiskLevelEnum.HIGH.getLevel(), RiskLevelEnum.MIDDLE.getLevel(), RiskLevelEnum.LOW.getLevel()), 6),
    /**
     * 痛风
     * 已病、高风险、中风险、低风险
     */
    GOUT(HealthProblemEnum.GOUT.getCode(), HealthProblemEnum.GOUT.getName(), Arrays.asList(RiskLevelEnum.CONFIRMED.getLevel(), RiskLevelEnum.HIGH.getLevel(), RiskLevelEnum.MIDDLE.getLevel(), RiskLevelEnum.LOW.getLevel()), 7),

    // 1.3新增 2022年10月31日
    /**
     * 脂肪肝
     * 已病、高风险、中风险、低风险
     */
    FATTY_LIVER(HealthProblemEnum.FATTY_LIVER.getCode(), HealthProblemEnum.FATTY_LIVER.getName(), Arrays.asList(RiskLevelEnum.CONFIRMED.getLevel(), RiskLevelEnum.HIGH.getLevel(), RiskLevelEnum.MIDDLE.getLevel(), RiskLevelEnum.LOW.getLevel()), 8),
    /**
     * 骨质疏松
     * 已病、高风险、低风险
     */
    OSTEOPOROSIS(HealthProblemEnum.OSTEOPOROSIS.getCode(), HealthProblemEnum.OSTEOPOROSIS.getName(), Arrays.asList(RiskLevelEnum.CONFIRMED.getLevel(), RiskLevelEnum.HIGH.getLevel(), RiskLevelEnum.LOW.getLevel()), 9),
    /**
     * 脑卒中
     * 已病、极高风险、高风险、中风险、低风险
     */
    STROKE(HealthProblemEnum.STROKE.getCode(), HealthProblemEnum.STROKE.getName(), Arrays.asList(RiskLevelEnum.CONFIRMED.getLevel(), RiskLevelEnum.POLAR.getLevel(), RiskLevelEnum.HIGH.getLevel(), RiskLevelEnum.MIDDLE.getLevel(), RiskLevelEnum.LOW.getLevel()), 10),
    /**
     * 心血管疾病
     * 已病、极高风险、高风险、中风险、低风险
     */
    CVD(HealthProblemEnum.CVD.getCode(), HealthProblemEnum.CVD.getName(), Arrays.asList(RiskLevelEnum.CONFIRMED.getLevel(), RiskLevelEnum.POLAR.getLevel(), RiskLevelEnum.HIGH.getLevel(), RiskLevelEnum.MIDDLE.getLevel(), RiskLevelEnum.LOW.getLevel()), 11),
    /**
     * 功能性胃肠病
     * 已病、高风险、中风险、低风险
     */
    FGID(HealthProblemEnum.FGID.getCode(), HealthProblemEnum.FGID.getName(), Arrays.asList(RiskLevelEnum.CONFIRMED.getLevel(), RiskLevelEnum.HIGH.getLevel(), RiskLevelEnum.MIDDLE.getLevel(), RiskLevelEnum.LOW.getLevel()), 12),
    /**
     * 免疫力
     * 较好、较差、差
     * 较好= 低风险       较差=中风险    差=高风险
     */
    IMMUNITY(HealthProblemEnum.IMMUNITY.getCode(), HealthProblemEnum.IMMUNITY.getName(), Arrays.asList(RiskLevelEnum.HIGH.getLevel(), RiskLevelEnum.MIDDLE.getLevel(), RiskLevelEnum.LOW.getLevel()), 13),
    /**
     * 营养不良
     * 高风险、中风险、低风险
     */
    NUTRIENT_DEFICIENCY(HealthProblemEnum.NUTRIENT_DEFICIENCY.getCode(), HealthProblemEnum.NUTRIENT_DEFICIENCY.getName(), Arrays.asList(RiskLevelEnum.HIGH.getLevel(), RiskLevelEnum.MIDDLE.getLevel(), RiskLevelEnum.LOW.getLevel()), 14),
    /**
     * 产后体重管理
     * 较好、较差、差
     * 差=高风险   较差=中风险   较好=低风险
     */
    POSTPARTUM_WEIGHT(HealthProblemEnum.POSTPARTUM_WEIGHT.getCode(), HealthProblemEnum.POSTPARTUM_WEIGHT.getName(), Arrays.asList(RiskLevelEnum.HIGH.getLevel(), RiskLevelEnum.MIDDLE.getLevel(), RiskLevelEnum.LOW.getLevel()), 15),

    /**
     * 甲减
     * 较好、较差、差
     * 差=高风险   较差=中风险   较好=低风险
     */
    TSH(HealthProblemEnum.TSH.getCode(), HealthProblemEnum.TSH.getName(), Arrays.asList(RiskLevelEnum.CONFIRMED.getLevel(), RiskLevelEnum.HIGH.getLevel(), RiskLevelEnum.MIDDLE.getLevel(), RiskLevelEnum.LOW.getLevel()), 16),

    /**
     * 甲亢
     * 较好、较差、差
     * 差=高风险   较差=中风险   较好=低风险
     */
    IIH(HealthProblemEnum.IIH.getCode(), HealthProblemEnum.IIH.getName(), Arrays.asList(RiskLevelEnum.CONFIRMED.getLevel(), RiskLevelEnum.HIGH.getLevel(), RiskLevelEnum.MIDDLE.getLevel(), RiskLevelEnum.LOW.getLevel()), 17),
    /**
     * 慢阻肺
     * 较好、较差、差
     * 差=高风险   较差=中风险   较好=低风险
     */
    COPD(HealthProblemEnum.COPD.getCode(), HealthProblemEnum.COPD.getName(), Arrays.asList(RiskLevelEnum.CONFIRMED.getLevel(), RiskLevelEnum.HIGH.getLevel(), RiskLevelEnum.LOW.getLevel()), 18),
    /**
     * 阿尔兹海默症
     * 较好、较差、差
     * 差=高风险   较差=中风险   较好=低风险
     */
    AD(HealthProblemEnum.AD.getCode(), HealthProblemEnum.AD.getName(), Arrays.asList(RiskLevelEnum.HIGH.getLevel(), RiskLevelEnum.MIDDLE.getLevel(), RiskLevelEnum.LOW.getLevel()), 19),
    /**
     * 慢性失眠症
     * 较好、较差、差
     * 差=高风险   较差=中风险   较好=低风险
     */
    INSOMNIA_CHRONIC_SYNDROME(HealthProblemEnum.INSOMNIA_CHRONIC_SYNDROME.getCode(), HealthProblemEnum.INSOMNIA_CHRONIC_SYNDROME.getName(), Arrays.asList(RiskLevelEnum.CONFIRMED.getLevel(), RiskLevelEnum.HIGH.getLevel(), RiskLevelEnum.MIDDLE.getLevel(), RiskLevelEnum.LOW.getLevel()), 20),
    /**
     * 慢性疲劳综合症
     * 较好、较差、差
     * 差=高风险   较差=中风险   较好=低风险
     */
    CFS(HealthProblemEnum.CFS.getCode(), HealthProblemEnum.CFS.getName(), Arrays.asList(RiskLevelEnum.CONFIRMED.getLevel(), RiskLevelEnum.HIGH.getLevel(), RiskLevelEnum.MIDDLE.getLevel(), RiskLevelEnum.LOW.getLevel()), 21),

    ;


    private String code;

    private String name;

    private List<Integer> riskLevels;

    private Integer sort;

    public static LifeStyleRightItemEnum getEnum(String code) {
        LifeStyleRightItemEnum[] values = values();
        if (code == null) {
            return null;
        }
        for (LifeStyleRightItemEnum value : values) {
            if (code.equals(value.code)) {
                return value;
            }
        }
        return null;
    }


    @Override
    public String code() {
        return code;
    }

    @Override
    public String message() {
        return name;
    }
}
