package com.jiankangyouyi.cloud.assessment.enums.assessmentCentre;

import lombok.AllArgsConstructor;
import lombok.Getter;
import org.apache.commons.lang.StringUtils;

/**
 * 评估中心身体指标枚举
 * <p>
 * @author fengxuanjun
 */
@AllArgsConstructor
@Getter
public enum AssessmentIndicatorEnum {


    /**
     * BMI
     */
    BMI("d72cd09e-aa28-4456-b624-fb33a19c07c8","BMI", "身体质量指数","1"),
    /**
     * 腰围
     */
    WAISTLINE("9791402f-4aea-47a4-b0ba-0d7b2dac5ebf", "WAISTLINE","腰围","1"),
    /**
     * 体脂率
     */
    BFR("6dbffed8-6632-4ccc-8942-09e83e549944", "BFR","体脂率","1"),

    /**
     * 空腹血糖
     */
    FBG("b11affc8-952d-4c0a-b5a2-3d147031ae34","FBG", "空腹血糖","1"),

    /**
     * 餐后血糖（餐后2小时血糖）
     */
    PBG("c946f658-90ab-414e-8532-80a109922db2","PBG", "餐后血糖","1"),
    /**
     * 随机血檀
     */
    RBG("2598baa7-16be-4f91-8385-216db5b4de7e", "RBG","随机血糖","1"),

    /**
     * 糖化血红蛋白
     */
    GHB("7621fc55-f07b-4674-9927-87155e52b3d5", "GHB","糖化血红蛋白","1"),

    /**
     * 收缩压（高压）
     */
    SBP("b1f6366f-27d6-4999-b131-4ebb26fb2dc0", "SBP","收缩压","1"),

    /**
     * 舒张压（低压）
     */
    DBP("a5ebf849-ee54-442b-a5da-a5031f5bdbb5", "DBP","舒张压","1"),

    /**
     * 总胆固醇
     */
    TC("bbf35a37-c6f8-4b99-a18d-54b98b07fefb","TC", "总胆固醇","1"),

    /**
     * 甘油三酯
     */
    TG("0ad6bc19-1b83-4181-8c3d-742540b59d84", "TG","甘油三酯","1"),

    /**
     * 高密度脂蛋白胆固醇
     */
    HDL_C("3b0f4a2f-15a8-4d45-b9ba-7168fff222e8", "HDL_C","高密度脂蛋白胆固醇","1"),

    /**
     * 低密度脂蛋白胆固醇
     */
    LDL_C("355b1528-50fc-4efc-8319-a1ab221d5a2e", "LDL_C","低密度脂蛋白胆固醇","1"),
    /**
     * 非高密度脂蛋白胆固醇
     */
    MDL_C("2a03f32a-5b6d-4f4f-bb2c-3e81d965c12a", "MDL_C","非高密度脂蛋白胆固醇","1"),

    /**
     * 骨密度T值
     */
    BMD_T_SCORE("1c222785-1a21-4cd2-a78d-289cc67d9b05","BMDTs", "骨密度T值","1"),

    /**
     * 血尿酸
     */
    UA("35e823cd-9d4c-41a1-86a4-ab1b0489e0dd", "UA","血尿酸","1"),
    /**
     * 肝内脂肪含量
     */
    IHCL("a2094f25-fbac-4d4f-83de-becc25fc85fd", "IHCL","肝内脂肪含量","1"),

    /**
     * γ-谷氨酰转移酶
     */
    YGGT("504bc1aa-4730-4276-9f8f-3aab797eb210", "YGGT","γ-谷氨酰转移酶","1"),

    /**
     * 呼吸频率
     */
    RR("47174ab0-fcee-45ab-9769-41129b445275", "RR","呼吸频率","1"),

    /**
     * 心率
     */
    HR("a024708d-96ce-4900-892d-a66fecbc326e", "HR","心率","1"),

    /**
     * 血氧饱和度
     */
    SAO2("f52bdc55-ed29-47b2-ac26-e055a4f2d676", "SAO2","血氧饱和度","1"),

    // 体检报告新增
    /**
     * 体温
     */
    BODY_TEMPERATURE("f840365e-2f70-4215-9869-8937e205fff1", "BODY_TEMPERATURE","体温","1"),
    /**
     * 皮下脂肪
     */
    SUBCUTFAT("881ad68a-d1c9-4fbb-aa33-b9ef430585d1", "SUBCUTFAT","皮下脂肪","1"),
    /**
     * 脂肪量（动态指标）
     */
    FAT_WIGHT("b751e38c-c210-492f-aa36-ef32d6ee9590", "FAT_WIGHT","脂肪量","3"),
    /**
     * 去脂体重（动态指标）
     */
    LBW("0771a108-88b9-44bb-ab80-905dabdc6293", "LBW","去脂体重","3"),
    /**
     * 肌肉率
     */
    MUSCLE("acc15be4-94e6-4c3b-8417-fad62e46daff", "MUSCLE","肌肉率","1"),
    /**
     * 蛋白率
     */
    PR("5a79eac7-43b5-49d5-b580-820d606bdac4", "PR","蛋白率","1"),
    /**
     * 水分率
     */
    WATER("e8d6f74d-c565-4b71-96df-6300de5042c9", "WATER","水分率","1"),
    /**
     * 内脏脂肪指数
     */
    VFAL("c104d2fe-0f81-481a-be69-63d25b8a6304", "VFAL","内脏脂肪指数","1"),
    /**
     * 血细胞比容
     */
    HCT("2649fbb0-2e43-4c6e-8b16-91727d23b408", "HCT","血细胞比容","1"),
    /**
     * 血红蛋白
     */
    HB("24e3ce9f-6956-4dec-88bf-abf3ddd7da79", "HB","血红蛋白","1"),
    /**
     * 红细胞计数
     */
    RBC("0c2121ea-a9c2-49fa-a6bf-2bd286f70bde", "RBC","红细胞计数","1"),
    /**
     * 红细胞体积分布宽度
     */
    RDW_CV("671231ec-d3c4-46bf-906b-008f567e859b", "RDW_CV","红细胞体积分布宽度","1"),
    /**
     * 平均红细胞血红蛋白浓度
     */
    MCHC("7d60fd34-f098-4b75-abc4-10b95c75a231", "MCHC","平均红细胞血红蛋白浓度","1"),
    /**
     * 平均红细胞血红蛋白量
     */
    MCH("576ae3f2-b9da-466e-b3e7-3d726a1ffed8", "MCH","平均红细胞血红蛋白量","1"),
    /**
     * 平均红细胞容积
     */
    MCV("d6157215-874c-47bb-bcb9-19fa7dbff429", "MCV","平均红细胞容积","1"),
    /**
     * 白细胞计数
     */
    WBC("c7f8f273-69d5-4e2c-ad00-1843cf703268", "WBC","白细胞计数","1"),
    /**
     * 血小板计数
     */
    PC("0eb8da1e-c81e-4757-8d21-fc27f2499f91", "PC","血小板计数","1"),
    /**
     * 血小板分布宽度
     */
    PDW("ef0edb65-fca9-4e57-89e1-21bd5820e6e7", "PDW","血小板分布宽度","1"),
    /**
     * 淋巴细胞
     */
    LYM("dfa833f3-1077-4a29-a955-ce960125ffe4", "LYM","淋巴细胞","1"),
    /**
     * 淋巴细胞百分数
     */
    LY("3202aafb-3cb1-401a-a496-62e2070a5ca1", "LY","淋巴细胞百分数","1"),
    /**
     * 中性粒细胞
     */
    NEUT("c3541445-2986-4edb-b137-b83b3ae50945", "NEUT","中性粒细胞","1"),
    /**
     * 中性粒细胞百分数
     */
    NEUR("f52b1f57-57cf-46da-8a0c-a11098972097", "NEUR","中性粒细胞百分数","1"),
    /**
     * 尿红细胞
     */
    URINE_RBC("f3faf415-b060-40ae-ab6e-8e0e6147e88f", "URINE_RBC","尿红细胞","1"),
    /**
     * 尿维生素C含量
     */
    U_VC("5dc60237-c698-43d9-b780-09ba088923cb", "U_VC","尿维生素C含量","1"),
    /**
     * 尿蛋白肌酐比
     */
    PCR("8d6c50ea-4c72-4801-b7ac-0f060c053dd6", "PCR","尿蛋白肌酐比","1"),
    /**
     * 尿比重
     */
    SG("96651952-01fa-4d79-bb93-47e41a793f18", "SG","尿比重","1"),
    /**
     * 尿酸碱度  bf55e27f-2ae9-451f-9328-46ad6b688667 -> b69795ef-279b-49d4-a6cc-5119ab69bb7e data-center同步修改
     */
    U_PH("b69795ef-279b-49d4-a6cc-5119ab69bb7e", "U_PH","尿酸碱度","1"),
    /**
     * 尿颜色
     */
    COL("1451e93e-b288-4094-8b78-c93bc132971a", "COL","尿颜色","2"),
    /**
     * 尿葡萄糖
     */
    GLU("52ffbf86-2535-4b75-a7ba-8fbfdeab79bb", "GLU","尿葡萄糖","2"),
    /**
     * 尿蛋白质
     */
    PRO("4ab5f152-24d6-4bc9-a84c-3af2021c20ae", "PRO","尿蛋白质","2"),
    /**
     * 尿白细胞
     */
    LEU("1ee111cd-1a94-4287-ad42-1d04f0e1a90c", "LEU","尿白细胞","2"),
    /**
     * 尿亚硝酸盐
     */
    NIT("59dcfc2a-e683-450b-bf3c-8572e7c7c557", "NIT","尿亚硝酸盐","2"),
    /**
     * 尿潜血- b580331a-9059-4f6e-85f4-1cf838109171 ->  fee34b13-a6ff-46d0-b966-459efbe959f9  data-center同步修改
     */
    BLD("fee34b13-a6ff-46d0-b966-459efbe959f9", "BLD","尿潜血","2"),
    /**
     * 尿酮体
     */
    KET("522688af-0ff1-4bf8-a85e-c4c3e25a5b64", "KET","尿酮体","2"),
    /**
     * 尿胆红素
     */
    BIL("715ec5dd-433e-437c-931e-cbe50d4ff7cf", "BIL","尿胆红素","2"),
    /**
     * 尿胆原
     */
    URO("0d5bcb1f-ae09-4de5-b132-f4e46475f51a", "URO","尿胆原","2"),
    /**
     * 空腹血糖（方法：毛细血管全血）
     */
    FBG_CAPILLARY("27c35214-22c0-4e47-8d98-f726117aa551", "FBG_CAPILLARY","空腹血糖","1"),
    /**
     * 睡前血糖
     */
    BBG("f8223b48-0e06-44fc-84ac-0f0bc82186f0", "BBG","睡前血糖","1"),
    /**
     * 碱性磷酸酶
     */
    ALP("3f7a7e55-574f-4381-9f37-738873edb2ee", "ALP","碱性磷酸酶","1"),
    /**
     * 丙氨酸氨基转移酶
     */
    ALT("d6de3a9f-b32d-4ee9-b62a-c35f97eca772", "ALT","丙氨酸氨基转移酶","1"),
    /**
     * 天门冬氨酸氨基转移酶
     */
    AST("e5237355-1aeb-46ae-a8e4-7a21234263a8", "AST","天门冬氨酸氨基转移酶","1"),
    /**
     * 白蛋白
     */
    ALB("ed5f3407-d6bd-45bb-b667-8fd16e4ac114", "ALB","白蛋白","1"),
    /**
     * 球蛋白
     */
    GLB("64a06656-da36-4e29-ba40-ee1ef4f0106f", "GLB","球蛋白","1"),
    /**
     * 总蛋白
     */
    TP("80b9c1f1-6c01-43d6-b71b-9db69fc39ad9", "TP","总蛋白","1"),
    /**
     * 白蛋白/球蛋白
     */
    ALB_GLB_RATIO("d9f04b53-7d96-4185-b1c8-408c60802a53", "ALB_GLB_RATIO","白蛋白/球蛋白","1"),
    /**
     * 结合胆红素
     */
    CB("42dce654-e41b-4316-b115-49786cc96c5d", "CB","结合胆红素","1"),
    /**
     * 非结合胆红素
     */
    UCB("fed73bde-b3e6-47fa-b63e-7495c418c95f", "UCB","非结合胆红素","1"),
    /**
     * 总胆红素
     */
    STB("8c6befee-f31c-4d84-a50d-31b8ea66b846", "STB","总胆红素","1"),
    /**
     * 胃泌素-17
     */
    G17("11658392-22a9-4cb2-a26b-763a9314d88a", "G17","胃泌素-17","1"),
    /**
     * 胃蛋白酶原I
     */
    PG1("674ca11d-2b9b-46b1-9c3b-dd4f44f070e4", "PG1","胃蛋白酶原I","1"),
    /**
     * 胃蛋白酶原II
     */
    PG2("1e03afbc-9431-441e-bc99-d121247fb6d9", "PG2","胃蛋白酶原II","1"),
    /**
     * 胃蛋白酶原比值
     */
    PGR("63ea2c42-1535-4faf-9f75-a95f0e93ef0b", "PGR","胃蛋白酶原比值","1"),
    /**
     * 血清总钙
     */
    SERUM_CA("f2f8f477-de99-4659-9a1b-b62ab5f85381", "SERUM_CA","血清总钙","1"),
    /**
     * 血清铜
     */
    SERUM_CU("cd2648a6-4d74-4526-9abf-9e1084f0e94a", "SERUM_CU","血清铜","1"),
    /**
     * 血清铁
     */
    SERUM_FE("79b193b9-a67e-480a-997c-11bbaeee30ab", "SERUM_FE","血清铁","1"),
    /**
     * 血清锌
     */
    SERUM_ZN("a2bb2ed8-74a6-4d06-8f24-ebbfc92193b9", "SERUM_ZN","血清锌","1"),
    /**
     * 血清镁
     */
    SERUM_MG("56e86b01-3617-4693-aec4-58c81e538c67", "SERUM_MG","血清镁","1"),
    /**
     * 尿中尿酸
     */
    UUA("2ba4df98-9359-44cb-852c-3a18522967eb", "UUA","尿中尿酸","1"),



    ;


    /**
     * 指标ID
     */
    private String indicatorId;

    /**
     * 指标编码
     */
    private String indicator;

    /**
     * 指标名称
     */
    private String indicatorName;

    /**
     * 指标类型
     * 1：数值类型
     * 2：描述类型
     * 3：动态类型
     */
    private String indicatorType;


    public static AssessmentIndicatorEnum getEnum(String indicatorId) {
        AssessmentIndicatorEnum[] values = values();
        if (StringUtils.isBlank(indicatorId)) {
            return null;
        }
        for (AssessmentIndicatorEnum value : values) {
            if (indicatorId.equals(value.indicatorId)) {
                return value;
            }
        }
        return null;
    }
}
