package com.jiankangyouyi.cloud.assessment.enums.assessmentCentre;

import com.jiankangyouyi.cloud.data.center.api.enums.HealthProblemEnum;
import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * 家族疾病史类型枚举类
 *
 * @author yangsongbo
 */
@Getter
@AllArgsConstructor
public enum FamilyPreviousHistoryEnum {

    /**
     * 肥胖
     */
    OBESITY( "肥胖", HealthProblemEnum.OBESITY.getCode()),
    /**
     * 2型糖尿病
     */
    DIABETES_TYPE_2("2型糖尿病",HealthProblemEnum.TYPE_2_DIABETES.getCode()),
    /**
     * 痛风
     */
    GOUT("痛风",HealthProblemEnum.GOUT.getCode()),
    /**
     * 血脂异常（高血脂）
     */
    HIGH_BLOOD_FAT("高血脂",HealthProblemEnum.HPYPERLIPIDEMIA.getCode()),
    /**
     * 脂肪肝
     */
    FATTY_LIVER( "脂肪肝",HealthProblemEnum.FATTY_LIVER.getCode()),
    /**
     * 甲状腺功能亢进（甲亢）
     */
    HYPERTHYROIDISM( "甲亢",HealthProblemEnum.IIH.getCode()),
    /**
    /**
     *支气管哮喘
     */
    ASTHMA("支气管哮喘",HealthProblemEnum.ASTHMA.getCode()),
    /**
     * 慢性支气管炎
     */
    CHRONIC_BRONCHITIS("慢性支气管炎",HealthProblemEnum.CHRONIC_BRONCHITIS.getCode()),
    /**
     * 肺气肿
     */
    EMPHYSEMA("肺气肿",HealthProblemEnum.EMPHYSEMA.getCode()),
    /**
     * 慢阻肺
     */
    COPD( "慢阻肺",HealthProblemEnum.COPD.getCode()),
    /**
     * 高血压
     */
    HIGH_BLOOD_PRESSURE("高血压",HealthProblemEnum.HYPERTENSION.getCode()),
    /**
     * 冠心病
     */
    CORONARY_DISEASE("冠心病",HealthProblemEnum.CORONARY_DISEASE.getCode()),
    /**
     * 脑卒中
     */
    APOPLEXY("脑卒中",HealthProblemEnum.STROKE.getCode()),
    /**
     * 骨质疏松
     */
    OSTEOPOROSIS( "骨质疏松",HealthProblemEnum.OSTEOPOROSIS.getCode()),
    /**
     * 因摔倒骨折
     */
    TRIP_FRACTURE("因摔倒骨折",HealthProblemEnum.TRIP_FRACTURE.getCode()),
    /**
     * 驼背
     */
    KYPHOSIS("驼背",HealthProblemEnum.KYPHOSIS.getCode()),

    /**
     * 高尿酸血症
     */
    HYPERURICEMIA("高尿酸血症",HealthProblemEnum.HYPERURICEMIA.getCode()),
    /**
     * 骨折
     */
    VCFS("骨折",HealthProblemEnum.VCFS.getCode()),



    ;

    /**
     * 疾病名称
     */
    private String diseaseName;

    /**
     * 疾病编码
     */
    private String diseaseCode;

    public static FamilyPreviousHistoryEnum getEnumByDiseaseName(String diseaseName) {
        FamilyPreviousHistoryEnum[] values = values();
        if (diseaseName == null) {
            return null;
        }
        for (FamilyPreviousHistoryEnum value : values) {
            if (diseaseName.equals(value.diseaseName)) {
                return value;
            }
        }
        return null;
    }


}
