package com.jiankangyouyi.cloud.assessment.enums.assessmentCentre.v3;

import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * 风险因素Enum
 *
 * @author fengxuanjun
 */
@AllArgsConstructor
@Getter
public enum RiskElementEnumV3 {

    /**
     * 健康人群
     */
    HEALTH("HEALTH","健康人群","健康人群","健康人群","健康人群"),

    /**
     * 偏瘦，当前结果业务代码中实现
     */
    THIN("THIN","偏瘦","18.5≤BMI＜24","","体重过轻会导致身体营养素缺乏、免疫力下降，使某些疾病患病率增高。"),
    /**
     * 超重，当前结果业务代码中实现
     */
    OVERWEIGHT("OVERWEIGHT","超重","18.5≤BMI＜24","","超重或肥胖最大的危害是与肥胖有关的并发症或伴发症，主要有睡眠呼吸暂停综合征、高血压、糖尿病、高血脂、脂肪肝、多囊卵巢综合征、哮喘等。"),
    /**
     * 肥胖，当前结果业务代码中实现
     */
    OBESITY("OBESITY","肥胖","18.5≤BMI＜24","","超重或肥胖最大的危害是与肥胖有关的并发症或伴发症，主要有睡眠呼吸暂停综合征、高血压、糖尿病、高血脂、脂肪肝、多囊卵巢综合征、哮喘等。"),
    /**
     * 中心型肥胖，参考范围，当前结果业务代码中实现
     */
    OBESITY_CENTER("OBESITY_CENTER","中心型肥胖","","","根据相关调查数据汇总，男性腰围≥85cm，女性腰围≥80cm者，患高血压的危险因素是腰围低于此值者的3.5倍，患糖尿病的危险约为2.5倍。"),
    /**
     * 高盐饮食
     */
    FOOD_HIGH_SALINITY("FOOD_HIGH_SALINITY","高盐饮食","低盐饮食","高盐饮食","研究发现，高盐饮食与高血压、心脏病、肾脏病及脑出血、胃癌等的发生有关。"),
    /**
     * 高糖饮食
     */
    FOOD_HIGH_SUGAR("FOOD_HIGH_SUGAR","高糖饮食","适量糖","高糖饮食","过多吃甜食容易患龋齿，另外，高糖饮食容易造成能量过剩，使多余的碳水化合物以脂肪的形式储存，会增加患慢性疾病的风险，包括超重肥胖、2型糖尿病、高血脂、高血压、脂肪肝、心血管病等。"),
    /**
     * 高碘饮食
     */
    FOOD_HIGH_IODINE("FOOD_HIGH_IODINE","高碘饮食","适量碘","高碘饮食","高碘同低碘一样会危害人体健康，会引起高碘甲状腺肿等不良反应，甚至造成碘源性甲亢。长期大量食用海带、紫菜易增加碘过量风险，尤其是在食用碘盐的情况下。"),
    /**
     * 抑制碘吸收->致甲肿物质
     */
    FOOD_RESTRAIN_IODINE("FOOD_RESTRAIN_IODINE","致甲肿物质","避免卷心菜、甘蓝等十字花科食物","致甲肿物质","卷心菜、甘蓝、木薯等是易导致甲状腺肿的食物，长期大量食用增加甲状腺功能减退发病或加重风险，请慎食致甲状腺肿食物。"),
    /**
     * 高脂肪高胆固醇饮食
     */
    FOOD_HIGH_FAT_TC("FOOD_HIGH_FAT_TC","高脂肪高胆固醇饮食","均衡膳食","高脂肪高胆固醇饮食","长期摄入高脂肪高胆固醇饮食容易引起机体能量过剩、胆固醇升高，从而增加肥胖风险，容易使血液粘稠，增加形成血栓的风险，诱发或加重多种慢性疾病，危害身体健康。"),
    /**
     * 高嘌呤饮食
     */
    FOOD_HIGH_PURINE("FOOD_HIGH_PURINE","高嘌呤饮食","均衡膳食","高嘌呤饮食","高嘌呤饮食可使血尿酸浓度升高，甚至诱发痛风性关节炎的急性发作，因此控制膳食中嘌呤的摄入可以在一定程度上控制血尿酸水平，减小痛风患者急性发作的风险。喝浓肉汤易诱发或加重高血脂。高嘌呤食物中的海鲜等含碘相对高，甲亢者不宜食用。"),
    /**
     * 烟熏饮食
     */
    FOOD_SMUDGIND("FOOD_SMUDGIND","烟熏饮食","避免烟熏饮食","烟熏饮食","烟熏饮食会增加患癌风险，日常应选择新鲜卫生的食物和适宜的烹调方式。"),
    /**
     * 蔬菜摄入不足
     */
    FOOD_LACK_VEGETABLES("FOOD_LACK_VEGETABLES","蔬菜摄入不足","足量蔬菜","蔬菜摄入不足","蔬菜富含维生素、矿物质、膳食纤维和植物化学物，且能量低。经相关研究表明，每天足量蔬菜可降低心血管疾病的发病及死亡风险、可降低食管癌、结肠癌、胃癌发病风险，绿叶蔬菜可降低2型糖尿病发病风险。"),
    /**
     * 水果摄入不足
     */
    FOOD_LACK_FRUITS("FOOD_LACK_FRUITS","水果摄入不足","足量水果","水果摄入不足","建议天天吃水果，经相关研究表明，每天摄入足量水果可降低心血管疾病发病风险、降低成年人体重增长的风险、降低主要消化道癌症的发病风险。"),
    /**
     * 奶类摄入不足
     */
    FOOD_LACK_DAIRY("FOOD_LACK_DAIRY","奶类摄入不足","每天300g奶","奶类摄入不足","牛奶及其制品富含钙，多摄入可以增加成人骨密度，另外酸奶可以缓解便秘。"),
    /**
     * 精细饮食
     */
    FOOD_FINE("FOOD_FINE","精细饮食","粗细搭配","精细饮食","在无疾病限制的情况下，主食应注意增加全谷物、杂豆、薯类等食物，因为加工精度高的谷类，营养含量大大减少，且易引起人体较高的血糖应答，对防治高血脂也不利。"),
    /**
     * 豆类摄入不足
     */
    FOOD_LACK_BEANS("FOOD_LACK_BEANS","豆类摄入不足","常吃大豆和豆制品","豆类摄入不足","大量体外和流行病学研究文献表明大豆及其中的蛋白质、异黄酮和皂苷等成分具有免疫调节及抗癌作用。"),


//    /**
//     * 日常生活习惯
//     * 饮食规律
//     */
//    DAILY_FOOD_RULE("DAILY_FOOD_RULE","饮食规律","规律饮食","饮食不规律","不良的饮食习惯，可能会引起糖、脂代谢紊乱， 造成营养缺乏或能量过剩，建议定时定量进餐、避免夜宵、减少高能量食品的摄入、减少在外就餐、避免进餐过快、每顿少吃一两口。"),
//    /**
//     * 日常作息
//     */
//    DAILY_WORK("DAILY_WORK","日常作息","规律作息","作息不规律","作息不规律会引起代谢紊乱，增加糖尿病、高尿酸血症、痛风等代谢性疾病的风险，同时还可以导致免疫力低下。"),
//    /**
//     * 进食速度
//     */
//    DAILY_FOOD_QUICK("DAILY_FOOD_QUICK","进食速度","细嚼慢咽","进食过快","进食过快会导致食物摄入过多，增加肥胖风险；同时由于咀嚼不到位，肠胃负担增加，营养不能会很好的吸收，导致营养不良。"),
//    /**
//     * 饮食结构
//     */
//    DAILY_FOOD_FLAT("DAILY_FOOD_FLAT","饮食结构","不吃宵夜","夜晚进食","经常吃宵夜会导致一天的总热量摄入过剩，加重肠胃负担，诱发失眠，导致代谢紊乱，增加肥胖的风险，同时也不利于血糖及痛风、高血脂等疾病的控制。"),
//    /**
//     * 就餐习惯
//     */
//    DAILY_FOOD_HABIT("DAILY_FOOD_HABIT","就餐习惯","减少在外就餐","常在外就餐","外面的饮食多属于高油高盐高脂饮食，富含饱和脂肪、反式脂肪、钠盐、糖类等，是肥胖、糖尿病、心血管病等的风险因素。"),
//    /**
//     * 三餐配比
//     */
//    DAILY_FOOD_MATCHING("DAILY_FOOD_MATCHING","三餐配比","早餐定时","不吃早餐","早餐可以快速的补充能量及消耗的各种营养素，长期不吃早餐会引起基础代谢降低，不利于体重控制，降低胰岛素的敏感性，增加代谢性疾病的风险。"),



    /**
     * 运动不足
     */
    EXERCISE_LCAK("EXERCISE_LCAK","运动不足","增加运动","运动不足","增加有规律的身体活动可以降低全因死亡风险，久坐不动会增加全因死亡率风险，是独立危险因素。增加身体活动可以降低心血管疾病、2型糖尿病、结肠癌、肺癌、乳腺癌的发病风险。"),
    /**
     * 日光照射不足
     */
    EXERCISE_LCAK_SUNSHINE("EXERCISE_LCAK_SUNSHINE","日光照射不足","多户外活动","日光照射不足","日光中的紫外线能够预防维生素D的缺乏和不足。适当的日照，不仅能改善骨代谢、骨密度情况，而且能够有效缓解骨质疏松的临床症状。"),
    /**
     * 疑似过量运动
     */
    EXERCISE_OVER_DOUBT("EXERCISE_OVER_DOUBT","疑似过量运动","避免过量运动","疑似过量运动","大强度过量运动可出现运动性免疫功能低下，导致对疾病的抵抗力削弱，上呼吸道感染的发生率增高。需注意勿过量运动。剧烈运动易使血尿酸增高。"),
    /**
     * 久坐
     */
    EXERCISE_SITTING("EXERCISE_SITTING","久坐","避免久坐","久坐","久坐不动是增加全因死亡率的独立危险因素，因此每小时都应主动起来动一动，动则有益。"),
    /**
     * 过量饮酒
     */
    DRINK_OVER("DRINK_OVER","过量饮酒","戒酒","过量饮酒","过量饮酒会伤害胃肠黏膜，并会影响肝脏和胰脏的功能，进而影响营养素的消化吸收及利用。此外还会增加高血压、中风、乳腺癌、消化道癌症及骨质疏松的危险。"),
    /**
     * 饮酒
     */
    DRINK("DRINK","饮酒","戒酒","饮酒","酒精对肝脏有直接的毒性作用，吸收入血的乙醇在肝内代谢，引起氧化还原状态的变化，从而干扰脂类、糖类和蛋白质等营养物质的正常代谢，也影响肝脏的正常解毒功能。"),
    /**
     * 饮水不足
     */
    WATER_LACK("WATER_LACK","饮水不足","每天1500-1700ml饮水量","饮水不足","水是一切生命必须的物质，也是营养输送、促进食物消化吸收代谢的重要载体。饮水不足或过多都会对人体健康造成危害，饮水应少量多次，要主动，不要感到口渴时再喝水。"),
    /**
     * 吸烟
     */
    SMOKE("SMOKE","吸烟","戒烟","吸烟","吸烟值得一提的是会增加叶酸缺乏风险，且大量的医学考证表明，烟草是心脑血管疾病、癌症、慢性阻塞性肺病等多种疾患的重要致病因素，而吸烟者与不吸烟者相比，平均寿命约减少10年。"),
    /**
     * 接触二手烟
     */
    SMOKE_SECOND("SMOKE_SECOND","接触二手烟","避免接触二手烟","接触二手烟","吸入二手烟会导致癌症、心血管疾病、呼吸系统疾病等多种疾病的发生，对人体健康造成严重损害。"),
    /**
     * 入睡困难，参考范围业务中实现
     */
    SLEEP_DIFFICULTY("SLEEP_DIFFICULTY","入睡困难","","入睡困难","睡眠作为生命所必须的过程，是调节压力、消除疲劳、恢复体力的\"良药\"，是机体复原、整合和巩固记忆的重要环节。而优质充足的睡眠是维护健康和体力的基础，请您适当调整睡眠。"),
    /**
     * 易醒
     */
    SLEEP_EASILY_WAKE("SLEEP_EASILY_WAKE","易醒","优质睡眠","易醒","睡眠作为生命所必须的过程，是调节压力、消除疲劳、恢复体力的\"良药\"，是机体复原、整合和巩固记忆的重要环节。而优质充足的睡眠是维护健康和体力的基础，请您适当调整睡眠。"),
    /**
     * 早醒
     */
    SLEEP_EARLY_WAKE("SLEEP_EARLY_WAKE","早醒","充足睡眠","早醒","睡眠作为生命所必须的过程，是调节压力、消除疲劳、恢复体力的\"良药\"，是机体复原、整合和巩固记忆的重要环节。而优质充足的睡眠是维护健康和体力的基础，请您适当调整睡眠。"),
    /**
     * 睡眠习惯差
     */
    SLEEP_BAD_HABIT("SLEEP_BAD_HABIT","睡眠习惯差","良好睡眠习惯","睡眠习惯差","睡眠作为生命所必须的过程，是调节压力、消除疲劳、恢复体力的\"良药\"，是机体复原、整合和巩固记忆的重要环节。而优质充足的睡眠是维护健康和体力的基础，请您适当调整睡眠。"),
    /**
     * 晚睡
     */
    SLEEP_LATE("SLEEP_LATE","晚睡","充足睡眠","晚睡","睡眠作为生命所必须的过程，是调节压力、消除疲劳、恢复体力的\"良药\"，是机体复原、整合和巩固记忆的重要环节。而优质充足的睡眠是维护健康和体力的基础，请您适当调整睡眠。"),
    /**
     * 睡眠不足
     */
    SLEEP_LACK("SLEEP_LACK","睡眠不足","充足睡眠","睡眠不足","睡眠作为生命所必须的过程，是调节压力、消除疲劳、恢复体力的\"良药\"，是机体复原、整合和巩固记忆的重要环节。而优质充足的睡眠是维护健康和体力的基础，请您适当调整睡眠。"),
    /**
     * 负面情绪
     */
    SPIRIT_NEGATIVE("SPIRIT_NEGATIVE","负面情绪","心理健康","负面情绪","不良的精神心理因素可以引起高血压、胃肠不适，抑制免疫功能，对糖尿病的治疗和预后也有不利影响。"),
    /**
     * 处于污染环境
     */
    ENVIRONMENT_POLLUTE("ENVIRONMENT_POLLUTE","处于污染环境","远离污染环境","处于污染环境","人需要呼吸空气以维持生命，若人长期处于污染环境中，易引起人体呼吸系统受损、生理机能障碍、消化系统紊乱、神经系统异常、智力下降、致癌致残、慢性支气管炎、支气管哮喘、肺气肿等疾病。"),
    //v1.1
    /**
     * 咖啡过量
     */
    COFFEE_OVER("COFFEE_OVER","咖啡过量","咖啡宜适量","咖啡过量","过量咖啡因会增加骨质疏松风险，且咖啡含有耐热型抗硫胺素因子易导致维生素B1缺乏，故饮咖啡宜适量。"),
    /**
     * 常喝浓茶
     */
    DRINK_STRONG_TEA("DRINK_STRONG_TEA","常喝浓茶","宜喝淡茶","常喝浓茶","茶叶含有耐热型抗硫胺素因子易导致维生素B1缺乏，故饮茶宜淡。此外浓茶对痛风、高尿酸血症、甲亢、阿尔茨海默症患者都不利。"),
    /**
     * 碳酸饮料
     */
    SODAS("SODAS","碳酸饮料","少喝碳酸饮料","碳酸饮料","碳酸饮料含磷高，易干扰钙吸收，故不宜多喝。"),
    /**
     * 常喝纯净水
     */
    DRINK_PURE_WATER("DRINK_PURE_WATER","常喝纯净水","合理选水","常喝纯净水","纯净水最大限度的去除了水中的杂质和各种矿物质，虽干净卫生，但也营养物质少，不利补充营养。"),
    /**
     * 淘米次数多
     */
    WASH_RICE_OVER("WASH_RICE_OVER","淘米次数多","减少淘米次数","淘米次数多","淘米次数太多会损失很多营养，如维生素B1、B2、矿物质等，故不宜淘洗次数过多。"),
    /**
     * 烹调加碱
     */
    ALKALINE_COOKING("ALKALINE_COOKING","烹调加碱","合理烹调","烹调加碱","烹调中加碱可导致维生素B1维生素B2等大量损失。"),
    /**
     * 缺去草酸处理
     */
    ABSENCE_OF_OXALIC_ACID_TREATMENT("ABSENCE_OF_OXALIC_ACID_TREATMENT","缺去草酸处理","注意去草酸","缺去草酸处理","菠菜、厚皮菜、空心菜、茭白、冬笋、洋葱等含草酸量高，妨碍钙、铁的吸收，可先焯水后炒，去除部分草酸，更利营养吸收。"),
    /**
     * 肉类摄入不当
     */
    IMPROPER_MEAT_INTAKE("IMPROPER_MEAT_INTAKE","肉类摄入不当","合理摄入肉类","肉类摄入不当","水产、畜禽肉类富含优质蛋白、脂类、多种维生素、矿物质，宜每天适量食用肉类，且各类肉营养各有特色，每天或每周多样食用更利营养均衡；但要少吃肥肉，肥肉饱和脂肪酸、胆固醇含量高，多吃对健康不利。素食者宜关注营养状况，必要时进行营养补充。"),
    /**
     * 蛋类摄入不当
     */
    IMPROPER_EGG_INTAKE("IMPROPER_EGG_INTAKE","蛋类摄入不当","合理摄入蛋类","蛋类摄入不当","蛋类营养丰富，适当摄入更能保证营养均衡，在没有疾病因素需控制的情况下，建议每天1个鸡蛋。"),
    /**
     * 常吃加工食品
     */
    EAT_PROCESSED_FOODS("EAT_PROCESSED_FOODS","常吃加工食品","少吃加工食品","常吃加工食品","加工食品可含有反式脂肪酸、防腐剂、致癌物等多种有害成分，目前虽没有明确吃多少才是安全的，但“少吃”可减少带来疾病的风险。"),
    /**
     * 深色菜不足
     */
    LACK_OF_DARK_DISHES("LACK_OF_DARK_DISHES","深色菜不足","增加深色菜","深色菜不足","深色蔬菜指深绿色、红色、橘红色和紫红色蔬菜，具有营养优势，尤其是胡萝卜素，是我国居民膳食维生素A的主要来源，无疾病控制情况下，应特别注意多摄入。"),

    //v1.2
    /**
     * 减重过快
     */
    LOSE_WEIGHT_FAST("LOSE_WEIGHT_FAST","减重过快","控制减重速度","减重过快","美国妇产科医师学会建议哺乳时每周减去1磅（453.6g）体重，不会对婴儿的成长有负面影响，如果未进行母乳喂养，则建议每周减去1~2磅的体重。英国国家健康与临床优化研究所建议产后体重降低不超过0.5~1kg/周，否则可能影响产后恢复以及母乳分泌。"),

    //新增六种癌症 2023年2月8日
    /**
     * 多个性伴侣
     */
    MULTIPLE_SEXUAL_PARTNERS("MULTIPLE_SEXUAL_PARTNERS","多个性伴侣","健康性行为","多个性伴侣","性伴侣越多，感染HPV的几率越高。"),
    /**
     * 红肉和加工肉类摄入过多
     */
    RED_AND_PROCESSED_MEAT_OVER("RED_AND_PROCESSED_MEAT_OVER","红肉和加工肉类摄入过多","适量吃红肉、少吃加工肉类","红肉和加工肉类摄入过多","红肉和加工肉类摄入与结直肠癌发病风险增高有关，相关报告指出，加工肉类每日摄入量每增加50g，红肉每日摄入量每增加100g，结直肠癌发病风险分别增加16%和12%。"),
    /**
     * 有相关职业暴露史
     */
    JOB_EXPOSE_HISTORY("JOB_EXPOSE_HISTORY","有相关职业暴露史","做好职业防护","有相关职业暴露史","工作中要了解工作岗位和工作环境中存在的危害因素，遵守操作规程，注意个人防护，避免职业伤害。"),


    ;
    /**
     * 风险因素分类
     */
    private String riskFactor;
    /**
     * 风险因素名称
     */
    private String riskFactorName;
    /**
     * 参考范围(建议)
     */
    private String referAdvice;
    /**
     * 当前结果
     */
    private String currentValue;
    /**
     * 风险因素通用描述
     */
    private String description;



}
