package com.jiankangyouyi.cloud.assessment.model.entity.mongo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.core.base.entity.AbstractMongoEntity;
import com.jiankangyouyi.cloud.core.base.enums.ValidStatusEnum;
import lombok.*;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.annotation.Version;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;

/**
 * 测评访问令牌表
 *
 * @author : yangsongbo
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "appId_-1_userId_-1_bizType_1_validStatus_1",
                        def = "{ 'appId': -1,'userId': -1,'bizType':1,'validStatus':1}",
                        unique = true
                )
        }
)
@Document(collection = "assessment.access.token")
public class AssessmentAccessTokenDO implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    @Id
    private ObjectId id;

    /**
     * 访问令牌ID，业务主键
     */
    @Indexed(unique = true)
    private String tokenId;

    /**
     * 访问令牌
     */
    private String accessToken;

    /**
     * 应用ID，不能为空
     */
    private String appId;

    /**
     * 业务类型，见《开放平台业务类型设计.xlsx》
     */
    private String bizType;

    /**
     * 用户ID
     */
    private String userId;

    /**
     * 有效标识符
     */
    private String validStatus;

    /**
     * 修改时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime ;
    /**
     * 修改时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime ;


    public static final String FIELD_ID = "_id";
    public static final String FIELD_VALIDSTATUS = "validStatus";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_TOKENID = "tokenId";
    public static final String FIELD_ACCESSTOKEN = "accessToken";
    public static final String FIELD_APPID = "appId";
    public static final String FIELD_BIZTYPE = "bizType";
    public static final String FIELD_USERID = "userId";


}
