package com.jiankangyouyi.cloud.assessment.model.entity.mongo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.assessment.model.param.AssessmentParams;
import com.jiankangyouyi.cloud.assessment.model.report.AssessmentReport;
import com.jiankangyouyi.cloud.core.base.entity.BaseMongoEntity;
import lombok.*;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;
import java.util.List;

/**
 * 测评结果表
 *
 * @author : yangsongbo
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
@Document(collection = "assessment.report")
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "appId_-1_userId_-1_bizType_-1_validStatus_1_reportId_-1",
                        def = "{'appId': -1, 'userId': -1,'bizType':-1,'validStatus':1,'reportId':-1}"
                ),
                @CompoundIndex(
                        name = "createDate_-1_appId_-1_bizType_-1_validStatus_1_reportId_-1",
                        def = "{'createDate':-1,'appId': -1, 'bizType': -1,'validStatus':1,'reportId':-1}"
                ),
                @CompoundIndex(
                        name = "tokenId_-1",
                        def = "{'tokenId':-1}"
                ),
                @CompoundIndex(
                        name = "createTime_-1_appId_userId_-1_-1_bizType_-1_assessmentType_1",
                        def = "{'createTime':-1,'appId': -1,'userId':-1, 'bizType': -1,'assessmentType': 1}"
                ),
        }
)
public class AssessmentReportDO extends BaseMongoEntity {

    private static final long serialVersionUID = 1L;

    /**
     * 配置ID，业务主键
     */
    @Indexed(unique = true)
    private String reportId;

    /**
     * accessToken Id
     */
    private String tokenId;

    /**
     * 业务类型，见《开放平台业务类型设计.xlsx》
     */
    private String bizType;

    /**
     * 应用ID
     */
    private String appId;

    /**
     * 测评项目ID
     */
    private String configId;

    /**
     * 用户ID
     */
    private String userId;

    /**
     * 本次测评的健康问题编码
     * {@link com.jiankangyouyi.cloud.assessment.enums.assessmentCentre.DiseaseEnum}
     */
    private List<String> assessmentHealthProblems;

    /**
     * 测评类型
     * {@link com.jiankangyouyi.cloud.assessment.enums.assessmentCentre.AssessmentTypeEnum}
     */
    private String assessmentType;

    /**
     * 测评参数
     */
    private AssessmentParams assessmentParams;

    /**
     * 测评报告
     */
    private AssessmentReport assessmentReport;

    /**
     * 关联制定方案id
     */
    private String planId;

    /**
     * 指定方案开始时间 yyyy-MM-dd
     */
    private String planStartDate;

    /**
     * 制定方案结束时间 yyyy-MM-dd
     */
    private String planEndDate;

    /**
     * 制定方案实际开始时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date planActualStartDate;

    /**
     * 指定方案实际结束时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date planActualEndDate;

    /**
     * 创建日期 yyyy-MM-dd
     */
    private String createDate;

    public static final String FIELD_REPORTID = "reportId";
    public static final String FIELD_TOKENID = "tokenId";
    public static final String FIELD_BIZTYPE = "bizType";
    public static final String FIELD_APPID = "appId";
    public static final String FIELD_USERID = "userId";
    public static final String FIELD_CONFIGID = "configId";
    public static final String FIELD_ASSESSMENTPARAMS = "assessmentParams";
    public static final String FIELD_ASSESSMENTREPORT = "assessmentReport";
    public static final String FIELD_PLANID = "planId";
    public static final String FIELD_CREATEDATE = "createDate";
    public static final String FIELD_ASSESSMENT_TYPE = "assessmentType";
    public static final String FIELD_ASSESSMENTREPORT_REPORT_DISEASESANALYSIS = "assessmentReport.report.diseasesAnalysis";

}
