package com.jiankangyouyi.cloud.assessment.model.entity.mongo.effect;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.assessment.model.entity.mongo.effect.component.EffectReport;
import com.jiankangyouyi.cloud.assessment.model.param.AssessmentParams;
import lombok.*;
import lombok.experimental.SuperBuilder;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;

/**
 * 效果评估表
 *
 * @author : fengxuanjun
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
@Document(collection = "v3.effect.report")
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "appId_-1_userId_-1_bizType_-1_validStatus_1_reportId_-1",
                        def = "{'appId': -1, 'userId': -1,'bizType':-1,'validStatus':1,'reportId':-1}"
                ),
                @CompoundIndex(
                        name = "createDate_-1_appId_-1_bizType_-1_validStatus_1_reportId_-1",
                        def = "{'createDate':-1,'appId': -1, 'bizType': -1,'validStatus':1,'reportId':-1}"
                ),
                @CompoundIndex(
                        name = "tokenId_-1",
                        def = "{'tokenId':-1}"
                )
        }
)
public class EffectReportDO extends EffectReport implements Serializable {

    private static final long serialVersionUID = 1L;

    @Id
    private ObjectId id;

    /**
     * 报告ID
     */
    @Indexed(unique = true)
    private String reportId;

    /**
     * tokenId
     */
    private String tokenId;

    /**
     * 状态
     * {@link com.jiankangyouyi.cloud.core.base.enums.ValidStatusEnum}
     */
    private String validStatus;

    @DateTimeFormat(
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    @JsonFormat(
            timezone = "GMT+8",
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    private Date updateTime;
    @DateTimeFormat(
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    @JsonFormat(
            timezone = "GMT+8",
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    private Date createTime;

    @JsonFormat(
            timezone = "GMT+8",
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    private Date reportTime;

    /**
     * 创建日期 yyyy-MM-dd
     */
    private String createDate;

    public static final String FIELD_REPORTID = "reportId";
    public static final String FIELD_TOKENID = "tokenId";
    public static final String FIELD_BIZTYPE = "bizType";
    public static final String FIELD_APPID = "appId";
    public static final String FIELD_USERID = "userId";
    public static final String FIELD_ASSESSMENTPARAMS = "assessmentParams";
    public static final String FIELD_REPORT = "report";
    public static final String FIELD_GUIDE = "guide";
    public static final String FIELD_CREATEDATE = "createDate";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_VALIDSTATUS = "validStatus";

}
