package com.jiankangyouyi.cloud.assessment.model.entity.mongo.effect.component;

import com.jiankangyouyi.cloud.assessment.api.enums.effect.ChangeStatusEnum;
import com.jiankangyouyi.cloud.assessment.api.enums.effect.EffectStatusEnum;
import com.jiankangyouyi.cloud.assessment.api.enums.effect.RiskChangeEnum;
import com.jiankangyouyi.cloud.assessment.enums.assessmentCentre.DailyLifeEnum;
import com.jiankangyouyi.cloud.assessment.model.param.AssessmentParams;
import com.jiankangyouyi.cloud.basedata.api.enums.BodyIndicatorEnum;
import com.jiankangyouyi.cloud.basedata.api.enums.RiskLevelEnum;
import com.jiankangyouyi.cloud.data.center.api.enums.HealthProblemEnum;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import java.io.Serializable;
import java.util.List;

/**
 * 效果评估表
 *
 * @author : fengxuanjun
 */
@Data
@SuperBuilder
@AllArgsConstructor
@NoArgsConstructor
public class EffectReport implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 业务类型，见《开放平台业务类型设计.xlsx》
     */
    private String bizType;

    /**
     * 应用ID
     */
    private String appId;

    /**
     * 用户ID
     */
    private String userId;

    /**
     * 权限ID
     */
    private String configId;

    /**
     * 测评参数
     */
    private AssessmentParams assessmentParams;

    /**
     * 效果评估报告
     */
    private Report report;

    /**
     * 效果评估指导建议
     */
    private Guide guide;

    /**
     * 测评报告
     */
    @Data
    @Builder
    @NoArgsConstructor
    @AllArgsConstructor
    public static class Report implements Serializable {

        private static final long serialVersionUID = 1L;

        /**
         * 健康综述
         */
        private List<String> reviews;

        /**
         * 指标控制情况
         */
        private IndicatorControl indicatorControl;

        /**
         * 症状改善情况
         */
        private SymptomAnalysis symptomAnalysis;

        /**
         * 风险程度变化
         */
        private RiskChange riskChange;

    }

    /**
     * 指标控制情况
     */
    @Data
    @Builder
    @NoArgsConstructor
    @AllArgsConstructor
    public static class IndicatorControl implements Serializable {

        private static final long serialVersionUID = 1L;

        /**
         * 指标信息列表
         */
        private List<IndicatorInfo> indicatorInfos;

        /**
         * 指标控制情况建议
         */
        private List<String> indicatorAdvice;


    }

    /**
     * 指标控制情况-指标信息
     */
    @Data
    @Builder
    @NoArgsConstructor
    @AllArgsConstructor
    public static class IndicatorInfo implements Serializable {

        private static final long serialVersionUID = 1L;

        /**
         * 评价结果
         * {@link com.jiankangyouyi.cloud.assessment.api.enums.effect.EffectStatusEnum}
         */
        private String resultStatus;

        /**
         * 指标类型
         */
        private String indicatorType;

        /**
         * 指标名称
         */
        private String indicatorName;

        public IndicatorInfo(EffectStatusEnum effectStatus, BodyIndicatorEnum indicator) {
            this.resultStatus = effectStatus.getCode();
            this.indicatorType = indicator.getIndicator();
            this.indicatorName = indicator.getIndicatorName();
        }
    }

    /**
     * 症状改善情况
     */
    @Data
    @Builder
    @NoArgsConstructor
    @AllArgsConstructor
    public static class SymptomAnalysis implements Serializable {

        private static final long serialVersionUID = 1L;

        /**
         * 评价结果
         * {@link com.jiankangyouyi.cloud.assessment.api.enums.effect.EffectStatusEnum}
         */
        private String resultStatus;

        /**
         * 症状综述
         */
        private List<String> reviews;

        /**
         * 症状列表
         */
        private List<Symptom> symptoms;

    }

    /**
     * 症状
     */
    @Data
    @Builder
    @NoArgsConstructor
    @AllArgsConstructor
    public static class Symptom implements Serializable {

        private static final long serialVersionUID = 1L;

        /**
         * 症状状态
         * 1：新增
         * 2：改善
         * 3：持续
         * {@link ChangeStatusEnum}
         */
        private String symptomStatus;

        /**
         * 症状编码
         */
        private String symptomCode;

        /**
         * 症状名称
         */
        private String symptomName;

    }

    /**
     * 风险程度变化
     */
    @Data
    @Builder
    @NoArgsConstructor
    @AllArgsConstructor
    public static class RiskChange implements Serializable {

        private static final long serialVersionUID = 1L;

        /**
         * 评价结果
         * {@link com.jiankangyouyi.cloud.assessment.api.enums.effect.EffectStatusEnum}
         */
        private String resultStatus;

        /**
         * 风险程度变化综述
         */
        private List<String> reviews;

        /**
         * 风险程度变化分析
         */
        private List<RiskAnalysis> riskAnalysis;


        /**
         * 默认为一般
         *
         * @return 返回默认数据
         */
        public static RiskChange defaultValue() {
            return RiskChange.builder().resultStatus(EffectStatusEnum.GENERAL.getCode()).build();
        }

    }

    /**
     * 风险程度变化分析
     */
    @Data
    @Builder
    @NoArgsConstructor
    @AllArgsConstructor
    public static class RiskAnalysis implements Serializable {

        private static final long serialVersionUID = 1L;

        /**
         * 风险程度状态
         * 1：风险增加
         * 2：风险降低
         * 3：风险不变
         *
         * @see RiskChangeEnum
         */
        private String riskStatus;

        /**
         * 健康问题编码
         *
         * @see com.jiankangyouyi.cloud.data.center.api.enums.HealthProblemEnum
         */
        private String healthProblemCode;

        /**
         * 健康问题名称
         */
        private String healthProblemName;

        /**
         * 之前风险等级
         *
         * @see com.jiankangyouyi.cloud.assessment.enums.RiskLevelEnum
         */
        private String oldRiskLevel;

        /**
         * 之前风险描述
         */
        private String oldRiskLevelDescription;

        /**
         * 当前风险等级
         *
         * @see com.jiankangyouyi.cloud.assessment.enums.RiskLevelEnum
         */
        private String nowRiskLevel;

        /**
         * 当前风险描述
         */
        private String nowRiskLevelDescription;

        public RiskAnalysis(RiskChangeEnum riskChangeEnum, HealthProblemEnum healthProblemEnum, RiskLevelEnum oldRiskLevel, RiskLevelEnum nowRiskLevel) {
            this.riskStatus = riskChangeEnum.getCode();
            this.healthProblemCode = healthProblemEnum.getCode();
            this.healthProblemName = healthProblemEnum.getName();
            this.oldRiskLevel = String.valueOf(oldRiskLevel.getLevel());
            this.oldRiskLevelDescription = oldRiskLevel.getDescription();
            this.nowRiskLevel = String.valueOf(nowRiskLevel.getLevel());
            this.nowRiskLevelDescription = nowRiskLevel.getDescription();
        }
    }

    /**
     * 指导建议（健康建议）
     */
    @Data
    @Builder
    @NoArgsConstructor
    @AllArgsConstructor
    public static class Guide implements Serializable {

        private static final long serialVersionUID = 1L;

        /**
         * 饮食建议
         */
        private DietAdvice dietAdvice;

        /**
         * 运动建议
         */
        private ExerciseAdvice exerciseAdvice;

        /**
         * 生活起居建议
         */
        private List<LifeStyleAdvice> lifeStyleAdvices;

    }

    /**
     * 饮食建议
     */
    @Data
    @Builder
    @NoArgsConstructor
    @AllArgsConstructor
    public static class DietAdvice implements Serializable {

        private static final long serialVersionUID = 1L;

        /**
         * 热量控制建议
         */
        private List<String> energyAdvices;

        /**
         * 三餐配比建议
         */
        private List<String> mealsAdvices;

        /**
         * 膳食结构建议
         */
        private List<String> balancedDietAdvices;

        /**
         * 膳食结构温馨提示
         */
        private List<String> balancedDietKindTips;

    }

    /**
     * 运动建议
     */
    @Data
    @Builder
    @NoArgsConstructor
    @AllArgsConstructor
    public static class ExerciseAdvice implements Serializable {

        private static final long serialVersionUID = 1L;

        /**
         * 运动原则
         */
        private List<ExercisePrinciple> exercisePrinciple;

        /**
         * 运动注意事项
         */
        private List<String> exerciseAttentions;

    }

    /**
     * 运动建议
     */
    @Data
    @Builder
    @NoArgsConstructor
    @AllArgsConstructor
    public static class ExercisePrinciple implements Serializable {

        private static final long serialVersionUID = 1L;

        /**
         * 类型：1 运动频率 2 运动强度 3 运动时长 4 运动方式
         */
        private String type;

        /**
         * 标题：运动频率、运动强度、运动时长、运动方式
         */
        private String title;

        /**
         * 建议内容
         */
        private String description;

    }

    /**
     * 生活起居建议
     */
    @Data
    @Builder
    @NoArgsConstructor
    @AllArgsConstructor
    public static class LifeStyleAdvice implements Serializable {

        private static final long serialVersionUID = 1L;

        /**
         * 类型
         * {@link DailyLifeEnum}
         */
        private String type;

        /**
         * 标题：运动频率、运动强度、运动时长、运动方式
         */
        private String title;

        /**
         * 建议内容
         */
        private List<String> descriptions;

    }


}
