package com.jiankangyouyi.cloud.assessment.model.entity.mongo.life.style;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.assessment.enums.assessment190101.LifeStyleSchemeEnum;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.FieldNameConstants;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 生活方式报告-方案-详情表
 *
 * @author : fengxuanjun
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "appId_-1_userId_-1_bizType_1_validStatus_1",
                        def = "{ 'appId': -1,'userId': -1,'bizType':1,'validStatus':1}"
                ),
                @CompoundIndex(
                        name = "businessId_-1",
                        def = "{ 'businessId': -1}"
                ),
        }
)
@Document(collection = "v3.life.style.report.scheme.detail")
@FieldNameConstants
public class LifeStyleReportSchemeDetailDO implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    @Id
    private ObjectId id;

    /**
     * 修改时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime ;
    /**
     * 修改时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime ;

    /**
     * 创建日期 yyyy-MM-dd
     */
    private String createDate;

    /**
     * 业务类型，见《开放平台业务类型设计.xlsx》
     */
    private String bizType;

    /**
     * 应用ID，不能为空
     */
    private String appId;

    /**
     * 用户ID
     */
    private String userId;

    /**
     * 报告ID
     */
    private String reportId;

    /**
     * 方案ID
     */
    private String schemeId;

    /**
     * 方案详情ID
     * {@link LifeStyleReportSchemeDO}
     * 生成ObjectId
     */
    private String schemeDetailId;

    /**
     * 方案详情业务ID
     * 生成ObjectId
     */
    private String businessId;

    /**
     * 方案类型（饮食、运动、饮酒、吸烟、心理、睡眠）
     * {@link com.jiankangyouyi.cloud.assessment.enums.LifeStyleSchemeTypeEnum}
     */
    private String schemeType;
    /**
     * 方案类型名称
     */
    private String schemeTypeName;
    /**
     * 方案 code
     * {@link LifeStyleSchemeEnum}
     */
    private String schemeCode;
    /**
     * 方案名称
     */
    private String schemeName;
    /**
     * 方案Logo
     */
    private String schemeLogo;
    /**
     * 底层库-方案组合-方案ID
     */
    private List<String> baseSchemeIds;
    /**
     * 展示状态
     * {@link com.jiankangyouyi.cloud.assessment.enums.assessment190101.LifeStyleSchemeShowStatusEnum}
     */
    private String schemeShowStatus;
    /**
     * 方案内容
     */
    private List<String> schemeContents;
    /**
     * 方案温馨提示
     */
    private List<String> warmPrompts;
    /**
     * 打卡情况 true、已打卡 false 、未打卡
     */
    private Boolean punchCardStatus;

    /**
     * 打卡时间
     */
    private Date punchCardTime;

    /**
     * 当前阶段
     * {@link com.jiankangyouyi.cloud.assessment.enums.assessment190101.LifeStyleSchemeStageEnum}
     */
    private Integer schemeStageNum;



    /**
     * 有效标识符
     */
    private String validStatus;


    public static final String FIELD_ID = "_id";
    public static final String FIELD_VALIDSTATUS = "validStatus";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_APPID = "appId";
    public static final String FIELD_BIZTYPE = "bizType";
    public static final String FIELD_USERID = "userId";
    public static final String FIELD_CREATEDATE = "createDate";
    public static final String FIELD_SCHEMEDETAILID = "schemeDetailId";
    public static final String FIELD_SCHEMEID = "schemeId";
    public static final String FIELD_REPORTID = "reportId";
    public static final String FIELD_BUSINESSID = "businessId";


}
