package com.jiankangyouyi.cloud.assessment.model.entity.mongo.life.style;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.assessment.enums.assessment190101.LifeStyleSchemeEnum;
import com.jiankangyouyi.cloud.assessment.model.entity.mongo.life.style.component.LifeStyleSchemeBasePriorityConfig;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 生活方式方案优先级表
 *
 * @author : fengxuanjun
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@Document(collection = "v3.life.style.scheme.priority")
public class LifeStyleSchemePriorityDO implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    @Id
    private ObjectId id;

    /**
     * 修改时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime ;
    /**
     * 修改时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime ;

    /**
     * 创建日期 yyyy-MM-dd
     */
    private String createDate;
    /**
     * 方案类型（饮食、运动、饮酒、吸烟、心理、睡眠）
     * {@link com.jiankangyouyi.cloud.assessment.enums.LifeStyleSchemeTypeEnum}
     */
    private String schemeType;
    /**
     * 方案类型名称
     */
    private String schemeTypeName;
    /**
     * 方案 code
     * {@link LifeStyleSchemeEnum}
     */
    private String schemeCode;
    /**
     * 方案名称
     */
    private String schemeName;

    /**
     * 等级（1，2，3级别）
     */
    private Integer level;

    /**
     * 父级编码
     */
    private String pSchemeCode;

    /**
     * 基础优先级权重
     * 注：配置信息，需要业务逻辑基于此数据进行业务逻辑动态计算
     */
    private List<LifeStyleSchemeBasePriorityConfig> basePriorityConfigs;

    /**
     * 有效标识符
     */
    private String validStatus;




    public static final String FIELD_ID = "_id";
    public static final String FIELD_VALIDSTATUS = "validStatus";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";


}
