package com.jiankangyouyi.cloud.assessment.model.param;

import com.fasterxml.jackson.annotation.JsonInclude;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.math.BigDecimal;
import java.util.List;

/**
 * 健康评估中心测评参数 bizType = 012502
 *
 * @author fengxuanjun
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@JsonInclude(value= JsonInclude.Include.NON_NULL)
public class Assessment012502Params implements AssessmentParams {
    private static final long serialVersionUID = 1L;


    /**
     * NOT NULL 出生日期，格式为yyyy-MM-dd,年龄（周岁）大于等于18岁，小于等于100岁
     */
    private String birthday;

    /**
     * NOT NULL 性别， 1 男 2 女
     */
    private String gender;

    /**
     * NOT NULL，身高，单位 cm,大于等于100，小于230
     */
    private BigDecimal height;

    /**
     * NOT NULL，单位 kg，保留1位小数，大于等于25，小于200
     */
    private BigDecimal weight;

    /**
     * NULL 腰围，单位 cm，大于等于50，小于200
     */
    private Integer waistline;

    /**
     * NULL 体脂率，单位 %，大于等于0，50
     */
    private Integer bfr;

    /**
     * 常居住地，1：城市 2：农村
     */
    private String residence;

    /**
     * NULL
     * 体力劳动的强度
     * 1 长时间久坐如银行、办公室职员
     * 2 体力活动一般如老师、学生
     * 3 体力活动较多如服务员
     * 4 体力活动为主如搬运工
     */
    private String activityLevel;

    /**
     * NULL
     * 代谢性疾病
     * 1 2型糖尿病
     * 2 高血脂
     * 3 高尿酸血症
     * 4 痛风
     * 5 脂肪肝
     * 6 多囊卵巢综合征
     * 7 甲减
     * 8 甲亢
     * 9 甲状腺功能异常
     */
    private List<String> metabolicDisease;
    /**
     * NULL
     * 自身免疫系统疾病
     * 1 红斑狼疮
     * 2 硬皮症
     * 3 干燥综合征
     * 4 类风湿关节炎
     * 5 1型糖尿病
     * 6 自身免疫性甲状腺疾病
     */
    private List<String> immuneSystem;
    /**
     * NULL
     * 心脑血管疾病
     * 1 高血压
     * 2 冠心病
     * 3 脑卒中
     * 4 缺血性心肌病
     * 5 外周动脉粥样硬化
     */
    private List<String> angiocarpyDisease;
    /**
     * NULL
     * 慢性疾病
     * 1 慢性肾病
     * 2 慢性乙肝
     * 3 慢性丙肝
     * 4 骨质疏松
     */
    private List<String> chronicDisease;
    /**
     * NULL
     * 呼吸系统疾病
     * 1 支气管哮喘
     * 2 过敏性鼻炎
     * 3 慢性支气管炎
     * 4 肺气肿
     * 5 慢阻肺
     * 6 睡眠呼吸暂停综合征
     */
    private List<String> breatheDisease;

    /**
     * NULL
     * 成年前健康问题
     * 1 婴幼儿期反复患下呼吸道感染。
     * 2 胎儿时期肺发育不良
     */
    private List<String> healthProblem;
    /**
     * NULL
     * 胃肠道问题
     * 1 克罗恩病
     * 2 乳糜泻
     * 3 营养不良
     * 4 胃肠疾病
     */
    private List<String> giProblem;
    /**
     * NULL
     * 曾出现健康问题
     * 1 有过妊娠糖尿病
     * 2 生产过8斤以上巨大儿
     * 3 成年后曾因轻摔后骨折
     * 4 在50 岁前切除卵巢且未补充激素
     * 5 45岁前停经
     * 6 除怀孕、绝经、子宫切除外曾停经超 12 个月
     * 7 40岁后身高减少超过3cm
     */
    private List<String> historyProblem;
    /**
     * NULL
     * 有健康问题
     * 1 维生素A缺乏
     * 2 近一年摔倒次数超过一次
     * 3 身体虚弱而担心摔倒
     * 4 心房颤动
     * 5 左心室肥厚
     * 6 皮肤或肌腱黄色瘤
     * 7 跟腱增厚
     * 8 甲状腺结节
     * 9 甲状腺肿
     */
    private List<String> haveProblem;
    /**
     * NULL
     * 直系亲属代谢性疾病
     * 1 肥胖
     * 2 2型糖尿病
     * 3 痛风
     * 4 高血脂
     * 5 脂肪肝
     * 6 甲亢
     */
    private List<String> familyMetabolismDisease;
    /**
     * NULL
     * 直系亲属呼吸系统疾病
     * 1 支气管哮喘
     * 2 慢性支气管炎
     * 3 肺气肿
     * 4 慢阻肺
     */
    private List<String> familyBreatheDisease;
    /**
     * NULL
     * 直系亲属心脑血管疾病
     * 1 高血压
     * 2 冠心病
     * 3 脑卒中
     */
    private List<String> familyAngiocarpyDisease;
    /**
     * NULL
     * 父母存在健康问题
     * 1 骨质疏松
     * 2 因摔倒骨折
     * 3 驼背
     */
    private List<String> parentsProblem;
    /**
     * NULL
     * 	接受过以下治疗
     * 1 甲状腺手术
     * 2 头颈部恶性肿瘤外放射治疗
     * 3 甲亢的放射性碘治疗
     */
    private List<String> receiveTreatment;
    /**
     * NULL
     * 连续服用以下药物超过3个月
     * 1 类固醇激素
     * 2 利尿剂
     * 3 降压药
     * 4 含碘药物如：西地碘片、乙胺碘呋酮等
     * 5 服用胺碘酮、锂制剂、酪氨酸激酶抑制剂等
     */
    private List<String> pharmacy3Month;

    /**
     * NULL 空腹血糖，单位 mmol/L，大于等于0.1，小于33
     */
    private BigDecimal fbg;

    /**
     * NULL 餐后血糖，单位 mmol/L，大于等于0.1，小于33
     */
    private BigDecimal pbg;

    /**
     * NULL 随机血糖，单位 mmol/L，大于等于0.1，小于33
     */
    private BigDecimal rbg;

    /**
     * NULL 糖化血红蛋白，单位：%，大于等于4，小于20
     */
    private BigDecimal ghb;

    /**
     * NULL 收缩压（高压），单位 mmHg，大于等于50，小于230
     */
    private Integer systolicPressure;

    /**
     * NULL 舒张压（低压），单位 mmHg，大于等于40，小于150
     */
    private Integer diastolicPressure;

    /**
     * NULL 骨密度T值，大于等于-50，小于等于50,保留1位小数，非必输
     */
    private BigDecimal bmdTscore;

    /**
     * NULL 血尿酸，单位 μmol/L，大于等于150，小于1000
     */
    private Integer ua;

    /**
     * NULL 总胆固醇，单位 mmol/L，大于等于0.01，小于等于50,保留两位小数，非必输
     */
    private BigDecimal tc;

    /**
     * NULL 甘油三酯，单位 mmol/L，大于等于.，小于50，保留两位小数，非必输
     */
    private BigDecimal tg;

    /**
     * NULL 高密度脂蛋白胆固醇，单位 mmol/L，大于等于0.01，小于10,保留两位小数，非必输
     */
    private BigDecimal hdlc;

    /**
     * NULL 低密度脂蛋白胆固醇，单位 mmol/L，大于等于0.01，小于10,保留两位小数，非必输
     */
    private BigDecimal ldlc;

    /**
     * NULL 非高密度脂蛋白胆固醇，单位 mmol/L，大于等于0，小于20,保留两位小数，非必输
     */
    private BigDecimal mdlc;

    /**
     * NULL γ-谷氨酰转移酶值，单位 U/L，大于等于5，小于300，非必输
     */
    private Integer yggt;

    /**
     * NULL 肝内脂肪含量， 单位：%，大于等于1.5，小于50，非必输
     */
    private BigDecimal liverFatContent;

    /**
     * NULL
     * 心血管系统异常症状
     * 1 心率增快
     * 2 心房颤动
     * 3 心率减慢
     * 4 脉压减少
     */
    private List<String> cardiovascularDisease;

    /**
     * NULL
     * 消化系统异常症状
     * 1 食欲亢进
     * 2 大便次数增多
     * 3 腹泻
     * 4 食欲减退
     * 5 腹胀
     * 6 便秘
     */
    private List<String> digestiveSymptoms;

    /**
     * NULL
     * 内分泌异常症状
     * 1 经量减少
     * 2 周期延长
     * 3 闭经
     * 4 月经周期紊乱
     * 5 月经量增多
     * 6 不孕
     * 7 高催乳素血症
     * 8 溢乳
     * 9 性欲减退
     * 10 乳房发育
     * 11 阳痿
     */
    private List<String> cryptorrbeaSymptoms;
    /**
     * NULL
     * 高代谢常见症状
     * 1 不明原因的体重下降
     * 2 乏力
     * 3 怕热
     * 4 低热
     * 5 多汗
     * 6 皮肤温暖、潮湿
     */
    private List<String> hypermetabolismSymptoms;
    /**
     * NULL
     * 低代谢常见症状
     * 1 畏寒
     * 2 少汗
     * 3 低温低于正常
     * 4 音调低哑
     * 5 行动迟缓
     * 6 言语缓慢
     * 7 体重增加
     * 8 乏力
     */
    private List<String> lowMetabolismSymptoms;
    /**
     * NULL
     * 异常症状
     * 1 气短
     * 2 气促
     * 3 咳痰
     * 4 皮肤干燥粗糙
     * 5 毛发干燥稀疏
     * 6 手脚掌皮肤呈姜黄色
     */
    private List<String> abnormalSymptoms;
    /**
     * NULL
     * 面部是否有以下体征
     * 1 面部浮肿
     * 2 表情呆板、淡漠
     * 3 面色苍白
     * 4 眼睑水肿
     * 5 舌体边缘有齿痕
     * 6 眉毛外1/3稀疏脱落
     * 7 胡须稀疏
     */
    private List<String> faceSymptoms;

    /**
     * NULL
     * 过去1个月出现气短的频率
     * 1 很少
     * 2 有时
     * 3 经常
     * 4 总是
     */
    private String pantFrequency;

    /**
     * NULL
     * 咳痰的频率
     * 1 偶尔只在感冒或者胸部感染时
     * 2 每月都咳几天
     * 3 大多日子都咳
     * 4 每天都咳
     */
    private String expectorationFrequency;

    /**
     * NULL
     * 过去1年因呼吸问题活动量减少情况
     * 1 从未减少
     * 2 减少
     * 3 大量减少
     */
    private String exerciseReduce;

    /**
     * NULL
     * 食物摄入超量问题
     * 1 喜好咸菜、火腿、各类炒货和腌制品
     * 2 每日摄入酱油、味精过量
     * 3 每日盐摄入多于一啤酒瓶盖
     * 4 每日至少吃一次甜品或饮料
     * 5 长期大量食用海带、紫菜
     * 6 长期大量食用卷心菜、芜菁、甘蓝、木薯
     */
    private List<String> foodExcess;

    /**
     * NULL
     * 食物摄入过量问题
     * 1 每日食用肉类或内脏至少100g
     * 2 每周至少吃一次食油炸食品
     * 3 每周至少吃一次海鲜、贝类
     * 4 每周至少喝一次浓的肉汤
     * 5 每周至少吃一次烧烤
     */
    private List<String> overeating;

    /**
     * NULL
     * 食物摄入不足问题
     * 1 蔬菜摄入少，每日低于300g
     * 2 水果摄入少，每日低于200g
     * 3 不食用乳制品、贝类
     * 4 精米白面，少粗粮
     * 5 每周豆类及制品少于50g
     */
    private List<String> foodInsufficient;
    /**
     * NULL
     * 日常生活习惯
     * 1 饮食不规律
     * 2 作息不规律
     * 3 进食过快
     * 4 常吃夜宵
     * 5 常在外就餐
     * 6 经常不吃早餐
     */
    private List<String> livingHabit;

    /**
     * NULL
     * 正在服用以下膳食补充剂
     * 1 维生素D
     * 2 钙
     * 3 B族维生素
     * 4 多种维生素、矿物质
     * 5 蛋白补充剂
     * 6 膳食纤维
     * 7 全营养补充剂
     * 8 益生菌
     */
    private List<String> dietarySupplement;

    /**
     * 运动情况
     * 1 除了工作/家务之外几乎不动
     * 2 每周运动1-2次
     * 3 每周运动3-4次
     * 4 每周运动5次以上
     */
    private String exerciseState;

    /**
     * 从事户外活动或运动时间
     * 1 ＜10分钟
     * 2 10-30分钟
     * 3 30-45分钟
     * 4 45-60分钟
     * 4 60分钟以上
     */
    private String outdoorTime;

    /**
     * 平均每天静坐时长
     * 1 小于3小时
     * 2 3-6个小时
     * 3 至少6小时
     */
    private String sitTime;

    /**
     * 饮酒情况
     * 1 平均每天> 1两酒精
     * 2 平均每天0.5-1两酒精
     * 3 平均每天< 0.5两酒精
     * 4 不喝酒
     */
    private String drinkState;

    /**
     * 每天的饮水量
     * 1 少于1000ml
     * 2 1000-1500ml
     * 3 1500-1700ml
     * 4 1700-2500ml
     * 5 2500ml以上
     */
    private String waterIntake;

    /**
     * 吸烟情况
     * 1 每周小于5支
     * 2 每周5-10支
     * 3 每周大于10支
     * 3 不抽烟但会接触二手烟
     * 4 每天不少于30支
     * 5 戒烟超过5年以上
     * 6 不抽烟也不接触二手烟
     */
    private String smokeState;

    /**
     * 睡眠问题
     * 1 入睡潜伏期超过30分钟
     * 2 夜间觉醒次数超过2次
     * 3 比期望的起床时间醒来早
     * 4 适宜时间不肯上床
     * 5 没有照顾者干预难以入睡
     * 6 经常23点以后睡觉
     * 7 睡眠时间不足6小时
     */
    private List<String> sleepState;

    /**
     * 当睡眠时间充足且睡眠环境适宜时仍存在睡眠问题
     * 1 是
     * 2 否
     */
    private String enoughSleepProblem;

    /**
     * 日间症状
     * 1 疲倦或精神萎靡
     * 2 情绪不稳、易怒
     * 3 注意力、专注力或记忆力下降
     * 4 日间瞌睡
     * 5 肢体乏力
     * 6 易犯错或者易出事故
     * 7 工作、学习、社交能力下降等
     */
    private List<String> daytimeSymptoms;

    /**
     * ***的症状至少每周出现三次
     * 1 是
     * 2 否
     */
    private String daytimeSymptomsThreeTimes;

    /**
     * ***的症状持续至少三个月
     * 1 是
     * 2 否
     */
    private String daytimeSymptomsThreeMonths;

    /**
     * 精神状态
     * 1 心理压力大紧张
     * 2 焦虑、担忧
     * 3 愤怒
     * 4 恐慌
     * 5 抑郁
     */
    private List<String> mentalState;

    /**
     * 长期居住或工作在以下环境
     * 1 接触粉尘、有毒有害化学气体、重金属颗粒等
     * 2 气候寒冷、潮湿地区以及使用燃煤、木柴取暖
     * 3 空气污染严重地区
     */
    private List<String> liveEnvironmental;

    /**
     * 受教育的年限
     * 1 ≥10年
     * 2 7-9年
     * 3 0-6年
     */
    private String education;

    // 饮食、运动
    /**
     * 民族
     * {@link com.jiankangyouyi.cloud.assessment.enums.assessmentCentre.NationEnum}
     */
    private String nation;

    /**
     * 你所在的地域
     * {@link com.jiankangyouyi.cloud.assessment.enums.assessmentCentre.AreaEnum}
     */
    private String area;

    /**
     * 你的口味
     * 1 酸
     * 2 甜
     * 3 苦
     * 4 辣
     * 5 蒜香
     * 6 咖喱
     * 7 麻
     * 8 清淡
     * 9 重口味
     */
    private List<String> taste;

    /**
     *运动能力
     * 1 高
     * 2 中
     * 3 低
     * 4 不清楚，立即评估
     */
    private String exerciseAbility;
    /**
     *上楼梯时（约五层楼高），呼吸状态自我评价感觉为
     * 1 一般
     * 2 急促
     * 3 非常急促
     */
    private String breatheStateEvaluate;
    /**
     *1分钟可以做多少个俯卧撑
     * 1 大于27个
     * 2 13-26个
     * 3 小于12个
     */
    private String pushUpNum;
    /**
     * 1分钟可以做多少个跪姿俯卧撑
     * 1 大于22个
     * 2 10-21个
     * 3 小于9个
     */
//    private String kneelingPushUpNum;

    /**
     *1分钟可以做多少个标准卷腹?(肩胛骨要离开地面)
     * 1 大于45个
     * 2 40个
     * 3 19-44个
     * 4 15-39个
     * 5 小于19个
     */
    private String crunchNum;
    /**
     *坐姿体前屈时,手指是否可以触碰到脚尖
     * 1 至少超过半个手掌
     * 2 可以碰到或刚刚超过脚尖
     * 3 碰不到脚尖
     */
    private String fingersTouchToes;
    /**
     *静蹲可以保持多长时间
     * 1 大于121秒
     * 2 大于111秒
     * 3 31-120秒
     * 4 26-110秒
     * 5 小于30秒
     * 6 小于25秒
     */
    private String quietSquatDownTime;
    /**
     *单脚站立可以保持多长时间？（平衡）
     * 1 大于1分钟
     * 2 30秒-1分钟
     * 3 小于30秒
     */
    private String standOnOneLegTime;
    /**
     * 乏力、疲倦或精神萎靡持续或反复发作的时间？
     * 1 小于1个月
     * 2 大于等于1个月
     * 3 大于等于6个月
     */
    private String weakRepetitionTime;
    /**
     * 是否现在或曾经患有以下精神心理方面的疾病？
     * 1 重度抑郁症（医生诊断后的）
     * 2 双相情感障碍
     * 3 精神分裂症
     * 4 妄想症
     * 5 痴呆症
     * 6 神经性厌食症
     * 7 神经性贪食症
     */
    private List<String> heartDisease;
    /**
     * 您近期是否常有以下不适症状？
     * 1 咽痛
     * 2 颈部或腋下淋巴结触痛
     * 3 肌肉痛
     * 4 多关节疼痛，但不伴红肿
     * 5 头痛
     * 6 运动后的疲劳持续超过24小时
     * 7 睡眠后不能恢复精力
     */
    private List<String> uncomfortableSymptoms;
    /**
     * 请勾选出持续或反复发作6个月及以上的症状？
     * 1 咽痛
     * 2 颈部或腋下淋巴结触痛
     * 3 肌肉痛
     * 4 多关节疼痛，但不伴红肿
     * 5 头痛
     * 6 运动后的疲劳持续超过24小时
     * 7 睡眠后不能恢复精力
     * 8 注意力、专注力或记忆力下降
     */
    private List<String> moreSixMonthSymptoms;
    /**
     * 	您有以下吃肉蛋类的情况吗？
     * 1 平均每月吃肥肉（含五花肉）大于2次
     * 2 平均每周吃畜肉小于2次
     * 3 平均每周吃禽肉小于2次
     * 4 平均每周吃水产类小于1次
     * 5 平均每周吃蛋类（以鸡蛋计）大于7个
     * 6 平均每周吃蛋类（以鸡蛋计）少于3个
     */
    private List<String> eatMeatEggTimes;
    /**
     * 您有下列饮食习惯吗？
     * 1 常吃加工食品
     * 2 进食深色蔬菜占总蔬菜比例小于1/2
     * 3 进食深色水果占总水果比例小于1/2
     * 4 平均每周吃坚果少于2次
     * 5 有吃亚麻籽油、紫苏子油
     * 6 食用无碘盐
     */
    private List<String> dietaryHabit;
    /**
     * 您是否有以下味觉、口、齿、舌相关症状？
     * 1 舌深红
     * 2 牙龈出血/2
     * 3 味觉减退/2
     * 4 口角裂/嘴唇干裂
     */
    private List<String> mouthSymptoms;
    /**
     * 您是否有以下眼、甲、皮肤相关症状？
     * 1 舟状甲/指甲脆薄
     * 2 皮肤有瘀斑/2
     * 3 眼干/2
     * 4 暗适应能力下降/夜盲症
     * 5 眼痒
     */
    private List<String> eyeNailSkinSymptoms;
    /**
     * 您是否有以下饮用习惯？
     * 1 常喝咖啡（平均每天超过3杯）
     * 2 常喝浓茶/2
     * 3 常喝碳酸饮料/2
     * 4 常喝纯净水
     */
    private List<String> drinkHabit;
    /**
     * 您家是否有以下烹饪习惯？
     * 1 做饭淘米超过2次
     * 2 烹调中(如：做粥时）加碱/2
     * 3 菠菜、冬笋等不焯水直接炒
     */
    private List<String> cookingHabit;

    /**
     * 你是否曾听医务人员说你只能在医务监督（有专业人士监督或仪器检测）下进行体力活动？
     * 1 是
     * 2 否
     */
    private String physicalActivity;
    /**
     * 生活中或运动时是否出现过胸痛？
     * 1 是
     * 2 否
     */
    private String chestPain;
    /**
     * 在过去1年中，有无出现过因头晕而失去平衡或失去知觉？
     * 1 是
     * 2 否
     * 3 因为高强度运动或过度通气导致的
     */
    private String lossOfBalance;
    /**
     * 目前或过去1年内，是否出现过运动中使骨骼、关节或软组织（肌肉、韧带或肌腱）恶化的问题？
     * 1 是
     * 2 否
     * 3 过去有，但不影响进行运动
     */
    private String bodyWorsen;
    /**
     * 您的疼痛程度为？
     * 1 无痛
     * 2 轻度疼痛（能忍受，能正常生活睡眠）
     * 3 中度疼痛（适当影响睡眠，需止痛药）
     * 4 重度疼痛（影响睡眠，需用麻醉止痛药）
     * 5 剧烈疼痛（影响睡眠较重，伴有其他症状）
     * 6 无法忍受（严重影响睡眠，伴有其他症状）
     */
    private String painDegree;
    /**
     * 在过去1年内，您是否存在以下由疼痛引起的关节问题？
     * 1 颈部关节及周围存在疼痛
     * 2 腰部关节及周围存在疼痛
     * 3 臀部关节及周围存在疼痛
     * 4 膝关节及周围存在疼痛
     * 5 踝关节及周围存在疼痛
     * 6 肩部关节及周围存在疼痛
     * 7 肘部关节及周围存在疼痛
     * 8 胸部关节及周围存在疼痛
     * 9 其他部位
     */
    private List<String> painInTheJoints;

    //v1.2

    /**
     * 您是否目前未患有任何疾病？（有未确诊的不适症状，在此不算病）
     * 1 是
     * 2 否
     */
    private String noDisease;

    /**
     * 您是否有以下消化系统问题？
     * 1 功能性胃肠病
     * 2 嗳气疾病
     * 3 功能性消化不良
     * 4 肠易激综合征
     * 5 功能性便秘
     * 6 功能性腹泻
     * 7 幽门螺杆菌感染
     * 8 无
     */
    private List<String> digestiveSystem;

    /**
     * 您是否患有以下妇科疾病？
     * 1 卵巢癌
     * 2 子宫内膜异位症
     * 3 无
     */
    private List<String> gynaeDisease;

    /**
     * 	您是否近期常有以下异常症状？
     * 1 嗳气
     * 2 上腹烧灼感
     * 3 腹痛
     * 4 无
     */
    private List<String> fgidAbnormalSymptoms;

    /**
     * 请勾选出以下持续至少6个月的症状？
     * 1 腹泻
     * 2 腹胀
     * 3 便秘
     * 4 嗳气
     * 5 上腹烧灼感
     * 6 腹痛
     * 7 无
     */
    private List<String> fgidMoreSixMonthSymptoms;

    /**
     * 您是否有以下健康问题？
     * 1 反复感冒
     * 2 伤口容易感染
     * 3 伤口愈合时间较正常长
     * 4 身体不同部位易长细小疖肿
     * 5 易感染传染病（如：感冒）
     * 6 有过敏的问题
     * 7 无
     */
    private List<String> immunityHealthProblem;

    /**
     * 您是否处于产后1年内？
     * 1 是
     * 2 否
     */
    private String postnatalOneYear;

    /**
     * 您的分娩日期是？
     */
    private String postnatalTime;

    /**
     * 您是否处于哺乳状态？
     * 1 是
     * 2 否
     */
    private String lactation;

    /**
     * 当前心率
     */
    private Double hr;

    /**
     * 当前心率变异性
     */
    private Double hrvChange;

    /**
     * 呼吸值（呼吸频率）
     */
    private Double brFace;

    /**
     * 血氧
     */
    private Integer bloodOxygen;

    /**
     * 年龄段 0（未检测出） 1（青少年） 2（青年） 3（中青年） 4（中年） 5（老年）
     */
    private String ageGroup;

    /**
     * 生理年龄(0~100)
     * （机能年龄）
     */
    private Integer phyAge;

    /**
     * 生理状态（精神状态）0 - 正常，1 - 焦虑， 2生理疲劳（运动性），3 - 昏昏欲睡。
     */
    private String instantStatus;

    /**
     * 长期压力指数(0~100)
     */
    private Double pressureIndex;

    /**
     * 恢复指数(0~100)
     */
    private Double resilentIndex;

    /**
     * 机能活性度 (0~2)
     */
    private Double activeLevel;

    /**
     * 心血管风险指数 (0~100)
     */
    private Double cardiovascularRisk;

    /**
     * 表情   0生气   1厌恶  2恐惧   3高兴   4伤心   5惊讶   6平静 （无人脸的情况下默认返回0 这个值不做参考）
     */
    private String emotion;


}
