package com.jiankangyouyi.cloud.assessment.model.param;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.jiankangyouyi.cloud.data.center.api.enums.Type2DiabetesPharmacyEnum;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.math.BigDecimal;
import java.util.List;

/**
 * 饮食干预中心测评参数 bizType = 020501
 *
 * @author fengxuanjun
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@JsonInclude(value= JsonInclude.Include.NON_NULL)
public class Assessment020501Params implements AssessmentParams {
    private static final long serialVersionUID = 1L;


    /**
     * NOT NULL 出生日期，格式为yyyy-MM-dd,年龄（周岁）大于等于18岁，小于等于100岁
     */
    private String birthday;

    /**
     * NOT NULL 性别， 1 男 2 女
     */
    private String gender;

    /**
     * NOT NULL，身高，单位 cm,大于等于100，小于230
     */
    private BigDecimal height;

    /**
     * NOT NULL，单位 kg，保留1位小数，大于等于25，小于200
     */
    private BigDecimal weight;

    /**
     * NULL
     * 体力劳动的强度
     * 1 长时间久坐如银行、办公室职员
     * 2 体力活动一般如老师、学生
     * 3 体力活动较多如服务员
     * 4 体力活动为主如搬运工
     */
    private String activityLevel;

    /**
     * 民族
     * {@link com.jiankangyouyi.cloud.assessment.enums.assessmentCentre.NationEnum}
     */
    private String nation;

    /**
     * 你所在的地域
     * {@link com.jiankangyouyi.cloud.assessment.enums.assessmentCentre.AreaEnum}
     */
    private String area;

    /**
     * 你的口味
     * 1 酸
     * 2 甜
     * 3 苦
     * 4 辣
     * 5 蒜香
     * 6 咖喱
     * 7 麻
     * 8 清淡
     * 9 重口味
     */
    private List<String> taste;

    /**
     * 您是否处于产后1年内？
     * 1 是
     * 2 否
     */
    private String postnatalOneYear;

    /**
     * 您的分娩日期是？
     */
    private String postnatalTime;

    /**
     * 您是否处于哺乳状态？
     * 1 是
     * 2 否
     */
    private String lactation;

    /**
     * 糖尿病用药情况
     * {@link Type2DiabetesPharmacyEnum}
     */
    private String type2DiabetesPharmacy;

    /**
     * 过敏原禁忌标签 {@link com.jiankangyouyi.cloud.data.center.api.enums.AllergenTabooTagEnum}
     */
    private List<String> allergenTabooTags;

}
