package com.jiankangyouyi.cloud.assessment.model.param;

import com.fasterxml.jackson.annotation.JsonInclude;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.math.BigDecimal;
import java.util.List;

/**
 * 运动干预中心测评参数 bizType = 032501
 *
 * @author fengxuanjun
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@JsonInclude(value= JsonInclude.Include.NON_NULL)
public class Assessment032501Params implements AssessmentParams {
    private static final long serialVersionUID = 1L;


    /**
     * NOT NULL 出生日期，格式为yyyy-MM-dd,年龄（周岁）大于等于18岁，小于等于100岁
     */
    private String birthday;

    /**
     * NOT NULL 性别， 1 男 2 女
     */
    private String gender;

    /**
     * NOT NULL，身高，单位 cm,大于等于100，小于230
     */
    private BigDecimal height;

    /**
     * NOT NULL，单位 kg，保留1位小数，大于等于25，小于200
     */
    private BigDecimal weight;

    /**
     * NULL
     * 过去半年中每周的运动情况是
     * 1 长时间久坐如银行、办公室职员
     * 2 体力活动一般如老师、学生
     * 3 体力活动较多如服务员
     * 4 体力活动为主如搬运工
     */
    private String exerciseState;

    /**
     *运动能力
     * 1 高
     * 2 中
     * 3 低
     * 4 不清楚，立即评估
     */
    private String exerciseAbility;


    /**
     *上楼梯时（约五层楼高），呼吸状态自我评价感觉为
     * 1 一般
     * 2 急促
     * 3 非常急促
     */
    private String breatheStateEvaluate;
    /**
     * 男
     * 1分钟可以做多少个俯卧撑
     * 1 大于26个
     * 2 13-26个
     * 3 小于13个
     *
     *  女
     * 1分钟可以做多少个跪姿俯卧撑
     * 1 大于21个
     * 2 10-21个
     * 3 小于10个
     */
    private String pushUpNum;

    /**
     *1分钟可以做多少个标准卷腹?(肩胛骨要离开地面)
     * 1 大于44个
     * 2 大于39个
     * 3 19-44个
     * 4 15-39个
     * 5 小于19个
     * 6 小于15个
     */
    private String crunchNum;
    /**
     *坐姿体前屈时,手指是否可以触碰到脚尖
     * 1 指尖超过脚尖
     * 2 手腕超过脚尖
     * 3 指尖可以碰到脚尖
     * 4 手腕可以触碰脚尖
     * 5 指尖碰不到脚尖
     * 6 手腕不能触碰脚尖
     */
    private String fingersTouchToes;
    /**
     *静蹲可以保持多长时间
     * 1 大于120秒
     * 2 大于110秒
     * 3 30-120秒
     * 4 25-110秒
     * 5 小于30秒
     * 6 小于25秒
     */
    private String quietSquatDownTime;
    /**
     * 单脚站立可以保持多长时间？（平衡）
     * 1 大于120秒
     * 2 30秒-60秒
     * 3 小于30秒
     */
    private String standOnOneLegTime;
    /**
     * 您的分娩日期是？
     */
    private String postnatalTime;

    /**
     * 医生建议过你需要在医疗监护下进行锻炼吗？
     * 1 是
     * 2 否
     */
    private String physicalActivity;
    /**
     * 生活中或运动时是否出现过胸痛？
     * 1 是
     * 2 否
     */
    private String chestPain;
    /**
     * 在过去1年中，有无出现过因头晕而失去平衡或失去知觉？
     * 1 是
     * 2 否
     * 3 因为高强度运动或过度通气导致的
     */
    private String lossOfBalance;
    /**
     * 目前或过去1年内，是否出现过运动中使骨骼、关节或软组织（肌肉、韧带或肌腱）恶化的问题？
     * 1 是
     * 2 否
     * 3 过去有，但不影响进行运动
     */
    private String bodyWorsen;
    /**
     * 在过去1年内，您是否存在以下由疼痛引起的关节问题？
     * 1 颈部关节及周围存在疼痛
     * 2 腰部关节及周围存在疼痛
     * 3 臀部关节及周围存在疼痛
     * 4 膝关节及周围存在疼痛
     * 5 踝关节及周围存在疼痛
     * 6 肩部关节及周围存在疼痛
     * 7 肘部关节及周围存在疼痛
     * 8 胸部关节及周围存在疼痛
     * 9 其他部位存在疼痛
     * 10 无痛
     */
    private List<String> painInTheJoints;
    /**
     * 您的疼痛程度为？
     * 1 轻度疼痛（能忍受，能正常生活睡眠）
     * 2 中度疼痛（适当影响睡眠，需止痛药）
     * 3 重度疼痛（影响睡眠，需用麻醉止痛药）
     * 4 剧烈疼痛（影响睡眠较重，伴有其他症状）
     * 5 无法忍受（严重影响睡眠，伴有其他症状）
     */
    private String painDegree;

    /**
     * 是否有其它理由使你不应进行运动？
     * 1 是
     * 2 否
     */
    private String otherReasonDoNotExercise;





}
