package com.jiankangyouyi.cloud.assessment.model.param;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.math.BigDecimal;
import java.util.List;

/**
 * 生活方式测评参数 bizType = 190101
 *
 * @author fengxuanjun
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@JsonInclude(value = JsonInclude.Include.NON_NULL)
public class Assessment190101ParamsV3 implements AssessmentParams {
    private static final long serialVersionUID = 1L;

    /**
     * NOT NULL 出生日期，格式为yyyy-MM-dd,年龄（周岁）大于等于18岁，小于等于100岁
     */
    private String birthday;

    /**
     * NOT NULL 性别， 1 男 2 女
     */
    private String gender;

    /**
     * NOT NULL，身高，单位 cm,大于等于100，小于230
     */
    private BigDecimal height;

    /**
     * NOT NULL，单位 kg，保留1位小数，大于等于25，小于200
     */
    private BigDecimal weight;


    /**
     * NULL 腰围，单位 cm，大于等于50，小于200
     */
    private Integer waistline;

    /**
     * 你的吸烟情况？
     * 1 每周小于5支
     * 2 每周5-10支
     * 3 每周大于10支
     * 4 不抽烟但会接触二手烟
     * 5 每天不少于30支
     * 6 戒烟超过5年以上
     * 7 不抽烟也不接触二手烟
     */
    private String smokeState;

    /**
     * NULL
     * 你是否有以下食物摄入超量问题？
     * 1 喜好咸菜、火腿、各类炒货和腌制品
     * 2 饭菜放酱油、味精较多
     * 3 吃的食物比较咸
     * 4 每周3次以上吃甜品或含糖饮料
     * 5 长期大量食用海带、紫菜
     * 6 长期大量食用卷心菜、芜菁、甘蓝、木薯
     * 7 无
     */
    private List<String> foodExcess;
    /**
     * NULL
     * 你是否有以下饮食习惯？
     * 1 常吃内脏（平均每月大于2次）
     * 2 每周至少吃一次油炸食品
     * 3 每周至少吃三次海鲜、贝类
     * 4 每周至少喝一次浓的肉汤
     * 5 每周至少吃一次烧烤
     * 6 无
     */
    private List<String> overeating;

    /**
     * NULL
     * 你是否有以下食物摄入不足问题？
     * 1 蔬菜摄入少，平均每日低于300g
     * 2 水果摄入少，平均每日低于200g
     * 3 平均每周吃乳类及其制品少于3次
     * 4 平均每周吃粗粮少于3次
     * 5 平均每周吃大豆及其制品少于3次
     */
    private List<String> foodInsufficient;

    /**
     * 你有以下吃肉蛋类的情况吗？
     * 1 平均每月吃肥肉（含五花肉）大于2次
     * 2 平均每周吃畜肉小于2次
     * 3 平均每周吃禽肉小于2次
     * 4 平均每周吃水产类小于1次
     * 5 平均每周吃蛋类（以鸡蛋计）大于7个
     * 6 平均每周吃蛋类（以鸡蛋计）少于3个
     * 7 无
     */
    private List<String> eatMeatEggTimes;

    /**
     * 你的畜肉（如猪、牛、羊等的肌肉和内脏）摄入量情况？
     * 1 平均每周525克，或每日75克以上
     * 2 平均每周280-525克，或每日40~75克
     * 3 平均每周280克，或每日40克以下
     */
    private String livestockMeatIntakeState;

    /**
     * 你有下列饮食习惯吗？
     * 1 常吃加工食品
     * 2 进食深色蔬菜占总蔬菜比例小于1/2
     * 3 进食深色水果占总水果比例小于1/2
     * 4 平均每周吃坚果少于2次
     * 5 有吃亚麻籽油、紫苏子油
     * 6 食用无碘盐
     * 7 无
     */
    private List<String> dietaryHabit;

    /**
     * NULL
     * 你是否喜爱吃高热量零食，如薯片、含糖饮料、酥脆点心、辣条等？
     * 1 是，每周3次以上
     * 2 是，很少吃
     * 3 不喜欢吃
     */
    private String likeEatSnacks;
    /**
     * NULL
     * 你每餐是否习惯吃十分饱或吃撑？
     * 1 是
     * 2 否
     */
    private String eatFullEveryMeal;

    /**
     * NULL
     * 日常生活习惯
     * 1 饮食不规律
     * 2 作息不规律
     * 3 进食过快
     * 4 常吃夜宵
     * 5 常在外就餐
     * 6 经常不吃早餐
     * 7 以上全无
     */
    private List<String> livingHabit;

    /**
     * NULL
     * 你是否长期存在以下问题？
     * 1 节食不当
     * 2 暴饮暴食
     * 3 情绪化进食
     * 4 以上全无
     */
    private List<String> longTimeProblems;


    /**
     * NULL
     * 过去半年中每周的运动情况是
     * 1 长时间久坐如银行、办公室职员
     * 2 体力活动一般如老师、学生
     * 3 体力活动较多如服务员
     * 4 体力活动为主如搬运工
     */
    private String exerciseState;


    /**
     * 你近期平均每天静坐时长？
     * 1 小于3小时
     * 2 3-8个小时
     * 3 至少8小时
     */
    private String sitTime;

    /**
     * 每天从事户外活动或运动时间？
     * 1 ＜10分钟
     * 2 10-30分钟
     * 3 30-45分钟
     * 4 45-60分钟
     * 5 60分钟以上
     */
    private String outdoorTime;

    /**
     * NULL
     * 你是否饮酒？
     * 1 平均每天>1两酒精
     * 2 平均每天0.5-1两酒精
     * 3 平均每天<0.5两酒精
     * 4 不喝酒
     */
    private String drink;


    /**
     * 你是否有以下睡眠问题需要解决？
     * 1 入睡潜伏期超过30分钟
     * 2 夜间觉醒次数超过2次
     * 3 比期望的起床时间醒来早
     * 4 适宜时间不肯上床
     * 5 没有照顾者干预难以入睡
     * 6 经常23点以后睡觉
     * 7 睡眠时间不足6小时
     * 8 无
     */
    private List<String> sleepProblem;

    /**
     * 你的睡眠环境或睡眠习惯是否存在以下情况？
     * 1 睡眠环境不佳或突然改变
     * 2 喜欢趴着睡
     * 3 呆在床上的时间较多
     * 4 睡前吸烟，喝咖啡、浓茶等
     * 5 睡眠时间不规律
     * 6 无
     */
    private List<String> sleepEnvironmentOrHabits;
    /**
     * 是否了解肥胖的危害？
     * 1 是
     * 2 否
     */
    private String understandTheDangersOfObesity;

    /**
     * 你是否长期存在以下精神状态？
     * 1 心理压力大紧张
     * 2 焦虑、担忧
     * 3 愤怒
     * 4 恐慌
     * 5 抑郁
     * 6 无
     */
    private List<String> mentalState;

    /**
     * 你是否了解并接受糖尿病自我管理与教育呢？
     * 1 积极的态度控制血糖
     * 2 丰富的糖尿病知识
     * 3 较好的糖尿病自我管理行为
     * 4 有战胜疾病的信心
     * 5 无
     */
    private List<String> diabetesRegulate;

    /**
     * 你每天的饮水量？
     * 1 少于1000ml
     * 2 1000-1500ml
     * 3 1500-1700ml
     * 4 1700-2500ml
     * 5 2500ml以上
     */
    private String waterIntake;

    /**
     * 你是否知晓并关注血尿酸水平的影响？
     * 1 不知道
     * 2 了解一点，不关注血尿酸水平的影响
     * 3 了解一点，关注血尿酸水平的影响
     * 4 完全知晓并关注血尿酸水平的影响
     */
    private String realizeUa;

    /**
     * 你是否有以下饮用习惯？
     * 1 常喝咖啡（平均每天超过3杯）
     * 2 常喝浓茶/2
     * 3 常喝碳酸饮料/2
     * 4 常喝纯净水
     * 5 常喝果味或果汁饮料（富含果葡糖浆）
     * 6 无
     */
    private List<String> drinkHabit;

    /**
     * 你是否患有糖尿病并发症？
     * 1 糖尿病肾病
     * 2 糖尿病视网膜病变
     * 3 糖尿病神经病变
     * 4 糖尿病下肢动脉病变
     * 5 糖尿病足病
     * 6 无
     */
    private List<String> diabetesComplication;

    /**
     * 你近14天内是否出现过低血糖症状？
     * 1 心悸
     * 2 焦虑
     * 3 出汗
     * 4 头晕
     * 5 手抖
     * 6 饥饿感
     * 7 其他
     * 8 无
     */
    private List<String> hypoglycemiaSymptoms;

    /**
     * 你的空腹血糖值？
     */
    private BigDecimal fbg;

    /**
     * 餐后2小时血糖
     */
    private BigDecimal pbg;

    /**
     * NULL 收缩压（高压），单位 mmHg，大于等于50，小于等于230
     */
    private Integer systolicPressure;

    /**
     * NULL 舒张压（低压），单位 mmHg，大于等于30，小于等于150
     */
    private Integer diastolicPressure;

    /**
     * 医生建议过你需要在医疗监护下进行锻炼吗？
     * 1 是
     * 2 否
     */
    private String physicalActivity;

    /**
     * 你的分娩日期是？yyyy-MM-dd格式日期
     */
    private String postnatalTime;

    /**
     * 你是否处于哺乳状态？
     * 1 是
     * 2 否
     */
    private String lactation;
    /**
     * 你是否长期居住或工作在以下环境？
     * 1 接触粉尘、有毒有害化学气体、重金属颗粒等
     * 2 目前使用煤炉或柴草烹饪或取暖
     * 3 空气污染严重地区
     * 4 无
     */
    private List<String> questionLiveEnvironmental;

    /**
     * 你是否常有意识地进行呼吸锻炼，如缩唇呼吸、腹式呼吸等？
     * 1 是
     * 2 否
     */
    private String breathingExercise;

    /**
     * 你是否常参加社会活动，如参加生日聚会、集体旅游度假等？
     * 1 是
     * 2 否
     */
    private String participateSocialActivities;
    /**
     * NOT NULL 生活方式标签
     */
    @JsonIgnore
    private List<String> lifeStyleLabels;


}
