package com.jiankangyouyi.cloud.assessment.model.param;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.jiankangyouyi.cloud.core.validator.ValidDTO;
import com.jiankangyouyi.cloud.core.validator.annotation.MaxHC;
import com.jiankangyouyi.cloud.core.validator.annotation.MinHC;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.List;

/**
 * 效果评估测评参数 bizType = 200101
 *
 * @author fengxuanjun
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@JsonInclude(value= JsonInclude.Include.NON_NULL)
public class Assessment200101Params implements AssessmentParams, ValidDTO {
    private static final long serialVersionUID = 1L;

    /**
     * NOT NULL 出生日期，格式为yyyy-MM-dd,年龄（周岁）大于等于18岁，小于等于100岁
     */
    private String birthday;

    /**
     * NOT NULL 性别， 1 男 2 女
     */
    private String gender;

    /**
     * NOT NULL，身高，单位 cm,大于等于100，小于230
     */
    @NotNull(message = "请求参数height不能为空")
    @MinHC(value = 100, message = "请求参数height不在合法范围[100,230]内")
    @MaxHC(value = 230, message = "请求参数height不在合法范围[100,230]内")
    private BigDecimal height;

    /**
     * NOT NULL，单位 kg，保留1位小数，大于等于25，小于200
     */
    @NotNull(message = "请求参数weight不能为空")
    @MinHC(value = 25, message = "请求参数weight不在合法范围[25,200]内")
    @MaxHC(value = 200, message = "请求参数weight不在合法范围[25,200]内")
    private BigDecimal weight;

    /**
     * NULL 腰围，单位 cm，大于等于50，小于200
     */
    @MinHC(value = 50, message = "请求参数waistline不在合法范围[50,200]内")
    @MaxHC(value = 200, message = "请求参数waistline不在合法范围[50,200]内")
    private Integer waistline;

    /**
     * 空腹血糖 监测方法：血浆，单位 mmol/L，[1-33]
     */
    @MinHC(value = 1, message = "请求参数fbg不在合法范围[1,33]内")
    @MaxHC(value = 33, message = "请求参数fbg不在合法范围[1,33]内")
    private BigDecimal fbg;

    /**
     * NULL 收缩压（高压），单位 mmHg，大于等于50，小于等于230
     */
    @MinHC(value = 50, message = "请求参数systolicPressure不在合法范围[50,230]内")
    @MaxHC(value = 230, message = "请求参数systolicPressure不在合法范围[50,230]内")
    private Integer systolicPressure;

    /**
     * NULL 舒张压（低压），单位 mmHg，大于等于30，小于等于150
     */
    @MinHC(value = 30, message = "请求参数diastolicPressure不在合法范围[30,150]内")
    @MaxHC(value = 150, message = "请求参数diastolicPressure不在合法范围[30,150]内")
    private Integer diastolicPressure;

    /**
     * NULL 骨密度T值，大于等于-6，小于等于3
     */
    @MinHC(value = -6, message = "请求参数bmdTscore不在合法范围[-6,3]内")
    @MaxHC(value = 3, message = "请求参数bmdTscore不在合法范围[-6,3]内")
    private BigDecimal bmdTscore;

    /**
     * NULL 血尿酸，单位 μmol/L，大于等于150，小于1000
     */
    @MinHC(value = 150, message = "请求参数ua不在合法范围[150,1000]内")
    @MaxHC(value =1000, message = "请求参数ua不在合法范围[150,1000]内")
    private Integer ua;

    /**
     * NULL 总胆固醇，单位 mmol/L，大于等于0.01，小于等于50
     */
    @MinHC(value = 0.01, message = "请求参数tc不在合法范围[0.01,50]内")
    @MaxHC(value = 50, message = "请求参数tc不在合法范围[0.01,50]内")
    private BigDecimal tc;

    /**
     * NULL 肝内脂肪含量， 单位：%，大于等于1，小于等于50
     */
    @MinHC(value = 1,message = "请求参数liverFatContent不在合法范围[1,50]内")
    @MaxHC(value = 50,message = "请求参数liverFatContent不在合法范围[1,50]内")
    private BigDecimal liverFatContent;

    /**
     * 你是否处于产后1年内？
     * 1 是
     * 2 否
     */
    private String postnatalOneYear;

    /**
     * 你的分娩日期是？yyyy-MM-dd格式日期
     */
    private String postnatalTime;

    /**
     * 你是否处于哺乳状态？
     * 1 是
     * 2 否
     */
    private String lactation;

    /**
     * 你是否饮酒？
     * 1 平均每天> 1两酒精
     * 2 平均每天0.5-1两酒精
     * 3 平均每天< 0.5两酒精
     * 4 不喝酒
     */
    private String drinkState;

    /**
     * NULL
     * 你是否近期有心血管系统异常症状？
     * 1 心率增快
     * 2 心悸
     * 3 心率减慢
     * 4 脉压减少
     * 5 无
     */
    private List<String> cardiovascularDisease;

    /**
     * NULL
     * 你是否近期常有消化系统异常症状？
     * 1 食欲亢进
     * 2 大便次数增多
     * 3 腹泻
     * 4 食欲减退
     * 5 腹胀
     * 6 便秘
     * 7 无
     */
    private List<String> digestiveSymptoms;

    /**
     * NULL
     * 你是否近期有内分泌异常症状？
     * 1 性欲减退
     * 2 阳痿
     * 3 无
     */
    private List<String> cryptorrbeaSymptoms;
    /**
     * NULL
     * 你是否近期有以下高代谢常见症状？
     * 1 不明原因的体重下降
     * 2 乏力
     * 3 怕热
     * 4 低热
     * 5 多汗
     * 6 皮肤温暖、潮湿
     * 7 无
     */
    private List<String> hypermetabolismSymptoms;
    /**
     * NULL
     * 	你是否近期有以下低代谢常见症状？
     * 1 畏寒
     * 2 少汗
     * 3 低温低于正常
     * 4 音调低哑
     * 5 行动迟缓
     * 6 言语缓慢
     * 7 体重增加
     * 8 乏力
     * 9 无
     */
    private List<String> lowMetabolismSymptoms;

    /**
     * NULL
     * 	你是否近期存在以下异常症状？
     * 1 气促
     * 2 咳痰
     * 3 皮肤干燥粗糙
     * 4 毛发干燥稀疏、脱发
     * 5 手脚掌皮肤呈姜黄色
     * 6 无
     */
    private List<String> abnormalSymptoms;

    /**
     * NULL
     * 你的面部是否近期有以下体征？
     * 1 面部浮肿
     * 2 表情呆板、淡漠
     * 3 面色苍白
     * 4 眼睑水肿
     * 5 舌体边缘有齿痕
     * 6 眉毛外1/3稀疏脱落
     * 7 胡须稀疏
     * 8 无
     */
    private List<String> faceSymptoms;

    /**
     * 	你是否有以下日间症状？
     * 1 疲倦或精神萎靡
     * 2 情绪不稳或易激惹
     * 3 注意力、专注力或记忆力下降
     * 4 日间瞌睡
     * 5 易犯错或者易出事故
     * 6 工作、学习、社交能力下降等
     * 7 无
     */
    private List<String> daytimeSymptoms;

    /**
     * 你是否有以下味觉、口、齿、舌相关症状？
     * 1 舌深红
     * 2 牙龈出血/2
     * 3 味觉减退/2
     * 4 口角裂/嘴唇干裂
     * 5 无
     */
    private List<String> mouthSymptoms;
    /**
     * 你是否有以下眼、甲、皮肤相关症状？
     * 1 舟状甲/指甲脆薄
     * 2 皮肤有瘀斑/2
     * 3 眼干/2
     * 4 暗适应能力下降/夜盲症
     * 5 眼痒
     * 6 无
     */
    private List<String> eyeNailSkinSymptoms;

    /**
     * 你是否近期常有以下异常症状？
     * 1 嗳气
     * 2 上腹烧灼感
     * 3 腹痛
     * 4 无
     */
    private List<String> fgidAbnormalSymptoms;

    /**
     * NULL
     * 你是否有以下食物摄入超量问题？
     * 1 喜好咸菜、火腿、各类炒货和腌制品
     * 2 每日摄入酱油、味精过量
     * 3 每日盐摄入多于一啤酒瓶盖
     * 4 每日至少吃一次甜品或饮料
     * 5 长期大量食用海带、紫菜
     * 6 长期大量食用卷心菜、芜菁、甘蓝、木薯
     * 7 无
     */
    private List<String> foodExcess;

    /**
     * NULL
     * 你是否有以下饮食习惯？（食物摄入过量问题）
     * 1 常吃内脏（平均每月大于2次）
     * 2 每周至少吃一次食油炸食品
     * 3 每周至少吃一次海鲜、贝类
     * 4 每周至少喝一次浓的肉汤
     * 5 每周至少吃一次烧烤
     * 6 无
     */
    private List<String> overeating;

    /**
     * NULL
     * 你是否有以下食物摄入不足问题？
     * 1 蔬菜摄入少，每日低于300g
     * 2 水果摄入少，每日低于200g
     * 3 不食用乳制品、贝类
     * 4 精米白面，少粗粮
     * 5 每周豆类及制品少于50g
     * 6 无
     */
    private List<String> foodInsufficient;

    /**
     * 过去半年中每周的运动情况是？
     * 1 除了工作/家务之外几乎不动
     * 2 每周运动1-2天
     * 3 每周运动3-4天
     * 4 每周运动5天以上
     */
    private String exerciseState;

    /**
     * 每天从事户外活动或运动时间？
     * 1 ＜10分钟
     * 2 10-30分钟
     * 3 30-45分钟
     * 4 45-60分钟
     * 5 60分钟以上
     */
    private String outdoorTime;

    /**
     * 	平均每天静坐时长
     * 1 小于3小时
     * 2 3-8个小时
     * 3 至少8小时
     */
    private String sitTime;

    /**
     * 	你每天的饮水量？
     * 1 少于1000ml
     * 2 1000-1500ml
     * 3 1500-1700ml
     * 4 1700-2500ml
     * 5 2500ml以上
     */
    private String waterIntake;

    /**
     * 你的吸烟情况？
     * 1 每周小于5支
     * 2 每周5-10支
     * 3 每周大于10支
     * 4 不抽烟但会接触二手烟
     * 5 每天不少于30支
     * 6 戒烟超过5年以上
     * 7 不抽烟也不接触二手烟
     */
    private String smokeState;

    /**
     * 	你是否长期存在以下精神状态？
     * 1 心理压力大紧张
     * 2 焦虑、担忧
     * 3 愤怒
     * 4 恐慌
     * 5 抑郁
     * 6 无
     */
    private List<String> mentalState;


}
