package com.jiankangyouyi.cloud.assessment.model.param;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.jiankangyouyi.cloud.core.validator.annotation.MaxHC;
import com.jiankangyouyi.cloud.core.validator.annotation.MinHC;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.math.BigDecimal;
import java.util.List;

/**
 * 健康评估中心测评参数V3 bizType = 012502
 *
 * @author fengxuanjun
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@JsonInclude(value= JsonInclude.Include.NON_NULL)
public class AssessmentReportParams implements AssessmentParams {
    private static final long serialVersionUID = 1L;


    /**
     * NOT NULL 出生日期，格式为yyyy-MM-dd,年龄（周岁）大于等于18岁，小于等于100岁
     */
    private String birthday;

    /**
     * NOT NULL 性别， 1 男 2 女
     */
    private String gender;

    /**
     * NOT NULL，身高，单位 cm,大于等于100，小于230
     */
    private BigDecimal height;

    /**
     * NOT NULL，单位 kg，保留1位小数，大于等于25，小于200
     */
    private BigDecimal weight;

    /**
     * NULL 腰围，单位 cm，大于等于50，小于200
     */
    private Integer waistline;

    /**
     * NULL 体脂率，单位 %，大于等于0，50
     */
    private Integer bfr;

    /**
     * NULL
     * 体力劳动的强度
     * 1 休息，主要是坐着或躺着
     * 2 坐位工作，几乎无走动，如：办公室职员
     * 3 坐位工作，有时需走动或站立，很少有重体力活动，如：学生
     * 4 主要是站着或走着工作，如：服务员
     * 5 重体力职业工作，如：建筑工人、农民或运动员
     */
    private String activityLevel;

    /**
     * 你目前是否未患有任何疾病？（有未确诊的不适症状，在此不算病）
     * 1 是
     * 2 否
     */
    private String noDisease;

    /**
     * NULL
     * 你目前是否患有以下代谢性疾病?
     * 1 2型糖尿病
     * 2 高血脂
     * 3 高尿酸血症
     * 4 痛风
     * 5 脂肪肝
     * 6 多囊卵巢综合征
     * 7 甲减
     * 8 甲亢
     * 9 无
     */
    private List<String> metabolicDisease;

    /**
     * NULL
     * 你目前是否患有以下心脑血管疾病？
     * 1 高血压
     * 2 冠心病
     * 3 脑卒中
     * 4 缺血性心肌病
     * 5 外周动脉粥样硬化
     * 6 无
     */
    private List<String> angiocarpyDisease;

    /**
     * NULL
     * 你目前是否患有以下自身免疫系统疾病？
     * 1 硬皮症
     * 2 类风湿关节炎
     * 3 1型糖尿病
     * 4 无
     */
    private List<String> immuneSystem;

    /**
     * NULL
     * 你目前是否患有以下慢性疾病?
     * 1 慢性肾脏病3/4期
     * 2 骨质疏松
     * 3 慢性疲劳综合征
     * 4 慢性失眠症
     * 5 慢阻肺
     * 6 睡眠呼吸暂停综合征
     * 7 无
     */
    private List<String> chronicDisease;

    /**
     * NULL
     * 你目前是否有以下胃肠道问题？
     * 1 克罗恩病
     * 2 乳糜泻
     * 3 吸收不良综合征
     * 4 其他胃肠疾病
     * 5 无
     */
    private List<String> giProblem;

    /**
     * 你目前是否患有以下妇科疾病？
     * 1 卵巢癌
     * 2 子宫内膜异位症
     * 3 无
     */
    private List<String> gynaeDisease;

    /**
     * 你目前是否有以下消化系统问题？
     * 1 功能性胃肠病
     * 2 嗳气疾病
     * 3 功能性消化不良
     * 4 肠易激综合征
     * 5 功能性便秘
     * 6 功能性腹泻
     * 7 幽门螺杆菌感染
     * 8 无
     */
    private List<String> digestiveSystem;

    /**
     * NULL
     * 	你是否曾出现以下健康问题？
     * 1 有过妊娠糖尿病
     * 2 生产过8斤以上巨大儿
     * 3 成年后曾因轻摔后骨折
     * 4 在50 岁前切除卵巢且未补充激素
     * 5 45岁前停经
     * 6 除怀孕、绝经、子宫切除外曾停经超 12 个月
     * 7 40岁后身高减少超过3cm
     * 8 无
     */
    private List<String> historyProblem;

    /**
     * NULL
     * 你的直系亲属是否存在以下代谢性疾病？
     * 1 肥胖
     * 2 2型糖尿病
     * 3 痛风
     * 4 高血脂
     * 5 甲亢
     * 6 高尿酸血症
     * 7 无
     */
    private List<String> familyMetabolismDisease;
    /**
     * NULL
     * 你的直系亲属是否存在以下呼吸系统疾病？
     * 1 支气管哮喘
     * 2 慢性支气管炎
     * 3 肺气肿
     * 4 慢阻肺
     * 5 肺癌
     * 6 无
     */
    private List<String> familyBreatheDisease;

    /**
     * NULL
     * 你的直系亲属是否存在以下心脑血管疾病？
     * 1 高血压
     * 2 冠心病
     * 3 脑卒中
     * 4 无
     */
    private List<String> familyAngiocarpyDisease;
    /**
     * NULL
     * 你的父母是否存在以下健康问题？
     * 1 骨质疏松
     * 2 因摔倒骨折
     * 3 驼背
     * 4 无
     */
    private List<String> parentsProblem;

    /**
     * NULL 空腹血糖，单位 mmol/L，大于等于1，小于等于33
     */
    private BigDecimal fbg;

    /**
     * NULL 餐后2小时血糖，单位 mmol/L，大于等于1，小于等于33
     */
    private BigDecimal pbg;

    /**
     * NULL 收缩压（高压），单位 mmHg，大于等于50，小于等于230
     */
    private Integer systolicPressure;

    /**
     * NULL 舒张压（低压），单位 mmHg，大于等于30，小于等于150
     */
    private Integer diastolicPressure;

    /**
     * NULL 骨密度T值，大于等于-6，小于等于3
     */
    private BigDecimal bmdTscore;

    /**
     * NULL 血尿酸，单位 μmol/L，大于等于150，小于1000
     */
    private Integer ua;

    /**
     * NULL 总胆固醇，单位 mmol/L，大于等于0.01，小于等于50
     */
    private BigDecimal tc;

    /**
     * NULL 甘油三酯，单位 mmol/L，大于等于0.01，小于等于50
     */
    private BigDecimal tg;

    /**
     * NULL 高密度脂蛋白胆固醇，单位 mmol/L，大于等于0.01，小于等于10
     */
    private BigDecimal hdlc;

    /**
     * NULL 低密度脂蛋白胆固醇，单位 mmol/L，大于等于0.01，小于等于20
     */
    private BigDecimal ldlc;

    /**
     * NULL 非高密度脂蛋白胆固醇，单位 mmol/L，大于等于0，小于等于20
     */
    private BigDecimal mdlc;

    /**
     * NULL γ-谷氨酰转移酶值，单位 U/L，大于等于5，小于等于300
     */
    private Integer yggt;

    /**
     * NULL 肝内脂肪含量， 单位：%，大于等于1，小于等于50
     */
    private BigDecimal liverFatContent;

    /**
     * 当前心率 单位：次/分钟 范围：[1-300]
     */
    private Double hr;

    /**
     * 血氧饱和度 单位：% 范围：[1-100]
     */
    private Integer bloodOxygen;

    /**
     * 心血管风险指数 范围：[0~100]
     */
    private Double cardiovascularRisk;

    /**
     * 当前心率变异性 范围：[0-10]
     */
    private Double hrvChange;

    /**
     * 你的常居住地？，1：城市 2：农村
     */
    private String residence;

    /**
     * 你受教育的年限？
     * 1 ≥10年
     * 2 7-9年
     * 3 0-6年
     */
    private String education;

    /**
     * 你是否处于产后1年内？
     * 1 是
     * 2 否
     */
    private String postnatalOneYear;

    /**
     * 你的分娩日期是？yyyy-MM-dd格式日期
     */
    private String postnatalTime;

    /**
     * 你是否处于哺乳状态？
     * 1 是
     * 2 否
     */
    private String lactation;

    /**
     * 你是否饮酒？
     * 1 平均每天> 1两酒精
     * 2 平均每天0.5-1两酒精
     * 3 平均每天< 0.5两酒精
     * 4 不喝酒
     */
    private String drinkState;

    /**
     * NULL
     * 	你是否有以下健康问题？
     * 1 近一年摔倒次数超过一次
     * 2 身体虚弱而担心摔倒
     * 3 心房纤颤
     * 4 左心室肥厚
     * 5 跟腱增厚
     * 6 甲状腺肿大
     * 7 无
     */
    private List<String> haveProblem;

    /**
     * NULL
     * 你是否近期有心血管系统异常症状？
     * 1 心率增快
     * 2 心悸
     * 3 心率减慢
     * 4 脉压减少
     * 5 无
     */
    private List<String> cardiovascularDisease;

    /**
     * NULL
     * 你是否近期常有消化系统异常症状？
     * 1 食欲亢进
     * 2 大便次数增多
     * 3 腹泻
     * 4 食欲减退
     * 5 腹胀
     * 6 便秘
     * 7 无
     */
    private List<String> digestiveSymptoms;

    /**
     * NULL
     * 你是否近期有内分泌异常症状？
     * 1 性欲减退
     * 2 阳痿
     * 3 无
     */
    private List<String> cryptorrbeaSymptoms;
    /**
     * NULL
     * 你是否近期有以下高代谢常见症状？
     * 1 不明原因的体重下降
     * 2 乏力
     * 3 怕热
     * 4 低热
     * 5 多汗
     * 6 皮肤温暖、潮湿
     * 7 无
     */
    private List<String> hypermetabolismSymptoms;
    /**
     * NULL
     * 	你是否近期有以下低代谢常见症状？
     * 1 畏寒
     * 2 少汗
     * 3 低温低于正常
     * 4 音调低哑
     * 5 行动迟缓
     * 6 言语缓慢
     * 7 体重增加
     * 8 乏力
     * 9 无
     */
    private List<String> lowMetabolismSymptoms;
    /**
     * NULL
     * 	你是否近期存在以下异常症状？
     * 1 气促
     * 2 咳痰
     * 3 皮肤干燥粗糙
     * 4 毛发干燥稀疏、脱发
     * 5 手脚掌皮肤呈姜黄色
     * 6 无
     */
    private List<String> abnormalSymptoms;

    /**
     * NULL
     * 你的面部是否近期有以下体征？
     * 1 面部浮肿
     * 2 表情呆板、淡漠
     * 3 面色苍白
     * 4 眼睑水肿
     * 5 舌体边缘有齿痕
     * 6 眉毛外1/3稀疏脱落
     * 7 胡须稀疏
     * 8 无
     */
    private List<String> faceSymptoms;

    /**
     * 睡眠问题
     * 	你是否有以下睡眠问题需要解决？
     * 1 入睡潜伏期超过30分钟
     * 2 夜间觉醒次数超过2次
     * 3 比期望的起床时间醒来早
     * 4 适宜时间不肯上床
     * 5 没有照顾者干预难以入睡
     * 6 经常23点以后睡觉
     * 7 睡眠时间不足6小时
     * 8 无
     */
    private List<String> sleepState;

    /**
     * 当睡眠时间充足且睡眠环境适宜时仍存在睡眠问题
     * 1 是
     * 2 否
     */
    private String enoughSleepProblem;

    /**
     * 	你是否有以下日间症状？
     * 1 疲倦或精神萎靡
     * 2 情绪不稳或易激惹
     * 3 注意力、专注力或记忆力下降
     * 4 日间瞌睡
     * 5 易犯错或者易出事故
     * 6 工作、学习、社交能力下降等
     * 7 无
     */
    private List<String> daytimeSymptoms;

    /**
     * 你选择的日间症状至少每周出现三次？
     * 1 是
     * 2 否
     */
    private String daytimeSymptomsThreeTimes;

    /**
     * 你选择的日间症状持续至少三个月？
     * 1 是
     * 2 否
     */
    private String daytimeSymptomsThreeMonths;

    /**
     * 乏力、疲倦或精神萎靡持续或反复发作的时间？
     * 1 小于1个月
     * 2 大于等于1个月
     * 3 大于等于6个月
     */
    private String weakRepetitionTime;
    /**
     * 你目前是否患有以下精神心理方面的疾病？
     * 1 重度抑郁症（医生诊断后的）
     * 2 双相情感障碍
     * 3 精神分裂症
     * 4 妄想症
     * 5 痴呆症
     * 6 神经性厌食症
     * 7 神经性贪食症
     * 8 无
     */
    private List<String> heartDisease;

    /**
     * 你曾经是否患有以下精神心理方面的疾病？
     * 1 重度抑郁症（医生诊断后的）
     * 2 双相情感障碍
     * 3 精神分裂症
     * 4 妄想症
     * 5 痴呆症
     * 6 神经性厌食症
     * 7 神经性贪食症
     * 8 无
     */
    private List<String> historyHeartDisease;

    /**
     * 你近期是否常有以下不适症状？
     * 1 咽痛
     * 2 颈部或腋下淋巴结触痛
     * 3 肌肉痛
     * 4 多关节疼痛，但不伴红肿
     * 5 头痛
     * 6 运动后的疲劳持续超过24小时
     * 7 睡眠后不能恢复精力
     * 8 无
     */
    private List<String> uncomfortableSymptoms;
    /**
     * 	请勾选出持续或反复发作6个月及以上的症状？
     * 1 咽痛
     * 2 颈部或腋下淋巴结触痛
     * 3 肌肉痛
     * 4 多关节疼痛，但不伴红肿
     * 5 头痛
     * 6 运动后的疲劳持续超过24小时
     * 7 睡眠后不能恢复精力
     * 8 注意力、专注力或记忆力下降
     * 9 无
     */
    private List<String> moreSixMonthSymptoms;

    /**
     * 你是否有以下味觉、口、齿、舌相关症状？
     * 1 舌深红
     * 2 牙龈出血/2
     * 3 味觉减退/2
     * 4 口角裂/嘴唇干裂
     * 5 无
     */
    private List<String> mouthSymptoms;
    /**
     * 你是否有以下眼、甲、皮肤相关症状？
     * 1 舟状甲/指甲脆薄
     * 2 皮肤有瘀斑/2
     * 3 眼干/2
     * 4 暗适应能力下降/夜盲症
     * 5 眼痒
     * 6 无
     */
    private List<String> eyeNailSkinSymptoms;

    /**
     * 你是否近期常有以下异常症状？
     * 1 嗳气
     * 2 上腹烧灼感
     * 3 腹痛
     * 4 无
     */
    private List<String> fgidAbnormalSymptoms;

    /**
     * 请勾选出以下持续至少6个月的症状？
     * 1 腹泻
     * 2 腹胀
     * 3 便秘
     * 4 嗳气
     * 5 上腹烧灼感
     * 6 腹痛
     * 7 无
     */
    private List<String> fgidMoreSixMonthSymptoms;

    /**
     * 你是否有以下健康问题？
     * 1 反复感冒
     * 2 伤口容易感染
     * 3 伤口愈合时间较正常长
     * 4 身体不同部位易长细小疖肿
     * 5 易感染传染病（如：感冒）
     * 6 有过敏的问题
     * 7 无
     */
    private List<String> immunityHealthProblem;

    /**
     * 没有感冒时你是否经常咳嗽？
     * 1 是
     * 2 否
     */
    private String oftenCough;

    /**
     * NULL
     * 你是否曾接受过以下治疗？
     * 1 甲状腺手术
     * 2 头颈部恶性肿瘤外放射治疗
     * 3 甲亢的放射性碘治疗
     * 4 胃大部分切除术，
     * 5 无
     */
    private List<String> receiveTreatment;
    /**
     * NULL
     * 你是否连续服用以下药物超过3个月？
     * 1 类固醇激素（如：可的松、泼尼松）
     * 2 利尿剂
     * 3 降压药
     * 4 含碘药物如：西地碘片、乙胺碘呋酮等
     * 5 服用胺碘酮、锂制剂、酪氨酸激酶抑制剂等
     * 6 无
     */
    private List<String> pharmacy3Month;

    /**
     * NULL
     * 你是否正在服用以下膳食补充剂？
     * 1 维生素D
     * 2 钙
     * 3 B族维生素
     * 4 多种维生素、矿物质
     * 5 蛋白补充剂
     * 6 膳食纤维
     * 7 全营养补充剂
     * 8 益生菌
     * 9 无
     */
    private List<String> dietarySupplement;

    /**
     * NULL
     * 你是否有以下食物摄入超量问题？
     * 1 喜好咸菜、火腿、各类炒货和腌制品
     * 2 每日摄入酱油、味精过量
     * 3 每日盐摄入多于一啤酒瓶盖
     * 4 每日至少吃一次甜品或饮料
     * 5 长期大量食用海带、紫菜
     * 6 长期大量食用卷心菜、芜菁、甘蓝、木薯
     * 7 无
     */
    private List<String> foodExcess;

    /**
     * NULL
     * 你是否有以下饮食习惯？（食物摄入过量问题）
     * 1 常吃内脏（平均每月大于2次）
     * 2 每周至少吃一次食油炸食品
     * 3 每周至少吃一次海鲜、贝类
     * 4 每周至少喝一次浓的肉汤
     * 5 每周至少吃一次烧烤
     * 6 无
     */
    private List<String> overeating;

    /**
     * NULL
     * 你是否有以下食物摄入不足问题？
     * 1 蔬菜摄入少，每日低于300g
     * 2 水果摄入少，每日低于200g
     * 3 不食用乳制品、贝类
     * 4 精米白面，少粗粮
     * 5 每周豆类及制品少于50g
     * 6 无
     */
    private List<String> foodInsufficient;

    /**
     * 过去半年中每周的运动情况是？
     * 1 除了工作/家务之外几乎不动
     * 2 每周运动1-2天
     * 3 每周运动3-4天
     * 4 每周运动5天以上
     */
    private String exerciseState;

    /**
     * 每天从事户外活动或运动时间？
     * 1 ＜10分钟
     * 2 10-30分钟
     * 3 30-45分钟
     * 4 45-60分钟
     * 5 60分钟以上
     */
    private String outdoorTime;

    /**
     * 	平均每天静坐时长
     * 1 小于3小时
     * 2 3-8个小时
     * 3 至少8小时
     */
    private String sitTime;

    /**
     * 	你每天的饮水量？
     * 1 少于1000ml
     * 2 1000-1500ml
     * 3 1500-1700ml
     * 4 1700-2500ml
     * 5 2500ml以上
     */
    private String waterIntake;

    /**
     * 你的吸烟情况？
     * 1 每天<=10支
     * 2 每天11-20支
     * 3 每天21~30支
     * 4 不抽烟但会接触二手烟，接触史＜20年
     * 5 不抽烟但会接触二手烟，接触史≥20年
     * 6 每天>30支
     * 7 戒烟＜5年
     * 8 5年＜戒烟＜15年
     * 9 戒烟≥15年
     * 10 现在和曾经均不抽烟也不接触二手烟
     */
    private String smokeState;

    /**
     * 	你是否长期存在以下精神状态？
     * 1 心理压力大紧张
     * 2 焦虑、担忧
     * 3 愤怒
     * 4 恐慌
     * 5 抑郁
     * 6 无
     */
    private List<String> mentalState;

    /**
     * 你是否长期居住或工作在以下环境？
     * 1 接触粉尘、有毒有害化学气体、重金属颗粒等
     * 2 目前使用煤炉或柴草烹饪或取暖
     * 3 空气污染严重地区
     * 4 无
     */
    private List<String> liveEnvironmental;

    /**
     * 你有以下吃肉蛋类的情况吗？
     * 1 平均每月吃肥肉（含五花肉）大于2次
     * 2 平均每周吃畜肉小于2次
     * 3 平均每周吃禽肉小于2次
     * 4 平均每周吃水产类小于1次
     * 5 平均每周吃蛋类（以鸡蛋计）大于7个
     * 6 平均每周吃蛋类（以鸡蛋计）少于3个
     * 7 无
     */
    private List<String> eatMeatEggTimes;
    /**
     * 你有下列饮食习惯吗？
     * 1 常吃加工食品
     * 2 进食深色蔬菜占总蔬菜比例小于1/2
     * 3 进食深色水果占总水果比例小于1/2
     * 4 平均每周吃坚果少于2次
     * 5 有吃亚麻籽油、紫苏子油
     * 6 食用无碘盐
     * 7 常吃红肉和加工肉类食物
     * 8 无
     */
    private List<String> dietaryHabit;

    /**
     * 你是否有以下饮用习惯？
     * 1 常喝咖啡（平均每天超过3杯）
     * 2 常喝浓茶/2
     * 3 常喝碳酸饮料/2
     * 4 常喝纯净水
     * 5 无
     */
    private List<String> drinkHabit;
    /**
     * 你家是否有以下烹饪习惯？
     * 1 做饭淘米超过2次
     * 2 烹调中(如：做粥时）加碱/2
     * 3 菠菜、冬笋等不焯水直接炒
     * 4 无
     */
    private List<String> cookingHabit;

    //以下字段没有对应问题
    /**
     * 	呼吸值（呼吸频率）
     */
    private Double brFace;

    /**
     * 年龄段
     * 0（未检测出）
     * 1（青少年）
     * 2（青年）
     * 3（中青年）
     * 4（中年）
     * 5（老年）
     */
    private String ageGroup;

    /**
     * 生理年龄(机能年龄)(0~100)
     */
    private Integer phyAge;

    /**
     * 生理状态（精神状态）
     * 0 - 正常，
     * 1 - 焦虑，
     * 2 - 生理疲劳（运动性），
     * 3 - 昏昏欲睡。
     */
    private String instantStatus;

    /**
     * 长期压力指数(0~100)
     */
    private Double pressureIndex;

    /**
     * 恢复指数(0~100)
     */
    private Double resilentIndex;

    /**
     * 机能活性度 (0~2)
     */
    private Double activeLevel;

    /**
     * 表情
     * 0生气
     * 1厌恶
     * 2恐惧
     * 3高兴
     * 4伤心
     * 5惊讶
     * 6平静
     */
    private String emotion;

    // 2023年2月7日 新增六种癌症

    /**
     * 你是否存在以下家族史？
     * 1 母亲、女儿或姐妹有乳腺癌或卵巢癌史
     * 2 姑姑、姨母、祖母或外祖母在50岁前，患有乳腺癌或卵巢癌，≥2人
     * 3 本人、母亲、女儿或姐妹携带BRCA1/2基因致病性遗传突变，≥1人
     * 4 一级亲属（父母、子女或同父母的兄弟姐妹）有胃癌病史
     * 5 一级亲属（父母、子女或同父母的兄弟姐妹）有结直肠癌史
     * 6 DTC/MTC或多发性内分泌腺瘤病2型
     * 7 家族性多发性息肉病
     * 8 某些甲状腺癌综合征
     * 9 无
     */
    private List<String> familyMedicalHistory;

    /**
     * 你是否有以下健康问题？
     * 癌症
     * 1 首次来月经的年龄≤12岁
     * 2 绝经年龄≥55岁
     * 3 有乳腺活检史或有乳腺良性疾病手术史或经病理检查为乳腺不典型增生病史
     * 4 使用“雌孕激素联合”的激素替代治疗≥半年
     * 5 45岁后乳腺X线检查提示乳腺实质类型为不均匀致密型或致密型
     * 6 无哺乳史或哺乳时间＜4个月
     * 7 无活产史（从未生育过、或流产、或死胎）、或初次生育年龄≥30岁
     * 8 仅使用“雌激素”激素替代治疗≥半年
     * 9 流产次数≥2次，含自然和人工流产
     * 10 童年期头颈部放射线照射史或放射性尘埃接触史
     * 11 全身放射治疗史
     * 12 慢性萎缩性胃炎、胃溃疡、胃息肉、手术后残胃、肥厚性胃炎、恶性贫血等疾病
     * 13 高危型HPV感染
     * 14 HIV感染
     * 15 初次性生活年龄＜20岁
     * 16 存在多个性伴侣
     * 17 器官或干细胞移植后使用免疫抑制药物
     * 18 无
     */
    private List<String> cancerHealthProblem;

    /**
     * 你是否有以下疾病史？
     * 1 结直肠癌病史
     * 2 肠道腺瘤病史
     * 3 8-10年长期不愈的炎症性肠病
     * 4 DTC/MTC或多发性内分泌腺瘤病2型
     * 5 家族性多发性息肉病
     * 6 某些甲状腺癌综合征
     * 7 无
     */
    private List<String> diseasesHistory;

    /**
     * 你的血清胃泌素-17（G-17）（pmol/L）值为？
     */
    private BigDecimal pgr;

    /**
     * 你的血清胃泌素-17（G-17）（pmol/L）值为？
     */
    private BigDecimal g17;

    /**
     * 你所在的地域
     * {@link com.jiankangyouyi.cloud.assessment.enums.assessmentCentre.AreaEnum}
     */
    private String area;

    /**
     * 你目前是否吸烟？
     * 1 吸烟
     * 2 不吸烟
     */
    private String smoking;

    /**
     * 你现在或曾经的吸烟年包数是否≥30？
     * （年包数=每天吸烟包数*吸烟年数）
     * 1 是
     * 2 否
     */
    private String yearSmokingLeastThirtyPacks;

    /**
     * 你是否有相关职业暴露史（石棉、氡、铍、铬、镉、镍、硅、煤烟和煤烟尘）至少1年？
     * 1 是
     * 2 否
     */
    private String jobExposeHistoryLeastOneYear;


}
