package com.jiankangyouyi.cloud.evaluation.enums;

import com.jiankangyouyi.cloud.core.constant.BaseEnum;
import lombok.AllArgsConstructor;

/**
 * 处理码定义
 *
 * @author wangshuang
 */
@AllArgsConstructor
public enum ResultEnum implements BaseEnum {

    /**
     * 系统错误
     */
    SYS0001("500", "系统错误"),
    /**
     * 测评简介不存在
     */
    EVA0002("10001", "测评简介不存在"),
    EVA0001("10001", "参数错误"),
    /**
     * 请检查必传参数是否传递
     */
    EVA0027("10001", "未传递必传参数"),
    EVA0128("10001", "参数异常-Http Body解析失败"),
    EVA0129("10001", "%s不在允许范围内"),

    /**
     * 答案长度不对
     */
    EVA0013("10001", "答案长度不对"),
    /**
     * 用户出生日期格式不合法
     */
    EVA0011("10001", "用户出生日期格式不合法"),
    /**
     * 用户出生日期不能小于当前日期
     */
    EVA0028("10001", "用户出生日期不能小于当前日期"),

    /**
     * 用户出生日期格式不合法
     */
    EVA0029("10001", "用户出生日期范围不合法"),


    /**
     * 参数范围不合法
     */
    EVA0015("10001", "参数范围不合法"),

    /**
     * 答案超出选择列表
     */
    EVA0012("10001", "答案超出选择列表"),

    /**
     * 专业测评问题答案列表不能为空
     */
    EVA0003("10001", "用户选项不能为空"),
    /**
     * 评测编码不能为空
     */
    EVA0004("10001", "评测编码不能为空"),
    /**
     * 测评问卷不存在
     */
    EVA0005("10001", "测评问卷不存在"),
    /**
     * 评测编码不合法
     */
    EVA0006("10001", "评测编码不合法"),
    /**
     * 专业测评问卷不存在
     */
    EVA0007("10001", "专业测评问题编码不存在"),
    /**
     * 问题编码与问卷编码不匹配
     */
    EVA0008("10001", "问题编码与问卷编码不匹配"),

    /**
     * 评测用户姓名不能为空
     */
    EVA0009("10001", "评测用户姓名不能为空"),
    /**
     * 评测用户性别不能为空
     */
    EVA0010("10001", "评测用户性别不能为空"),


    /**
     * 评测用户体重不能为空
     */
    EVA0014("10001", "评测用户体重不能为空"),


    /**
     * 参数类型错误
     */
    EVA0032("10001", "参数类型错误"),


    /**
     * 评测结果ID不能为空
     */
    EVA0016("10001", "评测结果ID不能为空"),

    /**
     * 评测结果不存在
     */
    EVA0017("10001", "测评结果不存在"),

    /**
     * 题库ID不能为空
     */
    EVA0018("10001", "题库ID不能为空"),

    /**
     * 用户性别不合法
     */
    EVA0019("10001", "用户性别不合法"),

    /**
     * 用户身高不合法
     */
    EVA0020("10001", "用户身高不合法"),

    /**
     * 用户体重不合法
     */
    EVA0021("10001", "用户体重不合法"),

    /**
     * 用户腰围不合法
     */
    EVA0022("10001", "用户腰围不合法"),

    /**
     * 评测记录不存在
     */
    EVA0023("10001", "评测记录不存在"),
    /**
     * 年龄超出区间
     */
    EVA0024("10001", "年龄超出区间"),

    /**
     * 用户年龄不合法
     */
    EVA0025("10001", "用户年龄不合法"),

    /**
     * 评测用户年龄不能为空
     */
    EVA0026("10001", "评测用户年龄不能为空"),

    /**
     * 劳动强度不合法
     */
    EVA0030("10001", "劳动强度不合法"),

    /**
     * 劳动强度不能为空
     */
    EVA0031("10001", "劳动强度不能为空"),

    /**
     * 标准入参不合法
     */
    EVA0033("400", "标准入参不合法"),
    ;

    private final String code;
    private final String comment;

    @Override
    public String code() {
        return code;
    }

    @Override
    public String message() {
        return comment;
    }

    public String comment() {
        return comment;
    }


    public static ResultEnum getEnum(String code) {

        ResultEnum[] ems = values();
        for (ResultEnum em : ems) {
            if (em.code().equalsIgnoreCase(code)) {
                return em;
            }
        }
        return null;
    }
}
