package com.jiankangyouyi.cloud.evaluation.model.entity.mongo;

import com.jiankangyouyi.cloud.core.base.entity.BaseMongoEntity;
import com.jiankangyouyi.cloud.evaluation.enums.EvaluationQuestionTypeEnum;
import lombok.*;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;

import java.math.BigDecimal;
import java.util.List;

/**
 * 测评标准参数集
 *
 * @author wangshuang
 * @since v2.0
 */
@Data
@NoArgsConstructor
@AllArgsConstructor
@Document(collection = "evaluation.standard.param.set")
public class EvaluationStandardParamSetDO extends BaseMongoEntity {

    private static final long serialVersionUID = 1L;

    public static final String FIELD_EVALUATIONCODE = "evaluationCode";
    public static final String FIELD_STANDARDPARAMLIST = "standardParamList";
    public static final String FIELD_STANDARDPARAMLIST_STANDARDPARAMKEY = "standardParamList.standardParamKey";
    public static final String FIELD_STANDARDPARAMLIST_DESCRIPTION = "standardParamList.description";
    public static final String FIELD_STANDARDPARAMLIST_STANDARDPARAMOPTIONS = "standardParamList.standardParamOptions";
    public static final String FIELD_STANDARDPARAMLIST_STANDARDPARAMOPTIONS_OPTIONCODE = "standardParamList.standardParamOptions.optionCode";
    public static final String FIELD_STANDARDPARAMLIST_STANDARDPARAMOPTIONS_OPTIONCONTENT = "standardParamList.standardParamOptions.optionContent";
    public static final String FIELD_STANDARDPARAMLIST_STANDARDPARAMOPTIONS_SCORE = "standardParamList.standardParamOptions.score";
    public static final String FIELD_STANDARDPARAMLIST_STANDARDPARAMTYPE = "standardParamList.standardParamType";
    public static final String FIELD_STANDARDPARAMLIST_NEEDSTATUS = "standardParamList.needStatus";
    public static final String FIELD_STANDARDPARAMLIST_LIMITINFO = "standardParamList.limitInfo";
    public static final String FIELD_STANDARDPARAMLIST_LIMITINFO_MINVALUE = "standardParamList.limitInfo.minValue";
    public static final String FIELD_STANDARDPARAMLIST_LIMITINFO_MAXVALUE = "standardParamList.limitInfo.maxValue";
    public static final String FIELD_STANDARDPARAMLIST_LIMITINFO_UNIT = "standardParamList.limitInfo.unit";


    /**
     * 评测编码
     */
    @Indexed(unique = true)
    private String evaluationCode;

    /**
     * 标准入参列表
     */
    private List<EvaluationStandardParam> standardParamList;

    @Getter
    @Setter
    @NoArgsConstructor
    @AllArgsConstructor
    public static class EvaluationStandardParam {

        /**
         * 标准参数编码
         * <p>
         * 例如：1、2、3、4、5、6
         */
        private String standardParamKey;

        /**
         * 描述
         */
        private String description;

        /**
         * 标准参数选项信息
         */
        private List<EvaluationStandardParamOption> standardParamOptions;

        /**
         * 标准参数类型  单选多选
         * {@link EvaluationQuestionTypeEnum}
         */
        private String standardParamType;
        /**
         * 备注
         */
        private List<String> remarks;

        /**
         * 是否必填
         */
        private boolean needStatus;


        /**
         * 限制信息
         */
        private LimitInfo limitInfo;
    }

    @Getter
    @Setter
    @NoArgsConstructor
    @AllArgsConstructor
    public static class EvaluationStandardParamOption {

        /**
         * 选项编码
         * <p>
         * 例如：1、2、3、4
         */
        private String optionCode;

        /**
         * 标准选项内容
         */
        private String optionContent;

        /**
         * 得分
         */
        private Double score;
        /**
         * 中医脏腑得分
         */
        private ZangAndFu zangAndFuScore;

    }
    @Setter
    @Getter
    public static class ZangAndFu {

        /**
         *肝
         */
        private Double liverScore;
        /**
         *心
         */
        private Double heartScore;
        /**
         *脾
         */
        private Double spleenScore;
        /**
         *肺
         */
        private Double lungScore;
        /**
         *肾
         */
        private Double kidneyScore;
        /**
         *胃
         */
        private Double stomachScore;
        /**
         *胆
         */
        private Double gallbladderScore;
        /**
         *大肠
         */
        private Double largeIntestineScore;
        /**
         *小肠
         */
        private Double smallIntestineScore;


    }

    @Setter
    @Getter
    public static class LimitInfo {

        /**
         * 最小值
         */
        private BigDecimal minValue;

        /**
         * 最小值
         */
        private BigDecimal maxValue;

        /**
         * 单位
         */
        private String unit;
    }
}
