package com.jiankangyouyi.cloud.evaluation.model.entity.mongo.template;

import com.jiankangyouyi.cloud.evaluation.enums.EvaluationVideoMappingEnum;
import com.jiankangyouyi.cloud.evaluation.enums.TemplateTypeEnum;
import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 音频和视频方案模板
 *
 * @author june
 */
@Getter
@Setter
@AllArgsConstructor
@NoArgsConstructor
public class VideoAndAudioTemplate implements IEvaluationTemplate2 {

    /**
     * 标题
     */
    private String title;
    /**
     * 结果说明
     */
    private List<String> remarks;

    /**
     * 视频地址
     */
    private VideoAndAudioTemplateDetail videoUrl;
    /**
     * 音频地址
     */
    private VideoAndAudioTemplateDetail audioUrl;

    public VideoAndAudioTemplate(String title, String remark, String type, EvaluationVideoMappingEnum videoUrl, EvaluationVideoMappingEnum... audioUrl) {
        this.title = title;
        this.remarks = Collections.singletonList(remark);
        this.videoUrl = new VideoAndAudioTemplateDetail(String.format("%s视频", type), videoUrl.getUrl());
        this.audioUrl = new VideoAndAudioTemplateDetail(String.format("%s音乐", type), Arrays.stream(audioUrl).map(EvaluationVideoMappingEnum::getUrl).collect(Collectors.toList()));
    }

    public static EvaluationTemplate2Bean build(String title, String remark, String type, EvaluationVideoMappingEnum videoUrl, EvaluationVideoMappingEnum... audioUrl) {
        EvaluationTemplate2Bean bean = new EvaluationTemplate2Bean();
        bean.setTemplateType(TemplateTypeEnum.VIDEO_AND_AUDIO_TEMPLATE.code());
        bean.setTemplate(new VideoAndAudioTemplate(title, remark, type, videoUrl, audioUrl));
        return bean;
    }

}
