package com.jiankangyouyi.cloud.motorplan.enums;

import com.jiankangyouyi.cloud.core.constant.BaseEnum;
import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * 疾病类型
 *
 * @author ：wangyalei
 * @date ：Created in 2021/6/18 4:35 下午
 */
@Getter
@AllArgsConstructor
public enum DiseaseEnum implements BaseEnum {

    /**
     * 健康/亚健康人群
     */
    HEALTHY_PERSON("HEALTHY_PERSON", "健康/亚健康人群"),
    /**
     * 2型糖尿病
     */
    TYPE_2_DIABETES("TYPE_2_DIABETES", "2型糖尿病"),

    /**
     * 高血压
     */
    HYPERTENSION("HYPERTENSION", "高血压"),

    /**
     * 冠心病
     */
    CORONARY_DISEASE("CORONARY_DISEASE", "冠心病"),

    /**
     * 骨质疏松
     */
    OSTEOPOROSIS("OSTEOPOROSIS", "骨质疏松"),

    /**
     * 痛风
     */
    GOUT("GOUT", "痛风"),

    /**
     * 脂肪肝
     */
    FATTY_LIVER("FATTY_LIVER", "脂肪肝"),

    /**
     * 脑卒中
     */
    STROKE("STROKE", "脑卒中"),

    /**
     * 胃功能紊乱
     */
    GASTRIC_FUNCTION_DISORDER("GASTRIC_FUNCTION_DISORDER", "胃功能紊乱"),

    /**
     * 肠道功能紊乱
     */
    INTESTINAL_FUNCTION_DISORDER("INTESTINAL_FUNCTION_DISORDER", "肠道功能紊乱"),

    /**
     * 免疫功能紊乱
     */
    HYPOIMMUNITY("HYPOIMMUNITY", "免疫功能紊乱"),

    /**
     * 肥胖
     */
    OBESITY("OBESITY", "肥胖"),

    /**
     * 胃癌
     */
    GASTRIC_CANCER("GASTRIC_CANCER", "胃癌"),

    /**
     * 高尿酸血症
     */
    HYPERURICEMIA("HYPERURICEMIA", "高尿酸血症"),

    /**
     * 阿尔兹海默症
     */
    AD("AD", "阿尔兹海默症"),

    /**
     * 慢阻肺
     */
    COPD("COPD", "慢阻肺"),

    /**
     * 动脉硬化性心血管病
     */
    ASCVD("ASCVD", "动脉硬化性心血管病"),

    /**
     * 缺血性心血管
     */
    ICVD("ICVD", "缺血性心血管"),

    /**
     * 失眠
     */
    INSOMNIA("INSOMNIA", "失眠"),

    /**
     * 高血脂
     */
    HPYPERLIPIDEMIA("HPYPERLIPIDEMIA", "高血脂"),

    /**
     * 甲亢
     */
    IIH("IIH", "甲亢"),
    /**
     * 甲减
     */
    TSH("TSH", "甲减"),

    /**
     * 产后(哺乳期)
     */
    POSTPARTUM_LACTATION("POSTPARTUM_LACTATION", "产后(哺乳期)"),
    /**
     * 产后(非哺乳期)
     */
    POSTPARTUM_NON_LACTATION("POSTPARTUM_NON_LACTATION", "产后(非哺乳期)"),
    /**
     * 贫血
     */
    ANEMIA("ANEMIA", "贫血"),
    /**
     * 慢性肾脏病
     */
    CHRONIC_RENAL_FAILURE("CHRONIC_RENAL_FAILURE", "慢性肾脏病"),
    /**
     * 慢性胃炎
     */
    CHRONIC_GASTRITIS("CHRONIC_GASTRITIS", "慢性胃炎"),
    /**
     * 溃疡性结肠炎
     */
    UC("UC", "溃疡性结肠炎"),
    /**
     * 慢性肝炎
     */
    CHRONIC_HEPATITIS("CHRONIC_HEPATITIS", "慢性肝炎"),

    /**
     * 营养不良
     */
    NUTRIENT_DEFICIENCY("NUTRIENT_DEFICIENCY", "营养不良"),
    /**
     * 慢性疲劳综合征
     */
    CFS("CFS","慢性疲劳综合征"),
    /**
     * 免疫力
     */
    IMMUNITY("IMMUNITY","免疫力"),
    /**
     * 功能性胃肠病
     */
    FGID("FGID","功能性胃肠病"),
    /**
     * 产后体重管理
     */
    POSTPARTUM_WEIGHT("POSTPARTUM_WEIGHT", "产后体重管理"),

    /**
     * 心血管疾病
     * 名称改为冠心病
     */
    CVD("CVD", "冠心病"),
    /**
     * 慢性失眠症
     */
    INSOMNIA_CHRONIC_SYNDROME("INSOMNIA_CHRONIC_SYNDROME", "慢性失眠症"),
    /**
     * 颈椎病
     */
    CERVICAL_SPONDYLOSIS("CERVICAL_SPONDYLOSIS", "颈椎病"),
    /**
     * 肩关节周围炎
     */
    PERIARTHRITIS_OF_SHOULDER("PERIARTHRITIS_OF_SHOULDER", "肩关节周围炎"),
    /**
     * 肩袖损伤
     */
    ROTATOR_CUFF_INJURY("ROTATOR_CUFF_INJURY", "肩袖损伤"),
    /**
     * 网球肘
     */
    TENNIS_ELBOW("TENNIS_ELBOW", "网球肘"),
    /**
     * 脊柱畸形
     */
    SPINAL_DEFORMITY("SPINAL_DEFORMITY", "脊柱畸形"),
    /**
     * 腰背肌劳损
     */
    LOW_BACK_MUSCLE_STRAIN("LOW_BACK_MUSCLE_STRAIN", "腰背肌劳损"),
    /**
     * 腰椎间盘突出
     */
    LUMBAR_DISC_HERNIATION("LUMBAR_DISC_HERNIATION", "腰椎间盘突出"),
    /**
     * 膝关节损伤
     */
    KNEE_INJURY("KNEE_INJURY", "膝关节损伤"),
    /**
     * 踝关节损伤
     */
    ANKLE_INJURY("ANKLE_INJURY", "踝关节损伤"),
    /**
     * 关节炎
     */
    ARTHRITIS("ARTHRITIS", "关节炎"),
    ;


    /**
     * 疾病类型
     */
    private final String diseaseType;

    /**
     * 疾病名称
     */
    private final String diseaseName;


    public static DiseaseEnum getEnum(String diseaseType) {
        DiseaseEnum[] values = values();
        if (diseaseType == null) {
            return null;
        }
        for (DiseaseEnum value : values) {
            if (diseaseType.equals(value.diseaseType)) {
                return value;
            }
        }
        return null;
    }

    public static DiseaseEnum getEnumByName(String diseaseName) {
        if (diseaseName == null) {
            return null;
        }
        DiseaseEnum[] values = values();
        for (DiseaseEnum value : values) {
            if (diseaseName.equals(value.diseaseName)) {
                return value;
            }
        }
        return null;
    }

    @Override
    public String code() {
        return getDiseaseType();
    }

    @Override
    public String message() {
        return getDiseaseName();
    }
}
