package com.jiankangyouyi.cloud.motorplan.enums;

import lombok.AllArgsConstructor;
import org.apache.commons.lang3.ArrayUtils;
import org.apache.commons.lang3.StringUtils;


/**
 * Redis Key Enum
 *
 * @author yangsongbo
 */
@AllArgsConstructor
public enum RedisKeyEnum {

    /**
     * 运动方案配置项
     */
    LIST_EXERCISE_PROJECT_CONFIG("list_exercise_project_config", "运动方案配置项"),
    /**
     * <p>公共参数缓存，后缀为paramGroup、paramKey</p>
     */
    STRING_PARAM_VALUE("string_param_value", "公共参数缓存，后缀为paramGroup、paramKey"),




    ;

    /**
     * redis key
     */
    private final String key;

    /**
     * 描述
     */
    private final String describe;


    /**
     * 获取key
     *
     * @param keySuffixes key后缀
     * @return redis key
     */
    public String getKey(String... keySuffixes) {
        StringBuilder builder = new StringBuilder(this.key);

        if (ArrayUtils.isNotEmpty(keySuffixes)) {
            for (String keySuffix : keySuffixes) {
                if (StringUtils.isNotBlank(keySuffix)) {
                    builder.append("_").append(keySuffix);
                }
            }
        }
        return builder.toString();
    }


}



