package com.jiankangyouyi.cloud.motorplan.model.bean;

import com.jiankangyouyi.cloud.basedata.api.enums.action.ActionPositionEnum;
import io.jsonwebtoken.lang.Assert;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;

import java.util.ArrayList;
import java.util.Comparator;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author ：wangyalei
 * @date ：Created in 2021/7/6 9:28 上午
 */
@Data
@AllArgsConstructor
@Builder
@Slf4j
public class ActionVideoHandler2 {
    /**
     * 站动作视频
     */
    private List<ActionVideoInfo2> standList;
    /**
     * 坐动作视频
     */
    private List<ActionVideoInfo2> sitList;
    /**
     * 俯卧动作视频
     */
    private List<ActionVideoInfo2> lieProstrateList;
    /**
     * 仰卧动作视频
     */
    private List<ActionVideoInfo2> lieSupineList;

    public ActionVideoHandler2() {
        standList = new ArrayList<>();
        sitList = new ArrayList<>();
        lieProstrateList = new ArrayList<>();
        lieSupineList = new ArrayList<>();
    }

    /**
     * 添加动作视频
     *
     * @param actionVideoInfo 动作视频
     * @param actionPosition  动作体位
     */
    public void addActionVideoInfo(ActionVideoInfo2 actionVideoInfo, String actionPosition) {
        Assert.notNull(actionVideoInfo, "this actionVideoInfo must have text; it must not be null，empty, or blank");
        Assert.hasText(actionPosition, "this actionPosition must have text; it must not be null，empty, or blank");

        if (actionPosition.equals(ActionPositionEnum.STAND.getCode())) {
            standList.add(actionVideoInfo);
        } else if (actionPosition.equals(ActionPositionEnum.SIT.getCode())) {
            sitList.add(actionVideoInfo);
        } else if (actionPosition.equals(ActionPositionEnum.LIE_PROSTRATE.getCode())) {
            lieProstrateList.add(actionVideoInfo);
        } else if (actionPosition.equals(ActionPositionEnum.LIE_SUPINE.getCode())) {
            lieSupineList.add(actionVideoInfo);
        }
    }

    /**
     * 获取排序合并结果
     *
     * @return List<ActionVideoInfo>
     */
    public List<ActionVideoInfo2> getSortMergeResult() {
        List<ActionVideoInfo2> finalVideoList = new ArrayList<>();
        if (!standList.isEmpty()) {
            finalVideoList.addAll(standList.stream().sorted(Comparator.comparing(ActionVideoInfo2::getMet).thenComparing(ActionVideoInfo2::getActionGroup).thenComparing(ActionVideoInfo2::getRelationActionGroupOrder)).collect(Collectors.toList()));
        }
        if (!sitList.isEmpty()) {
            finalVideoList.addAll(sitList.stream().sorted(Comparator.comparing(ActionVideoInfo2::getMet).thenComparing(ActionVideoInfo2::getActionGroup).thenComparing(ActionVideoInfo2::getRelationActionGroupOrder)).collect(Collectors.toList()));
        }
        if (!lieProstrateList.isEmpty()) {
            finalVideoList.addAll(lieProstrateList.stream().sorted(Comparator.comparing(ActionVideoInfo2::getMet).thenComparing(ActionVideoInfo2::getActionGroup).thenComparing(ActionVideoInfo2::getRelationActionGroupOrder)).collect(Collectors.toList()));
        }
        if (!lieSupineList.isEmpty()) {
            finalVideoList.addAll(lieSupineList.stream().sorted(Comparator.comparing(ActionVideoInfo2::getMet).thenComparing(ActionVideoInfo2::getActionGroup).thenComparing(ActionVideoInfo2::getRelationActionGroupOrder)).collect(Collectors.toList()));
        }
        // log.info("finalVideoList11111:{}", JsonUtils.toJson(finalVideoList));
        return finalVideoList;

    }


}
