package com.jiankangyouyi.cloud.motorplan.model.bean;

import com.jiankangyouyi.cloud.motorplan.model.entity.mongo.ExerciseCourseProjectGlobalConfigDO;
import com.jiankangyouyi.cloud.motorplan.model.entity.mongo.component.v3.ActionConfig;
import com.jiankangyouyi.cloud.motorplan.model.entity.mongo.component.v3.ExerciseConfigInfo;
import com.jiankangyouyi.cloud.motorplan.model.entity.mongo.component.v3.ExerciseCourseProjectConfig;
import com.jiankangyouyi.cloud.motorplan.model.entity.mongo.component.v3.SystemRemindDescriptionConfig;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serializable;
import java.util.List;

/**
 * @author ：wangyalei
 * @date ：Created in 2021/7/7 6:30 下午
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
public class ExerciseCourseProjectConfigResult2 implements Serializable {
    /**
     * 管理目标
     */
    private List<String> managementGoals;
    /**
     * 注意事项
     */
    private List<String> attentionItems;
    /**
     * 动作难度
     */
    private List<String> actionDifficulty;
    /**
     * 视频课程禁忌动作属性
     */
    private List<String> forbidActionProperties;
    /**
     * 系统课程禁忌动作属性
     */
    private List<String> systemForbidActionProperties;
    /**
     * 运动频率
     */
    private String exerciseFrequencyDesc;
    /**
     * 运动频率最小值 /天
     */
    private Integer exerciseFrequencyMinValue;
    /**
     * 运动频率最大值 /天
     */
    private Integer exerciseFrequencyMaxValue;
    /**
     * 用户BMI
     */
    private Double bmi;
    /**
     * 运动能力 1、低 2、中 3、高
     */
    private Integer athleticAbility;
    /**
     * 出生日期
     */
    private String birthday;
    /**
     * 运动配置信息
     */
    private ExerciseConfigInfo exerciseConfigInfo;
    /**
     * 动作时间信息
     */
    private ActionTimeInfo actionTimeInfo;

    /***
     * 热身动作约束信息
     */
    private ActionGroupConfigResult2.ActionLimitInfo warmupActonLimitInfo;
    /***
     * 拉伸动作约束信息
     */
    private ActionGroupConfigResult2.ActionLimitInfo stretchActonLimitInfo;
    /***
     * 训练动作约束信息
     */
    private ActionGroupConfigResult2.ActionLimitInfo trainingActonLimitInfo;
    /**
     * 休息视频条件信息
     */
    private ActionGroupConfigResult2.RestVideoConditionInfo restVideoConditionInfo;
    /**
     * 梅脱限制信息
     */
    private ActionGroupConfigResult2.MetLimitInfo metLimitInfo;
    /**
     * 动作规则
     */
    private ActionConfig.RuleInfo ruleInfo;

    /**
     * 系统运动提示话术配置
     */
    private List<SystemRemindDescriptionConfig.ConfigDetail> systemRemindDescriptionConfigs;
    /**
     * 方案配置
     */
    private ExerciseCourseProjectConfig exerciseCourseProjectConfig;
    /**
     * 运动课程方案全局配置
     */
    private ExerciseCourseProjectGlobalConfigDO exerciseCourseProjectGlobalConfigDO;

    /**
     * 梅脱限制信息
     */
    @Data
    @Builder
    @AllArgsConstructor
    @NoArgsConstructor
    public static class MetLimitInfo {
        /**
         * 视频约束最小值
         */
        private Double videoLimitMinValue;
        /**
         * 视频约束最小值
         */
        private Double videoLimitMaxValue;
        /**
         * 时间占比最小值
         */
        private Double timeProportionMinValue;
        /**
         * 时间占比最大值
         */
        private Double timeProportionMaxValue;
        /**
         * 时间占比 （只合成的视频时长占比）
         */
        private Double timeProportion;
    }

    /**
     * 动作约束信息
     */
    @Builder
    @Data
    @AllArgsConstructor
    @NoArgsConstructor
    public static class ActionLimitInfo {
        /**
         * 动作体位
         */
        private List<String> actionPositions;
        /**
         * 动作分类
         */
        private List<String> actionClassifications;
        /**
         * 动作锻炼肌群
         */
        private List<String> trainPositions;
    }

    /**
     * 休息视频条件信息
     */
    @Data
    @Builder
    @AllArgsConstructor
    @NoArgsConstructor
    public static class RestVideoConditionInfo {
        /**
         * 动作个数
         */
        private Integer actionCount;
        /**
         * 视频规格
         */
        private String videoSize;
    }

    /**
     * 动作时间信息
     */
    @Data
    @Builder
    @AllArgsConstructor
    @NoArgsConstructor
    public static class ActionTimeInfo {
        /**
         * 热身时间 /分
         */
        private Integer warmupTime;
        /**
         * 拉伸时间 /分
         */
        private Integer stretchTime;
        /**
         * 最小训练时间
         */
        private Integer minTrainTime;
        /**
         * 最大训练时间
         */
        private Integer maxTrainTime;

    }



}
