package com.jiankangyouyi.cloud.motorplan.model.bean;

import com.jiankangyouyi.cloud.core.util.StringUtils;
import com.jiankangyouyi.cloud.motorplan.model.entity.mongo.component.v3.RestVideoDetailInfo;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.apache.commons.collections4.CollectionUtils;

import java.util.LinkedHashMap;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * @author ：wangyalei
 * @date ：Created in 2021/6/22 4:44 下午
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
public class GenerateActionVideo2 {

    /**
     * 热身动作总时间 /ms
     */
    private Long warmupTotalTimeMilliseconds;
    /**
     * 热身动作产生总热量
     */
    private Integer warmupTotalHeat;
    /**
     * 热身动作视频列表
     */
    private List<ActionVideoInfo2> warmupVideos;
    /**
     * 热身动作个数
     */
    private Integer warmupActionCount;

    /**
     * 训练动作总时间 /ms
     */
    private Long trainingTotalTimeMilliseconds;
    /**
     * 训练动作产生总热量
     */
    private Integer trainingTotalHeat;
    /**
     * 训练动作视频列表 / 单套
     */
    private List<ActionVideoInfo2> trainingVideos;
    /**
     * 训练动作个数 /单套
     */
    private Integer trainingActionCount;

    /**
     * 拉伸动作总时间 /ms
     */
    private Long stretchTotalTimeMilliseconds;
    /**
     * 拉伸动作产生总热量
     */
    private Integer stretchTotalHeat;
    /**
     * 拉伸动作视频列表
     */
    private List<ActionVideoInfo2> stretchVideos;

    /**
     * 拉伸动作个数
     */
    private Integer stretchActionCount;
    /**
     * 训练动作循环次数
     */
    private Integer trainingCirculationCount;
    /**
     * 训练动作间隔个数 （插入休息视频用）
     */
    private Integer trainingIntervalCount;
    /**
     * 休息视频总个数
     */
    private Integer restVideoTotalCount;
    /**
     * 休息视频总时间 /ms
     */
    private Long restVideoTotalTime;
    /**
     * 休息视频信息
     */
    private RestVideoDetailInfo restVideoInfo;
    /**
     * 最终视频列表
     */
    private List<ActionVideoInfo2> finalActionVideos;

    /**
     * 课程封面图
     */
    private String courseImageKey;
    /**
     * 课程视频 1080 分辨率   m3u8 文件地址key
     */
    private String courseVideoM3u8P1080Key;
    /**
     * 课程视频 720 分辨率   m3u8 文件地址key
     */
    private String courseVideoM3u8P720Key;
    /**
     * 课程视频 480 分辨率   m3u8 文件地址key
     */
    private String courseVideoM3u8P480Key;
    /**
     * 器材类型
     */
    private List<String> equipments;


    public Double getWarmupTotalHeat() {
        if (CollectionUtils.isEmpty(warmupVideos)) {
            return 0.0;
        }
        return warmupVideos.stream().map(ActionVideoInfo2::getHeat).filter(Objects::nonNull).reduce(Double::sum).orElse(0.000);
    }
    public Integer getWarmupActionCount() {
        if (CollectionUtils.isEmpty(warmupVideos)) {
            return 0;
        }
        return warmupVideos.stream()
                .filter(item -> StringUtils.isNotBlank(item.getActionGroup()))
                .collect(Collectors.groupingBy(ActionVideoInfo2::getActionGroup, LinkedHashMap::new, Collectors.toList()))
                .size();
    }

    public Double getStretchTotalHeat() {
        if (CollectionUtils.isEmpty(stretchVideos)) {
            return 0.0;
        }
        return stretchVideos.stream().map(ActionVideoInfo2::getHeat).filter(Objects::nonNull).reduce(Double::sum).orElse(0.0);
    }
    public Integer getStretchActionCount() {
        if (CollectionUtils.isEmpty(stretchVideos)) {
            return 0;
        }
        return stretchVideos.stream()
                .filter(item -> StringUtils.isNotBlank(item.getActionGroup()))
                .collect(Collectors.groupingBy(ActionVideoInfo2::getActionGroup, LinkedHashMap::new, Collectors.toList()))
                .size();
    }

    public Double getTrainingTotalHeat() {
        if (CollectionUtils.isEmpty(finalActionVideos)) {
            return 0.0;
        }
        return finalActionVideos.stream().filter(ActionVideoInfo2::getTrainingVideo).map(ActionVideoInfo2::getHeat).filter(Objects::nonNull).reduce(Double::sum).orElse(0.0);
    }
    public Integer getTrainingActionCount() {
        if (CollectionUtils.isEmpty(trainingVideos)) {
            return 0;
        }
        return trainingVideos.stream()
                .filter(item -> StringUtils.isNotBlank(item.getActionGroup()) && item.getTrainingVideo())
                .collect(Collectors.groupingBy(ActionVideoInfo2::getActionGroup, LinkedHashMap::new, Collectors.toList()))
                .size();
    }

    public Long getWarmupTotalTimeMilliseconds() {
        if (CollectionUtils.isEmpty(warmupVideos)) {
            return 0L;
        }
        return warmupVideos.stream().map(ActionVideoInfo2::getTimeMilliseconds).filter(Objects::nonNull).reduce(Long::sum).orElse(0L);
    }

    public Long getStretchTotalTimeMilliseconds() {
        if (CollectionUtils.isEmpty(stretchVideos)) {
            return 0L;
        }
        return stretchVideos.stream().map(ActionVideoInfo2::getTimeMilliseconds).filter(Objects::nonNull).reduce(Long::sum).orElse(0L);
    }

    public Long getTrainingTotalTimeMilliseconds() {
        if (CollectionUtils.isEmpty(finalActionVideos)) {
            return 0L;
        }
        return finalActionVideos.stream().filter(ActionVideoInfo2::getTrainingVideo).map(ActionVideoInfo2::getTimeMilliseconds).filter(Objects::nonNull).reduce(Long::sum).orElse(0L);
    }

    public Integer getRestVideoTotalCount() {
        if (CollectionUtils.isEmpty(finalActionVideos)) {
            return 0;
        }
        return (int) finalActionVideos.stream().filter(ActionVideoInfo2::getRestVideo).count();
    }

    public Long getRestVideoTotalTime() {
        if (CollectionUtils.isEmpty(finalActionVideos)) {
            return 0L;
        }
        return finalActionVideos.stream().filter(ActionVideoInfo2::getRestVideo).map(ActionVideoInfo2::getTimeMilliseconds).filter(Objects::nonNull).reduce(Long::sum).orElse(0L);
    }

}
