package com.jiankangyouyi.cloud.motorplan.model.builder;

import com.jiankangyouyi.cloud.core.external.qiniu.QiniuClient;
import com.jiankangyouyi.cloud.core.external.qiniu.constant.ProtocolEnum;
import com.jiankangyouyi.cloud.core.external.qiniu.entity.key.QiniuKey;
import com.jiankangyouyi.cloud.core.util.CollectionUtils;
import com.jiankangyouyi.cloud.motorplan.api.model.dto.response.component.*;
import com.jiankangyouyi.cloud.motorplan.constant.Constants;
import com.jiankangyouyi.cloud.motorplan.enums.QiniuBucketEnum;
import com.jiankangyouyi.cloud.motorplan.model.entity.mongo.ExerciseCoursePlanDO;
import com.jiankangyouyi.cloud.motorplan.model.vo.ExerciseCoursePlanInfoVO;
import com.jiankangyouyi.cloud.motorplan.model.vo.ExerciseCoursePlanInfoVO2;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;

import java.math.BigDecimal;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author ：wangyalei
 * @date ：Created in 2021/7/2 5:00 下午
 */
@Slf4j
public class ExerciseCoursePlanOperationBuilder {

    /**
     * 构建课程计划信息 (建议使用V2)
     *
     * @param exerciseCoursePlanDO 请求参数
     * @return ExerciseCoursePlanInfoVO
     */
    @Deprecated
    public static ExerciseCoursePlanInfoVO buildExerciseCoursePlanInfoVO(ExerciseCoursePlanDO exerciseCoursePlanDO) {
        QiniuClient qiniuClient = QiniuClient.getClient(QiniuBucketEnum.JKYY_PRIVATE.getBucket());
        List<ActionExplainInfo> actionExplainInfos = null;
        if (CollectionUtils.isNotEmpty(exerciseCoursePlanDO.getActionExplains())) {
            actionExplainInfos = exerciseCoursePlanDO.getActionExplains().stream().map(xx ->
                    ActionExplainInfo.builder()
                            .actionImageUrl(xx.getActionImageKey())
                            .actionName(xx.getActionName())
                            .actionExplains(xx.getActionExplains())
                            .videoDurationSecond(xx.getVideoDurationSecond())
                            .attentions(xx.getAttentions())
                            .actionVideoM3u8P1080Url(qiniuClient.pm3u8(ProtocolEnum.HTTPS, xx.getActionVideoM3u8P1080Key(), QiniuBucketEnum.JKYY_PRIVATE.getBucket(), Constants.VIDEO_LINK_VALID_TIME))
                            .actionVideoM3u8P720Url(qiniuClient.pm3u8(ProtocolEnum.HTTPS, xx.getActionVideoM3u8P720Key(), QiniuBucketEnum.JKYY_PRIVATE.getBucket(), Constants.VIDEO_LINK_VALID_TIME))
                            .actionVideoM3u8P480Url(qiniuClient.pm3u8(ProtocolEnum.HTTPS, xx.getActionVideoM3u8P480Key(), QiniuBucketEnum.JKYY_PRIVATE.getBucket(), Constants.VIDEO_LINK_VALID_TIME))
                            .build()
            ).collect(Collectors.toList());
        }

        return ExerciseCoursePlanInfoVO.builder()
                .courseId(exerciseCoursePlanDO.getCourseId())
                .actionCount(exerciseCoursePlanDO.getActionCount())
                .actionExplains(actionExplainInfos)
                .attentionItems(exerciseCoursePlanDO.getAttentionItems())
                .courseDurationMinute(exerciseCoursePlanDO.getCourseDurationMinute())
                .courseDurationSecond(exerciseCoursePlanDO.getCourseDurationSecond())
                .courseFinishDetails(exerciseCoursePlanDO.getCourseFinishDetails())
                .courseHeat(BigDecimal.valueOf(exerciseCoursePlanDO.getCourseHeat()).setScale(3,BigDecimal.ROUND_HALF_UP).doubleValue())
                .courseImageUrl(exerciseCoursePlanDO.getCourseImageKey())
                .courseFinishTotalDuration(exerciseCoursePlanDO.getCourseFinishTotalDuration())
                .courseFinishTotalHeat(exerciseCoursePlanDO.getCourseFinishTotalHeat())
                .courseVideoDetailInfos(exerciseCoursePlanDO.getCourseVideoDetailInfos().stream().map(item -> CourseVideoDetailInfo.builder()
                        .startTime(item.getStartTime())
                        .endTime(item.getEndTime())
                        .heat(item.getHeat())
                        .build()).collect(Collectors.toList()))
                .exerciseAims(exerciseCoursePlanDO.getExerciseAims())
                .exerciseEquipments(exerciseCoursePlanDO.getExerciseEquipments())
                .exerciseFrequencyDesc(exerciseCoursePlanDO.getExerciseFrequencyDesc())
                .courseVideoM3u8P1080Url(qiniuClient.pm3u8(ProtocolEnum.HTTPS, exerciseCoursePlanDO.getCourseVideoM3u8P1080Key(), QiniuBucketEnum.JKYY_PRIVATE.getBucket(), Constants.VIDEO_LINK_VALID_TIME))
                .courseVideoM3u8P720Url(qiniuClient.pm3u8(ProtocolEnum.HTTPS, exerciseCoursePlanDO.getCourseVideoM3u8P720Key(), QiniuBucketEnum.JKYY_PRIVATE.getBucket(), Constants.VIDEO_LINK_VALID_TIME))
                .courseVideoM3u8P480Url(qiniuClient.pm3u8(ProtocolEnum.HTTPS, exerciseCoursePlanDO.getCourseVideoM3u8P480Key(), QiniuBucketEnum.JKYY_PRIVATE.getBucket(), Constants.VIDEO_LINK_VALID_TIME))
                .courseDate(exerciseCoursePlanDO.getCourseDate())
                .build();
    }

    /**
     * 构建课程计划信息v2
     *
     * @param exerciseCoursePlanDO 请求参数
     * @return ExerciseCoursePlanInfoVO2
     */
    public static ExerciseCoursePlanInfoVO2 buildExerciseCoursePlanInfoVO2(ExerciseCoursePlanDO exerciseCoursePlanDO, Long expireTime, String replaceAddress) {
        SystemExerciseInfo systemExerciseInfo = exerciseCoursePlanDO.getSystemExerciseInfo();
        List<ExerciseBaseInfo> moreExerciseList = systemExerciseInfo.getMoreExerciseList();
        for (ExerciseBaseInfo exerciseBaseInfo : moreExerciseList) {
            exerciseBaseInfo.setImageUrl(exerciseBaseInfo.getImageKey());
        }
        systemExerciseInfo.setMoreExerciseList(moreExerciseList);
        List<ExerciseBaseInfo> recommendExerciseList = systemExerciseInfo.getRecommendExerciseList();
        for (ExerciseBaseInfo exerciseBaseInfo : recommendExerciseList) {
            exerciseBaseInfo.setImageUrl(exerciseBaseInfo.getImageKey());
        }
        systemExerciseInfo.setRecommendExerciseList(recommendExerciseList);
        exerciseCoursePlanDO.setSystemExerciseInfo(systemExerciseInfo);

        // 只有视频课程
        if (exerciseCoursePlanDO.getActionCount() != null && exerciseCoursePlanDO.getSystemExerciseInfo() == null) {
            return buildVideoExercise(exerciseCoursePlanDO, expireTime, replaceAddress);
        }
        // 只有系统课程
        if (exerciseCoursePlanDO.getActionCount() == null && exerciseCoursePlanDO.getSystemExerciseInfo() != null) {
            return buildSystemExercise(exerciseCoursePlanDO);
        }

        // 视频课程、系统课程都有
        QiniuClient qiniuClient = QiniuClient.getClient(QiniuBucketEnum.JKYY_PRIVATE.getBucket());
        Long finalExpireTime = expireTime == null ? Constants.VIDEO_LINK_VALID_TIME : expireTime;
        List<ActionExplainInfo> actionExplainInfos = null;
        if (CollectionUtils.isNotEmpty(exerciseCoursePlanDO.getActionExplains())) {
            actionExplainInfos = exerciseCoursePlanDO.getActionExplains().stream().map(xx ->
                    ActionExplainInfo.builder()
                            .actionId(xx.getActionId())
                            .actionImageUrl(xx.getActionImageKey())
                            .actionName(xx.getActionName())
                            .actionExplains(xx.getActionExplains())
                            .videoDurationSecond(xx.getVideoDurationSecond())
                            .attentions(xx.getAttentions())
                            //.actionVideoMP4Url(StringUtils.isBlank(xx.getVideoMP4Key()) ? null : qiniuClient.fileKeyToFileUrl(ProtocolEnum.HTTPS, new QiniuKey(xx.getVideoMP4Key()), finalExpireTime))
                            .actionVideoM3u8P1080Url(qiniuClient.getDomain() + (StringUtils.isEmpty(xx.getActionVideoM3u8P1080Key()) ? "" : xx.getActionVideoM3u8P1080Key().split("\\?")[0]))
                            .actionVideoM3u8P720Url(qiniuClient.getDomain() + (StringUtils.isEmpty(xx.getActionVideoM3u8P1080Key()) ? "" : xx.getActionVideoM3u8P720Key().split("\\?")[0]))
                            .actionVideoM3u8P480Url(qiniuClient.getDomain() + (StringUtils.isEmpty(xx.getActionVideoM3u8P1080Key()) ? "" : xx.getActionVideoM3u8P480Key().split("\\?")[0]))
                            .build()
            ).collect(Collectors.toList());
        }

//        if (CollectionUtils.isNotEmpty(exerciseCoursePlanDO.getActionExplains())) {
//            actionExplainInfos = exerciseCoursePlanDO.getActionExplains().stream().map(xx ->
//                    ActionExplainInfo.builder()
//                            .actionId(xx.getActionId())
//                            .actionImageUrl(xx.getActionImageKey())
//                            .actionName(xx.getActionName())
//                            .actionExplains(xx.getActionExplains())
//                            .videoDurationSecond(xx.getVideoDurationSecond())
//                            .attentions(xx.getAttentions())
//                            //.actionVideoMP4Url(StringUtils.isBlank(xx.getVideoMP4Key()) ? null : qiniuClient.fileKeyToFileUrl(ProtocolEnum.HTTPS, new QiniuKey(xx.getVideoMP4Key()), finalExpireTime))
//                            .actionVideoM3u8P1080Url(StringUtils.isBlank(replaceAddress) ? qiniuClient.pm3u8(ProtocolEnum.HTTPS, xx.getActionVideoM3u8P1080Key(), QiniuBucketEnum.JKYY_PRIVATE.getBucket(), finalExpireTime) : qiniuClient.fileKeyToFileUrl(ProtocolEnum.HTTPS, new QiniuKey(xx.getActionVideoM3u8P1080Key()), finalExpireTime))
//                            .actionVideoM3u8P720Url(StringUtils.isBlank(replaceAddress) ? qiniuClient.pm3u8(ProtocolEnum.HTTPS, xx.getActionVideoM3u8P720Key(), QiniuBucketEnum.JKYY_PRIVATE.getBucket(), finalExpireTime) : qiniuClient.fileKeyToFileUrl(ProtocolEnum.HTTPS, new QiniuKey(xx.getActionVideoM3u8P720Key()), finalExpireTime))
//                            .actionVideoM3u8P480Url(StringUtils.isBlank(replaceAddress) ? qiniuClient.pm3u8(ProtocolEnum.HTTPS, xx.getActionVideoM3u8P480Key(), QiniuBucketEnum.JKYY_PRIVATE.getBucket(), finalExpireTime) : qiniuClient.fileKeyToFileUrl(ProtocolEnum.HTTPS, new QiniuKey(xx.getActionVideoM3u8P480Key()), finalExpireTime))
//                            .build()
//            ).collect(Collectors.toList());
//        }
        // log.info("exerciseCoursePlanDO.getCourseVideoM3u8P1080Key(),{}", exerciseCoursePlanDO.getCourseVideoM3u8P1080Key());
        //  log.info("exerciseCoursePlanDO.getCourseVideoM3u8P720Key(),{}", exerciseCoursePlanDO.getCourseVideoM3u8P720Key());
        //  log.info("exerciseCoursePlanDO.getCourseVideoM3u8P480Key(),{}", exerciseCoursePlanDO.getCourseVideoM3u8P480Key());
        return ExerciseCoursePlanInfoVO2.builder()
                .courseId(exerciseCoursePlanDO.getCourseId())
                .courseDate(exerciseCoursePlanDO.getCourseDate())
                .attentionItems(exerciseCoursePlanDO.getAttentionItems())
                .exerciseAims(exerciseCoursePlanDO.getExerciseAims())
                .exerciseFrequencyDesc(exerciseCoursePlanDO.getExerciseFrequencyDesc())
                .videoExerciseInfo(VideoExerciseInfo.builder()
                        .actionCount(exerciseCoursePlanDO.getActionCount())
                        .actionExplains(actionExplainInfos)
                        .courseDurationMinute(exerciseCoursePlanDO.getCourseDurationMinute())
                        .courseDurationSecond(exerciseCoursePlanDO.getCourseDurationSecond())
                        .courseFinishDetails(exerciseCoursePlanDO.getCourseFinishDetails())
//                        .courseHeat(exerciseCoursePlanDO.getCourseHeat())
                        .courseHeat(BigDecimal.valueOf(exerciseCoursePlanDO.getCourseHeat()).setScale(3,BigDecimal.ROUND_HALF_UP).doubleValue())
                        .courseImageUrl(exerciseCoursePlanDO.getCourseImageKey())
                        .courseFinishTotalDuration(exerciseCoursePlanDO.getCourseFinishTotalDuration())
                        .courseFinishTotalHeat(exerciseCoursePlanDO.getCourseFinishTotalHeat())
                        .courseVideoDetailInfos(exerciseCoursePlanDO.getCourseVideoDetailInfos().stream().map(item -> CourseVideoDetailInfo.builder()
                                .startTime(item.getStartTime())
                                .endTime(item.getEndTime())
                                .heat(item.getHeat())
                                .build()).collect(Collectors.toList()))
                        .exerciseEquipments(exerciseCoursePlanDO.getExerciseEquipments())
                        .courseVideoM3u8P1080Url(StringUtils.isBlank(replaceAddress) ? qiniuClient.pm3u8(ProtocolEnum.HTTPS, exerciseCoursePlanDO.getCourseVideoM3u8P1080Key(), QiniuBucketEnum.JKYY_PRIVATE.getBucket(), finalExpireTime) : qiniuClient.fileKeyToFileUrl(ProtocolEnum.HTTPS, new QiniuKey(exerciseCoursePlanDO.getCourseVideoM3u8P1080Key()), finalExpireTime))
                        .courseVideoM3u8P720Url(StringUtils.isBlank(replaceAddress) ? qiniuClient.pm3u8(ProtocolEnum.HTTPS, exerciseCoursePlanDO.getCourseVideoM3u8P720Key(), QiniuBucketEnum.JKYY_PRIVATE.getBucket(), finalExpireTime) : qiniuClient.fileKeyToFileUrl(ProtocolEnum.HTTPS, new QiniuKey(exerciseCoursePlanDO.getCourseVideoM3u8P720Key()), finalExpireTime))
                        .courseVideoM3u8P480Url(StringUtils.isBlank(replaceAddress) ? qiniuClient.pm3u8(ProtocolEnum.HTTPS, exerciseCoursePlanDO.getCourseVideoM3u8P480Key(), QiniuBucketEnum.JKYY_PRIVATE.getBucket(), finalExpireTime) : qiniuClient.fileKeyToFileUrl(ProtocolEnum.HTTPS, new QiniuKey(exerciseCoursePlanDO.getCourseVideoM3u8P480Key()), finalExpireTime))
                        .build())
                .systemExerciseInfo(exerciseCoursePlanDO.getSystemExerciseInfo())
                .build();
    }

    /**
     * 构建视频运动信息
     *
     * @param exerciseCoursePlanDO 请求参数
     * @return ExerciseCoursePlanInfoVO2
     */
    private static ExerciseCoursePlanInfoVO2 buildVideoExercise(ExerciseCoursePlanDO exerciseCoursePlanDO, Long expireTime, String replaceAddress) {
        QiniuClient qiniuClient = QiniuClient.getClient(QiniuBucketEnum.JKYY_PRIVATE.getBucket());
        Long finalExpireTime = expireTime == null ? Constants.VIDEO_LINK_VALID_TIME : expireTime;
        List<ActionExplainInfo> actionExplainInfos = null;
        if (CollectionUtils.isNotEmpty(exerciseCoursePlanDO.getActionExplains())) {
            actionExplainInfos = exerciseCoursePlanDO.getActionExplains().stream().map(xx ->
                    ActionExplainInfo.builder()
                            .actionImageUrl(xx.getActionImageKey())
                            .actionName(xx.getActionName())
                            .actionExplains(xx.getActionExplains())
                            .videoDurationSecond(xx.getVideoDurationSecond())
                            .attentions(xx.getAttentions())
                            //.actionVideoMP4Url(StringUtils.isBlank(xx.getVideoMP4Key()) ? null : qiniuClient.fileKeyToFileUrl(ProtocolEnum.HTTPS, new QiniuKey(xx.getVideoMP4Key()), finalExpireTime))
                            .actionVideoM3u8P1080Url(StringUtils.isBlank(replaceAddress) ? qiniuClient.pm3u8(ProtocolEnum.HTTPS, xx.getActionVideoM3u8P1080Key(), QiniuBucketEnum.JKYY_PRIVATE.getBucket(), finalExpireTime) : qiniuClient.fileKeyToFileUrl(ProtocolEnum.HTTPS, new QiniuKey(xx.getActionVideoM3u8P1080Key()), finalExpireTime))
                            .actionVideoM3u8P720Url(StringUtils.isBlank(replaceAddress) ? qiniuClient.pm3u8(ProtocolEnum.HTTPS, xx.getActionVideoM3u8P720Key(), QiniuBucketEnum.JKYY_PRIVATE.getBucket(), finalExpireTime) : qiniuClient.fileKeyToFileUrl(ProtocolEnum.HTTPS, new QiniuKey(xx.getActionVideoM3u8P720Key()), finalExpireTime))
                            .actionVideoM3u8P480Url(StringUtils.isBlank(replaceAddress) ? qiniuClient.pm3u8(ProtocolEnum.HTTPS, xx.getActionVideoM3u8P480Key(), QiniuBucketEnum.JKYY_PRIVATE.getBucket(), finalExpireTime) : qiniuClient.fileKeyToFileUrl(ProtocolEnum.HTTPS, new QiniuKey(xx.getActionVideoM3u8P480Key()), finalExpireTime))
                            .build()
            ).collect(Collectors.toList());
        }

        return ExerciseCoursePlanInfoVO2.builder()
                .courseId(exerciseCoursePlanDO.getCourseId())
                .courseDate(exerciseCoursePlanDO.getCourseDate())
                .attentionItems(exerciseCoursePlanDO.getAttentionItems())
                .exerciseAims(exerciseCoursePlanDO.getExerciseAims())
                .exerciseFrequencyDesc(exerciseCoursePlanDO.getExerciseFrequencyDesc())
                .videoExerciseInfo(VideoExerciseInfo.builder()
                        .actionCount(exerciseCoursePlanDO.getActionCount())
                        .actionExplains(actionExplainInfos)
                        .courseDurationMinute(exerciseCoursePlanDO.getCourseDurationMinute())
                        .courseDurationSecond(exerciseCoursePlanDO.getCourseDurationSecond())
                        .courseFinishDetails(exerciseCoursePlanDO.getCourseFinishDetails())
                        .courseFinishDetails(exerciseCoursePlanDO.getCourseFinishDetails())
                        .courseHeat(BigDecimal.valueOf(exerciseCoursePlanDO.getCourseHeat()).setScale(3,BigDecimal.ROUND_HALF_UP).doubleValue())
                        .courseImageUrl(exerciseCoursePlanDO.getCourseImageKey())
                        .courseFinishTotalDuration(exerciseCoursePlanDO.getCourseFinishTotalDuration())
                        .courseFinishTotalHeat(exerciseCoursePlanDO.getCourseFinishTotalHeat())
                        .courseVideoDetailInfos(exerciseCoursePlanDO.getCourseVideoDetailInfos().stream().map(item -> CourseVideoDetailInfo.builder()
                                .startTime(item.getStartTime())
                                .endTime(item.getEndTime())
                                .heat(item.getHeat())
                                .build()).collect(Collectors.toList()))
                        .exerciseEquipments(exerciseCoursePlanDO.getExerciseEquipments())
                        .courseVideoM3u8P1080Url(StringUtils.isBlank(replaceAddress) ? qiniuClient.pm3u8(ProtocolEnum.HTTPS, exerciseCoursePlanDO.getCourseVideoM3u8P1080Key(), QiniuBucketEnum.JKYY_PRIVATE.getBucket(), finalExpireTime) : qiniuClient.fileKeyToFileUrl(ProtocolEnum.HTTPS, new QiniuKey(exerciseCoursePlanDO.getCourseVideoM3u8P1080Key()), finalExpireTime))
                        .courseVideoM3u8P720Url(StringUtils.isBlank(replaceAddress) ? qiniuClient.pm3u8(ProtocolEnum.HTTPS, exerciseCoursePlanDO.getCourseVideoM3u8P720Key(), QiniuBucketEnum.JKYY_PRIVATE.getBucket(), finalExpireTime) : qiniuClient.fileKeyToFileUrl(ProtocolEnum.HTTPS, new QiniuKey(exerciseCoursePlanDO.getCourseVideoM3u8P720Key()), finalExpireTime))
                        .courseVideoM3u8P480Url(StringUtils.isBlank(replaceAddress) ? qiniuClient.pm3u8(ProtocolEnum.HTTPS, exerciseCoursePlanDO.getCourseVideoM3u8P480Key(), QiniuBucketEnum.JKYY_PRIVATE.getBucket(), finalExpireTime) : qiniuClient.fileKeyToFileUrl(ProtocolEnum.HTTPS, new QiniuKey(exerciseCoursePlanDO.getCourseVideoM3u8P480Key()), finalExpireTime))
                        .build())
                .build();
    }

    /**
     * 构建系统（非视频）运动信息
     *
     * @param exerciseCoursePlanDO 请求参数
     * @return ExerciseCoursePlanInfoVO2
     */
    private static ExerciseCoursePlanInfoVO2 buildSystemExercise(ExerciseCoursePlanDO exerciseCoursePlanDO) {
        return ExerciseCoursePlanInfoVO2.builder()
                .courseId(exerciseCoursePlanDO.getCourseId())
                .courseDate(exerciseCoursePlanDO.getCourseDate())
                .exerciseFrequencyDesc(exerciseCoursePlanDO.getExerciseFrequencyDesc())
                .exerciseAims(exerciseCoursePlanDO.getExerciseAims())
                .attentionItems(exerciseCoursePlanDO.getAttentionItems())
                .systemExerciseInfo(exerciseCoursePlanDO.getSystemExerciseInfo())
                .build();

    }


}
