package com.jiankangyouyi.cloud.motorplan.model.dto;

import com.jiankangyouyi.cloud.motorplan.enums.BodyExerciseEvaluationStatusEnum;
import com.jiankangyouyi.cloud.motorplan.model.dto.api.AbstractHttpApiRequestDTO;
import com.jiankangyouyi.cloud.motorplan.model.entity.mongo.component.DiseaseInfo;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;

import javax.validation.Valid;
import javax.validation.constraints.*;
import java.util.List;

/**
 * @author ：wangyalei
 * @date ：Created in 2021/6/21 3:23 下午
 */
@EqualsAndHashCode(callSuper = true)
@Data
@AllArgsConstructor
@NoArgsConstructor
public class AcquireCoursePlanDTO extends AbstractHttpApiRequestDTO {
    /**
     * 用户id
     */
    @NotBlank(message = "请求参数 userId 不能为空")
    @Size(max = 32,message = "请求参数 userId 超过最大有效长度 32")
    private String userId;
    /**
     * 是否强制替换 true 是 false 否
     */
    private Boolean forceReplace = false;
    /**
     * 出生日期 / yyyy-MM-dd
     */
    @NotBlank(message = "请求参数 birthday 不能为空")
    @Size(min = 10,max = 10,message = "请求参数 birthday 有效长度 10")
    private String birthday;
    /**
     * 体重 /kg
     */
    @NotNull(message = "请求参数 weight 不能为空")
    @Min(value = 10,message = "请求参数 weight 低于最小有效值 10")
    @Max(value = 200,message = "请求参数 weight 大于最大有效值 200")
    private Double weight;
    /**
     * 性别  1、男 2、女
     */
    @NotBlank(message = "请求参数 gender 不能为空")
    @Size(max = 1,message = "请求参数 gender 超过最大有效长度 1")
    private String gender;
    /**
     * 身高 /cm
     */
    @NotNull(message = "请求参数 height 不能为空")
    @Min(value = 50,message = "请求参数 height 低于最小有效值 50")
    @Max(value = 230,message = "请求参数 height 大于最大有效值 230")
    private Integer height;

    /**
     * 运动能力 1、低 2、中 3、高
     */
    private Integer athleticAbility = 1;
    /**
     * 配课热量
     */
    @Min(value = 0,message = "请求参数 heat 小于最小值 0")
    private Integer heat;
    /**
     * 疾病信息
     */
    @Valid
    private List<DiseaseInfo> diseaseInfoList;
    /**
     * 器械名称
     */
    private List<String> equipments;
    /**
     * 亚健康/健康 人群 true 、是 false 否
     */
    @NotNull(message = "请求参数 healthyPerson 不能为空")
    private Boolean healthyPerson;

    /**
     * 课程日期 / yyyy-MM-dd
     */
    @Size(min = 10,max = 10,message = "请求参数 courseDate 有效长度 10")
    private String courseDate;
    /**
     * 动作禁忌类型 {@link com.jiankangyouyi.cloud.basedata.api.enums.action.ActionFeatureEnum}
     */
    private List<String> actionTaboos;
    /**
     * 用户身体运动评估状态 / 默认正常 {@link com.jiankangyouyi.cloud.motorplan.enums.BodyExerciseEvaluationStatusEnum}
     */
    private String bodyExerciseEvaluationStatus = BodyExerciseEvaluationStatusEnum.NORMAL.getStatus();

    /**
     * 配置ID
     */
    private String configId;

    /**
     * 分娩日期 / yyyy-MM-dd
     */
    @Size(min = 10,max = 10,message = "请求参数 deliveryDate 有效长度 10")
    private String deliveryDate;

    /**
     * 教练性别 1、男 2、女
     */
    @Size(max = 1,message = "请求参数 coachGender 有效长度 1")
    private String coachGender = "2";
    /**
     * 运动水平 1、低 2、中 3、高
     */
    private Integer exerciseLevel = 1;



}
