package com.jiankangyouyi.cloud.motorplan.model.dto;

import com.jiankangyouyi.cloud.core.entity.page.Page;
import com.jiankangyouyi.cloud.core.validator.annotation.EnumHC;
import com.jiankangyouyi.cloud.data.center.api.enums.ExerciseLevelEnum;
import com.jiankangyouyi.cloud.motorplan.enums.DiseaseEnum;
import com.jiankangyouyi.cloud.motorplan.enums.GenderRealEnum;
import com.jiankangyouyi.cloud.motorplan.model.dto.api.AbstractHttpApiRequestDTO;
import lombok.Data;
import lombok.EqualsAndHashCode;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;

/**
 * 康复课程查询参数
 *
 * @author june
 */
@Data
@EqualsAndHashCode(callSuper = true)
public class RecoveryCourseQueryParamDTO extends AbstractHttpApiRequestDTO {

    /**
     * 健康问题类型（课程分类）
     */
    @EnumHC(enumTypes = DiseaseEnum.class, message = "请求参数 diseaseType 不合法")
    private String diseaseType;
    /**
     * 课程难度 1-低2-中3-高
     */
    @EnumHC(enumTypes = ExerciseLevelEnum.class, message = "请求参数 courseDifficulties 不合法")
    private Integer courseDifficulties;
    /**
     * 课程强度 1-低2-中3-高
     */
    @EnumHC(enumTypes = ExerciseLevelEnum.class, message = "请求参数 courseIntensity 不合法")
    private Integer courseIntensity;

    /**
     * 教练性别
     */
    @EnumHC(enumTypes = GenderRealEnum.class, message = "请求参数 coachGender 不合法")
    private String coachGender;


    @NotNull(message = "请求参数page不能为空")
    @Valid
    private Page page;
}
