package com.jiankangyouyi.cloud.motorplan.model.entity.mongo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.core.base.enums.ValidStatusEnum;
import com.jiankangyouyi.cloud.motorplan.model.entity.mongo.component.ExerciseCoursePlan;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;

/**
 * 运动课程计划
 * @author ：wangyalei
 * @date ：Created in 2021/6/29 10:47 下午
 */
@Data
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
@Document(collection = "exercise.course.plan")
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "classifyId_-1",
                        def = "{'appId' : -1,'userId': -1 ,'courseDate': -1}"
                ),
                @CompoundIndex(
                        name = "updateTime_-1",
                        def = "{ 'updateTime' : -1}"
                ),
        }
)
public class ExerciseCoursePlanDO extends ExerciseCoursePlan {
    private static final long serialVersionUID = 1L;

    public static final String FIELD_DATE = "date";
    public static final String FIELD_ID = "_id";
    public static final String FIELD_VALIDSTATUS = "validStatus";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";


    @Id
    private ObjectId id;
    /**
     * 1、有效(有实际的课程方案) 2、无效(无有效的课程方案，仅保存用户获取方案的请求参数) 其他、（逻辑产出）
     */
    private String validStatus;

    @DateTimeFormat(
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    @JsonFormat(
            timezone = "GMT+8",
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    private Date updateTime;
    @DateTimeFormat(
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    @JsonFormat(
            timezone = "GMT+8",
            pattern = "yyyy-MM-dd HH:mm:ss"
    )

    @Indexed()
    private Date createTime;



    public ExerciseCoursePlanDO() {
        Date date = new Date();
        this.validStatus = ValidStatusEnum.VALID.getCode();
        this.updateTime = date;
        this.createTime = date;
    }

}
