package com.jiankangyouyi.cloud.motorplan.model.entity.mongo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.motorplan.api.model.dto.response.component.SystemExerciseInfo;
import com.jiankangyouyi.cloud.motorplan.model.entity.mongo.component.ActionExplain;
import com.jiankangyouyi.cloud.motorplan.model.entity.mongo.component.ActionVideoDetailInfo;
import lombok.AllArgsConstructor;
import lombok.Data;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;
import java.util.List;

/**
 * 运动计划测试工具数据记录表
 * @author ：wangyalei
 * @date ：Created in 2021/7/19 5:16 下午
 */
@Data
@AllArgsConstructor
@Document(collection = "exercise.course.plan.test.tool.record")
public class ExerciseCoursePlanTestToolRecordDO {

    @Id
    private ObjectId id;

    @DateTimeFormat(
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    @JsonFormat(
            timezone = "GMT+8",
            pattern = "yyyy-MM-dd HH:mm:ss"
    )

    @Indexed()
    private Date createTime;
    /**
     * 课程Id
     */
    @Indexed(unique = true)
    private String courseId;
    /**
     * 用户BMI
     */
    private Double bmi;
    /**
     * 训练动作组合类型编号
     */
    private String currentTrainingActionTypeNum;
    /**
     * 健康/亚健康人群 true 是 false 否
     */
    private Boolean healthyPerson;
    /**
     * 疾病类型
     */
    private String diseaseType;
    /**
     * 风险等级
     */
    private List<Integer> riskLevel;
    /**
     * 分娩日期
     */
    private String deliveryDate;
    /**
     * 动作难度 1、一级 2、二级 3、三级 4、四级 5、五级
     */
    private List<String> actionDifficulties;
    /**
     * 动作个数
     */
    private Integer actionCount;
    /**
     * 课程时长 /分
     */
    private Integer courseDurationMinute;
    /**
     * 课程时长 /秒
     */
    private Integer courseDurationSecond;
    /**
     * 课程热量
     */
    private Double courseHeat;
    /**
     * 运动频率描述
     */
    private String exerciseFrequencyDesc;
    /**
     * 课程使用的运动器材
     */
    private List<String> exerciseEquipments;
    /**
     * 禁忌动作
     */
    private List<String> forbidActionProperties;
    /**
     * 注意事项
     */
    private List<String> attentionItems;
    /**
     * 运动目标
     */
    private List<String> exerciseAims;
    /**
     * 动作讲解
     */
    private List<ActionExplain> actionExplains;
    /**
     * 热身动作总时间 /s
     */
    private Long warmupTotalTime;
    /**
     * 热身动作产生总热量
     */
    private Double warmupTotalHeat;
    /**
     * 热身动作视频列表
     */
    private List<ActionVideoDetailInfo> warmupVideos;
    /**
     * 训练动作总时间 /s
     */
    private Long trainingTotalTime;
    /**
     * 训练动作产生总热量
     */
    private Double trainingTotalHeat;
    /**
     * 训练动作视频列表
     */
    private List<ActionVideoDetailInfo> trainingVideos;
    /**
     * 拉伸动作总时间 /s
     */
    private Long stretchTotalTime;
    /**
     * 拉伸动作产生总热量
     */
    private Double stretchTotalHeat;
    /**
     * 拉伸动作视频列表
     */
    private List<ActionVideoDetailInfo> stretchVideos;
    /**
     * 休息视频总时间 /s
     */
    private Long restVideoTotalTime;
    /**
     * 休息视频个数
     */
    private Integer restVideoCount;
    /**
     * 课程封面图
     */
    private String courseImageKey;
    /**
     * 课程视频 1080 分辨率   m3u8 文件地址key
     */
    private String courseVideoM3u8P1080Key;
    /**
     * 课程视频 720 分辨率   m3u8 文件地址key
     */
    private String courseVideoM3u8P720Key;
    /**
     * 课程视频 480 分辨率   m3u8 文件地址key
     */
    private String courseVideoM3u8P480Key;
    /**
     * 系统运动信息（非视频课程方案）
     */
    private SystemExerciseInfo systemExerciseInfo;



    public ExerciseCoursePlanTestToolRecordDO() {
        this.createTime = new Date();
    }

    public static final String FIELD_ID = "_id";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_COURSEID = "courseId";
    public static final String FIELD_BMI = "bmi";
    public static final String FIELD_CURRENTTRAININGACTIONTYPENUM = "currentTrainingActionTypeNum";
    public static final String FIELD_HEALTHYPERSON = "healthyPerson";
    public static final String FIELD_DISEASETYPE = "diseaseType";
    public static final String FIELD_RISKLEVEL = "riskLevel";
    public static final String FIELD_ACTIONDIFFICULTIES = "actionDifficulties";
    public static final String FIELD_ACTIONCOUNT = "actionCount";
    public static final String FIELD_COURSEDURATIONMINUTE = "courseDurationMinute";
    public static final String FIELD_COURSEDURATIONSECOND = "courseDurationSecond";
    public static final String FIELD_COURSEHEAT = "courseHeat";
    public static final String FIELD_EXERCISEFREQUENCYDESC = "exerciseFrequencyDesc";
    public static final String FIELD_EXERCISEEQUIPMENTS = "exerciseEquipments";
    public static final String FIELD_FORBIDACTIONPROPERTIES = "forbidActionProperties";
    public static final String FIELD_ATTENTIONITEMS = "attentionItems";
    public static final String FIELD_EXERCISEAIMS = "exerciseAims";
    public static final String FIELD_ACTIONEXPLAINS = "actionExplains";
    public static final String FIELD_ACTIONEXPLAINS_VIDEODURATIONSECOND = "actionExplains.videoDurationSecond";
    public static final String FIELD_ACTIONEXPLAINS_ACTIONIMAGEKEY = "actionExplains.actionImageKey";
    public static final String FIELD_ACTIONEXPLAINS_ATTENTIONS = "actionExplains.attentions";
    public static final String FIELD_ACTIONEXPLAINS_ACTIONEXPLAINS = "actionExplains.actionExplains";
    public static final String FIELD_ACTIONEXPLAINS_ACTIONNAME = "actionExplains.actionName";
    public static final String FIELD_ACTIONEXPLAINS_ACTIONVIDEOM3U8P1080KEY = "actionExplains.actionVideoM3u8P1080Key";
    public static final String FIELD_ACTIONEXPLAINS_ACTIONVIDEOM3U8P720KEY = "actionExplains.actionVideoM3u8P720Key";
    public static final String FIELD_ACTIONEXPLAINS_ACTIONVIDEOM3U8P480KEY = "actionExplains.actionVideoM3u8P480Key";
    public static final String FIELD_WARMUPTOTALTIME = "warmupTotalTime";
    public static final String FIELD_WARMUPTOTALHEAT = "warmupTotalHeat";
    public static final String FIELD_WARMUPVIDEOS = "warmupVideos";
    public static final String FIELD_WARMUPVIDEOS_ACTIONID = "warmupVideos.actionId";
    public static final String FIELD_WARMUPVIDEOS_VIDEOTS1080 = "warmupVideos.videoTs1080";
    public static final String FIELD_WARMUPVIDEOS_VIDEOTS720 = "warmupVideos.videoTs720";
    public static final String FIELD_WARMUPVIDEOS_VIDEOTS480 = "warmupVideos.videoTs480";
    public static final String FIELD_WARMUPVIDEOS_ACTIONDIFFICULTY = "warmupVideos.actionDifficulty";
    public static final String FIELD_WARMUPVIDEOS_ACTIONFEATURES = "warmupVideos.actionFeatures";
    public static final String FIELD_WARMUPVIDEOS_ACTIONCLASSIFICATION = "warmupVideos.actionClassification";
    public static final String FIELD_WARMUPVIDEOS_ACTIONPOSITION = "warmupVideos.actionPosition";
    public static final String FIELD_WARMUPVIDEOS_TRAINPOSITIONS = "warmupVideos.trainPositions";
    public static final String FIELD_WARMUPVIDEOS_ACTIONVIDEOSIZE = "warmupVideos.actionVideoSize";
    public static final String FIELD_WARMUPVIDEOS_HEAT = "warmupVideos.heat";
    public static final String FIELD_WARMUPVIDEOS_ACTIONNAME = "warmupVideos.actionName";
    public static final String FIELD_WARMUPVIDEOS_TIMESECONDS = "warmupVideos.timeSeconds";
    public static final String FIELD_TRAININGTOTALTIME = "trainingTotalTime";
    public static final String FIELD_TRAININGTOTALHEAT = "trainingTotalHeat";
    public static final String FIELD_TRAININGVIDEOS = "trainingVideos";
    public static final String FIELD_TRAININGVIDEOS_ACTIONID = "trainingVideos.actionId";
    public static final String FIELD_TRAININGVIDEOS_VIDEOTS1080 = "trainingVideos.videoTs1080";
    public static final String FIELD_TRAININGVIDEOS_VIDEOTS720 = "trainingVideos.videoTs720";
    public static final String FIELD_TRAININGVIDEOS_VIDEOTS480 = "trainingVideos.videoTs480";
    public static final String FIELD_TRAININGVIDEOS_ACTIONDIFFICULTY = "trainingVideos.actionDifficulty";
    public static final String FIELD_TRAININGVIDEOS_ACTIONFEATURES = "trainingVideos.actionFeatures";
    public static final String FIELD_TRAININGVIDEOS_ACTIONCLASSIFICATION = "trainingVideos.actionClassification";
    public static final String FIELD_TRAININGVIDEOS_ACTIONPOSITION = "trainingVideos.actionPosition";
    public static final String FIELD_TRAININGVIDEOS_TRAINPOSITIONS = "trainingVideos.trainPositions";
    public static final String FIELD_TRAININGVIDEOS_ACTIONVIDEOSIZE = "trainingVideos.actionVideoSize";
    public static final String FIELD_TRAININGVIDEOS_HEAT = "trainingVideos.heat";
    public static final String FIELD_TRAININGVIDEOS_ACTIONNAME = "trainingVideos.actionName";
    public static final String FIELD_TRAININGVIDEOS_TIMESECONDS = "trainingVideos.timeSeconds";
    public static final String FIELD_STRETCHTOTALTIME = "stretchTotalTime";
    public static final String FIELD_STRETCHTOTALHEAT = "stretchTotalHeat";
    public static final String FIELD_STRETCHVIDEOS = "stretchVideos";
    public static final String FIELD_STRETCHVIDEOS_ACTIONID = "stretchVideos.actionId";
    public static final String FIELD_STRETCHVIDEOS_VIDEOTS1080 = "stretchVideos.videoTs1080";
    public static final String FIELD_STRETCHVIDEOS_VIDEOTS720 = "stretchVideos.videoTs720";
    public static final String FIELD_STRETCHVIDEOS_VIDEOTS480 = "stretchVideos.videoTs480";
    public static final String FIELD_STRETCHVIDEOS_ACTIONDIFFICULTY = "stretchVideos.actionDifficulty";
    public static final String FIELD_STRETCHVIDEOS_ACTIONFEATURES = "stretchVideos.actionFeatures";
    public static final String FIELD_STRETCHVIDEOS_ACTIONCLASSIFICATION = "stretchVideos.actionClassification";
    public static final String FIELD_STRETCHVIDEOS_ACTIONPOSITION = "stretchVideos.actionPosition";
    public static final String FIELD_STRETCHVIDEOS_TRAINPOSITIONS = "stretchVideos.trainPositions";
    public static final String FIELD_STRETCHVIDEOS_ACTIONVIDEOSIZE = "stretchVideos.actionVideoSize";
    public static final String FIELD_STRETCHVIDEOS_HEAT = "stretchVideos.heat";
    public static final String FIELD_STRETCHVIDEOS_ACTIONNAME = "stretchVideos.actionName";
    public static final String FIELD_STRETCHVIDEOS_TIMESECONDS = "stretchVideos.timeSeconds";
    public static final String FIELD_RESTVIDEOTOTALTIME = "restVideoTotalTime";
    public static final String FIELD_RESTVIDEOCOUNT = "restVideoCount";
    public static final String FIELD_COURSEIMAGEKEY = "courseImageKey";
    public static final String FIELD_COURSEVIDEOM3U8P1080KEY = "courseVideoM3u8P1080Key";
    public static final String FIELD_COURSEVIDEOM3U8P720KEY = "courseVideoM3u8P720Key";
    public static final String FIELD_COURSEVIDEOM3U8P480KEY = "courseVideoM3u8P480Key";
    public static final String FIELD_SYSTEMEXERCISEINFO = "systemExerciseInfo";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST = "systemExerciseInfo.moreExerciseList";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_EXERCISEID = "systemExerciseInfo.moreExerciseList.exerciseId";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_MINCOUNT = "systemExerciseInfo.moreExerciseList.minCount";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_UNIT = "systemExerciseInfo.moreExerciseList.unit";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_MINCOUNTPRODUCEHEAT = "systemExerciseInfo.moreExerciseList.minCountProduceHeat";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_EXERCISETIMEMIN = "systemExerciseInfo.moreExerciseList.exerciseTimeMin";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_EXERCISETIMEMAX = "systemExerciseInfo.moreExerciseList.exerciseTimeMax";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_EXERCISEHEATMIN = "systemExerciseInfo.moreExerciseList.exerciseHeatMin";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_EXERCISEHEATMAX = "systemExerciseInfo.moreExerciseList.exerciseHeatMax";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_IMAGEKEY = "systemExerciseInfo.moreExerciseList.imageKey";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_EXERCISENAME = "systemExerciseInfo.moreExerciseList.exerciseName";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_EXERCISETYPE = "systemExerciseInfo.moreExerciseList.exerciseType";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_DESCRIPTIONS = "systemExerciseInfo.moreExerciseList.descriptions";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_ORDER = "systemExerciseInfo.moreExerciseList.order";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_MET = "systemExerciseInfo.moreExerciseList.met";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST = "systemExerciseInfo.recommendExerciseList";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_EXERCISEID = "systemExerciseInfo.recommendExerciseList.exerciseId";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_MINCOUNT = "systemExerciseInfo.recommendExerciseList.minCount";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_UNIT = "systemExerciseInfo.recommendExerciseList.unit";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_MINCOUNTPRODUCEHEAT = "systemExerciseInfo.recommendExerciseList.minCountProduceHeat";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_EXERCISETIMEMIN = "systemExerciseInfo.recommendExerciseList.exerciseTimeMin";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_EXERCISETIMEMAX = "systemExerciseInfo.recommendExerciseList.exerciseTimeMax";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_EXERCISEHEATMIN = "systemExerciseInfo.recommendExerciseList.exerciseHeatMin";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_EXERCISEHEATMAX = "systemExerciseInfo.recommendExerciseList.exerciseHeatMax";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_IMAGEKEY = "systemExerciseInfo.recommendExerciseList.imageKey";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_EXERCISENAME = "systemExerciseInfo.recommendExerciseList.exerciseName";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_EXERCISETYPE = "systemExerciseInfo.recommendExerciseList.exerciseType";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_DESCRIPTIONS = "systemExerciseInfo.recommendExerciseList.descriptions";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_ORDER = "systemExerciseInfo.recommendExerciseList.order";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_MET = "systemExerciseInfo.recommendExerciseList.met";
    public static final String FIELD_SYSTEMEXERCISEINFO_EXERCISEADVICES = "systemExerciseInfo.exerciseAdvices";




}
