package com.jiankangyouyi.cloud.motorplan.model.entity.mongo.component;

import com.jiankangyouyi.cloud.motorplan.api.model.dto.response.component.CourseFinishDetail;
import com.jiankangyouyi.cloud.motorplan.api.model.dto.response.component.SystemExerciseInfo;
import com.jiankangyouyi.cloud.motorplan.model.entity.mongo.component.v3.CourseVideoDetailInfo;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.data.mongodb.core.index.Indexed;

import java.util.List;

/**
 * @author ：wangyalei
 * @date ：Created in 2021/6/29 10:51 下午
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class ExerciseCoursePlan {
    /**
     * 用户Id
     */
    private String userId;
    /**
     * 应用Id
     */
    private String appId;
    /**
     * 课程Id
     */
    @Indexed(unique = true)
    private String courseId;
    /**
     * 课程日期 / yyyy-MM-dd
     */
    @Indexed
    private String courseDate;
    /**
     * 训练动作组合类型编号 （此字段 v2.4之后不再使用，慎用做业务逻辑）
     */
    private String nextTrainingActionTypeNum;
    /**
     * 用户信息
     */
    private UserInfo userInfo;
    /**
     * 动作个数
     */
    private Integer actionCount;
    /**
     * 课程时长 /分
     */
    private Integer courseDurationMinute;
    /**
     * 课程时长 /秒
     */
    private Integer courseDurationSecond;
    /**
     * 课程热量
     */
    private Double courseHeat;
    /**
     * 运动频率描述
     */
    private String exerciseFrequencyDesc;
    /**
     * 运动频率最小值 /天
     */
    private Integer exerciseFrequencyMinValue;
    /**
     * 运动频率最大值 /天
     */
    private Integer exerciseFrequencyMaxValue;
    /**
     * 用户选择的运动器材
     */
    private List<String> userChoiceExerciseEquipments;
    /**
     * 课程使用的运动器材
     */
    private List<String> exerciseEquipments;
    /**
     * 注意事项
     */
    private List<String> attentionItems;
    /**
     * 运动目标
     */
    private List<String> exerciseAims;
    /**
     * 课程封面图
     */
    private String courseImageKey;
    /**
     * 课程视频 1080 分辨率   m3u8 文件地址key
     */
    private String courseVideoM3u8P1080Key;
    /**
     * 课程视频 720 分辨率   m3u8 文件地址key
     */
    private String courseVideoM3u8P720Key;
    /**
     * 课程视频 480 分辨率   m3u8 文件地址key
     */
    private String courseVideoM3u8P480Key;
    /**
     * 课程视频详情
     */
    private List<CourseVideoDetailInfo> courseVideoDetailInfos;
    /**
     * 动作讲解
     */
    private List<ActionExplain> actionExplains;
    /**
     * 课程完成总热量
     */
    private Integer courseFinishTotalHeat;
    /**
     * 课程完成总时长 /s
     */
    private Integer courseFinishTotalDuration;
    /**
     * 课程完成详情信息
     */
    private List<CourseFinishDetail> courseFinishDetails;
    /**
     * 系统运动信息（非视频课程方案）
     */
    private SystemExerciseInfo systemExerciseInfo;


    public static final String FIELD_USERID = "userId";
    public static final String FIELD_APPID = "appId";
    public static final String FIELD_COURSEID = "courseId";
    public static final String FIELD_COURSEDATE = "courseDate";
    public static final String FIELD_NEXTTRAININGACTIONTYPENUM = "nextTrainingActionTypeNum";
    public static final String FIELD_USERINFO = "userInfo";
    public static final String FIELD_USERINFO_HEIGHT = "userInfo.height";
    public static final String FIELD_USERINFO_WEIGHT = "userInfo.weight";
    public static final String FIELD_USERINFO_BIRTHDAY = "userInfo.birthday";
    public static final String FIELD_USERINFO_GENDER = "userInfo.gender";
    public static final String FIELD_USERINFO_ATHLETICABILITY = "userInfo.athleticAbility";
    public static final String FIELD_USERINFO_HEALTHYPERSON = "userInfo.healthyPerson";
    public static final String FIELD_USERINFO_DISEASEINFOS = "userInfo.diseaseInfos";
    public static final String FIELD_USERINFO_DISEASEINFOS_ORDERNUM = "userInfo.diseaseInfos.orderNum";
    public static final String FIELD_USERINFO_DISEASEINFOS_DISEASETYPE = "userInfo.diseaseInfos.diseaseType";
    public static final String FIELD_USERINFO_DISEASEINFOS_RISKLEVEL = "userInfo.diseaseInfos.riskLevel";
    public static final String FIELD_USERINFO_ACTIONTABOOS = "userInfo.actionTaboos";
    public static final String FIELD_USERINFO_BODYEXERCISEEVALUATIONSTATUS = "userInfo.bodyExerciseEvaluationStatus";
    public static final String FIELD_USERINFO_EXERCISECONFIGINFO = "userInfo.exerciseConfigInfo";
    public static final String FIELD_ACTIONCOUNT = "actionCount";
    public static final String FIELD_COURSEDURATIONMINUTE = "courseDurationMinute";
    public static final String FIELD_COURSEDURATIONSECOND = "courseDurationSecond";
    public static final String FIELD_COURSEHEAT = "courseHeat";
    public static final String FIELD_EXERCISEFREQUENCYDESC = "exerciseFrequencyDesc";
    public static final String FIELD_USERCHOICEEXERCISEEQUIPMENTS = "userChoiceExerciseEquipments";
    public static final String FIELD_EXERCISEEQUIPMENTS = "exerciseEquipments";
    public static final String FIELD_ATTENTIONITEMS = "attentionItems";
    public static final String FIELD_EXERCISEAIMS = "exerciseAims";
    public static final String FIELD_COURSEIMAGEKEY = "courseImageKey";
    public static final String FIELD_COURSEVIDEOM3U8P1080KEY = "courseVideoM3u8P1080Key";
    public static final String FIELD_COURSEVIDEOM3U8P720KEY = "courseVideoM3u8P720Key";
    public static final String FIELD_COURSEVIDEOM3U8P480KEY = "courseVideoM3u8P480Key";
    public static final String FIELD_COURSEVIDEODETAILINFOS = "courseVideoDetailInfos";
    public static final String FIELD_COURSEVIDEODETAILINFOS_STARTTIME = "courseVideoDetailInfos.startTime";
    public static final String FIELD_COURSEVIDEODETAILINFOS_ENDTIME = "courseVideoDetailInfos.endTime";
    public static final String FIELD_COURSEVIDEODETAILINFOS_HEAT = "courseVideoDetailInfos.heat";
    public static final String FIELD_ACTIONEXPLAINS = "actionExplains";
    public static final String FIELD_ACTIONEXPLAINS_VIDEODURATIONSECOND = "actionExplains.videoDurationSecond";
    public static final String FIELD_ACTIONEXPLAINS_ACTIONIMAGEKEY = "actionExplains.actionImageKey";
    public static final String FIELD_ACTIONEXPLAINS_ATTENTIONS = "actionExplains.attentions";
    public static final String FIELD_ACTIONEXPLAINS_ACTIONEXPLAINS = "actionExplains.actionExplains";
    public static final String FIELD_ACTIONEXPLAINS_ACTIONNAME = "actionExplains.actionName";
    public static final String FIELD_ACTIONEXPLAINS_ACTIONVIDEOM3U8P1080KEY = "actionExplains.actionVideoM3u8P1080Key";
    public static final String FIELD_ACTIONEXPLAINS_ACTIONVIDEOM3U8P720KEY = "actionExplains.actionVideoM3u8P720Key";
    public static final String FIELD_ACTIONEXPLAINS_ACTIONVIDEOM3U8P480KEY = "actionExplains.actionVideoM3u8P480Key";
    public static final String FIELD_COURSEFINISHTOTALHEAT = "courseFinishTotalHeat";
    public static final String FIELD_COURSEFINISHTOTALDURATION = "courseFinishTotalDuration";
    public static final String FIELD_COURSEFINISHDETAILS = "courseFinishDetails";
    public static final String FIELD_COURSEFINISHDETAILS_RECORDDATE = "courseFinishDetails.recordDate";
    public static final String FIELD_COURSEFINISHDETAILS_EXERCISEDURATION = "courseFinishDetails.exerciseDuration";
    public static final String FIELD_COURSEFINISHDETAILS_EXERCISEHEAT = "courseFinishDetails.exerciseHeat";
    public static final String FIELD_SYSTEMEXERCISEINFO = "systemExerciseInfo";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST = "systemExerciseInfo.moreExerciseList";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_EXERCISEID = "systemExerciseInfo.moreExerciseList.exerciseId";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_MINCOUNT = "systemExerciseInfo.moreExerciseList.minCount";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_UNIT = "systemExerciseInfo.moreExerciseList.unit";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_MINCOUNTPRODUCEHEAT = "systemExerciseInfo.moreExerciseList.minCountProduceHeat";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_EXERCISETIMEMIN = "systemExerciseInfo.moreExerciseList.exerciseTimeMin";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_EXERCISETIMEMAX = "systemExerciseInfo.moreExerciseList.exerciseTimeMax";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_EXERCISEHEATMIN = "systemExerciseInfo.moreExerciseList.exerciseHeatMin";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_EXERCISEHEATMAX = "systemExerciseInfo.moreExerciseList.exerciseHeatMax";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_IMAGEKEY = "systemExerciseInfo.moreExerciseList.imageKey";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_EXERCISENAME = "systemExerciseInfo.moreExerciseList.exerciseName";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_EXERCISETYPE = "systemExerciseInfo.moreExerciseList.exerciseType";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_DESCRIPTIONS = "systemExerciseInfo.moreExerciseList.descriptions";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_ORDER = "systemExerciseInfo.moreExerciseList.order";
    public static final String FIELD_SYSTEMEXERCISEINFO_MOREEXERCISELIST_MET = "systemExerciseInfo.moreExerciseList.met";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST = "systemExerciseInfo.recommendExerciseList";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_EXERCISEID = "systemExerciseInfo.recommendExerciseList.exerciseId";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_MINCOUNT = "systemExerciseInfo.recommendExerciseList.minCount";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_UNIT = "systemExerciseInfo.recommendExerciseList.unit";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_MINCOUNTPRODUCEHEAT = "systemExerciseInfo.recommendExerciseList.minCountProduceHeat";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_EXERCISETIMEMIN = "systemExerciseInfo.recommendExerciseList.exerciseTimeMin";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_EXERCISETIMEMAX = "systemExerciseInfo.recommendExerciseList.exerciseTimeMax";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_EXERCISEHEATMIN = "systemExerciseInfo.recommendExerciseList.exerciseHeatMin";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_EXERCISEHEATMAX = "systemExerciseInfo.recommendExerciseList.exerciseHeatMax";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_IMAGEKEY = "systemExerciseInfo.recommendExerciseList.imageKey";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_EXERCISENAME = "systemExerciseInfo.recommendExerciseList.exerciseName";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_EXERCISETYPE = "systemExerciseInfo.recommendExerciseList.exerciseType";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_DESCRIPTIONS = "systemExerciseInfo.recommendExerciseList.descriptions";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_ORDER = "systemExerciseInfo.recommendExerciseList.order";
    public static final String FIELD_SYSTEMEXERCISEINFO_RECOMMENDEXERCISELIST_MET = "systemExerciseInfo.recommendExerciseList.met";
    public static final String FIELD_SYSTEMEXERCISEINFO_EXERCISEADVICES = "systemExerciseInfo.exerciseAdvices";







}
