package com.jiankangyouyi.cloud.motorplan.model.entity.mongo.component.v3;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.List;

/**
 * 动作配置
 *
 * @author ：wangyalei
 * @date ：2022/4/28 1:19 下午
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class ActionConfig {
    /**
     * 视频合成规则 TIME : 以时间 、 COUNT ： 以条数
     */
    public static final String TIME = "TIME";
    public static final String COUNT = "COUNT";

    /**
     * 配置详情
     */
    private List<ConfigDetail> configDetails;
    /**
     * BMI 条件配置
     */
    private List<BmiConditionConfig> bmiConditionConfigs;


    /**
     * BMI 条件配置
     */
    @Data
    @Builder
    @AllArgsConstructor
    @NoArgsConstructor
    public static class BmiConditionConfig {
        /**
         * 开始值
         */
        private Double startValue;
        /**
         * 是否包含开始值
         */
        private Boolean includeStartValue;
        /**
         * 结束值
         */
        private Double endValue;
        /**
         * 是否包含结束值
         */
        private Boolean includeEndValue;
        /**
         * 配置详情
         */
        private List<ConfigDetail> configDetails;
    }

    /**
     * 配置详情
     */
    @Data
    @Builder
    @AllArgsConstructor
    @NoArgsConstructor
    public static class ConfigDetail {
        /**
         * 运动能力
         */
        private Integer exerciseLevel;
        /**
         * 规则信息
         */
        private List<RuleInfo> ruleInfoList;
    }


    /**
     * 规则信息
     */
    @Data
    @Builder
    @AllArgsConstructor
    @NoArgsConstructor
    public static class RuleInfo {
        /**
         * 当前规则编号 (训练日 1 、2 类似于此类的编号)
         */
        private String currentRuleNum;
        /**
         * 下一条规则编号
         */
        private String nextRuleNum;
        /**
         * 热身计划编号
         */
        private String warmupPlanNum;
        /**
         * 热身规则类型 分为：时间、次数
         */
        private String warmupRuleType;
        /**
         * 热身规则值 规则类型以时间的话，该值单位是秒，以次数的话，单位是个
         */
        private Integer warmupRuleValue;
        /**
         * 训练计划编号
         */
        private String trainingPlanNum;
        /**
         * 训练规则类型 分为：时间、次数
         */
        private String trainingRuleType;
        /**
         * 训练规则值 规则类型以时间的话，该值单位是秒，以次数的话，单位是个
         */
        private Integer trainingRuleValue;
        /**
         * 训练动作循环次数
         */
        private Integer trainingCirculationCount;
        /**
         * 拉伸计划编号
         */
        private String stretchPlanNum;
        /**
         * 拉伸规则类型 分为：时间、次数
         */
        private String stretchRuleType;
        /**
         * 拉伸规则值 规则类型以时间的话，该值单位是秒，以次数的话，单位是个
         */
        private Integer stretchRuleValue;
        /**
         * 系统课程运动类型
         */
        private List<String> systemExerciseTypes;
    }
}
