package com.jiankangyouyi.cloud.motorplan.model.entity.mongo.component.v3;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serializable;
import java.util.List;

/**
 * 运动课程方案配置
 * @author ：wangyalei
 * @date ：2022/4/26 4:16 下午
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class ExerciseCourseProjectConfig implements Serializable {

    /**
     * 方案编号
     */
    private String projectNum;
    /**
     * 描述信息
     */
    private String description;
    /**
     * 疾病类型
     */
    private String diseaseType;
    /**
     * 健康/亚健康人群 true 是 false 否
     */
    private Boolean healthyPerson;
    /**
     * 风险等级
     */
    private List<Integer> riskLevels;
    /**
     * 其他等级 (特殊疾病标签处理)
     */
    private List<String> otherLevels;

    /**
     * 管理目标配置
     */
    private ManagementGoalConfig managementGoalConfig;

    /**
     * 时间-频率-难度配置
     */
    private TFDConfig tfdConfig;
    /**
     * 梅脱和休息配置
     */
    private MetRestConfig metRestConfig;
    /**
     * 动作配置
     */
    private ActionConfig actionConfig;

    /**
     * 禁止动作标签 （视频课程）
     */
    private VideoForbidActionLabelConfig videoForbidActionLabelConfig;

    /**
     * 注意事项 （视频课程）
     */
    private VideoAttentionItemConfig videoAttentionItemConfig;

    /**
     * 禁止动作标签 （系统课程）
     */
    private SystemForbidActionLabelConfig systemForbidActionLabelConfig;
    /**
     * 注意事项 （系统课程）
     */
    private SystemAttentionItemConfig systemAttentionItemConfig;
    /**
     * 系统运动提示话术
     */
    private SystemRemindDescriptionConfig systemRemindDescriptionConfig;

    public static final String FIELD_PROJECTNUM = "projectNum";
    public static final String FIELD_DISEASETYPE = "diseaseType";
    public static final String FIELD_HEALTHYPERSON = "healthyPerson";
    public static final String FIELD_RISKLEVELS = "riskLevels";
    public static final String FIELD_OTHERLEVELS = "otherLevels";
    public static final String FIELD_MANAGEMENTGOALCONFIG = "managementGoalConfig";
    public static final String FIELD_MANAGEMENTGOALCONFIG_CONFIGDETAILS = "managementGoalConfig.configDetails";
    public static final String FIELD_MANAGEMENTGOALCONFIG_BMICONDITIONCONFIGS = "managementGoalConfig.bmiConditionConfigs";
    public static final String FIELD_MANAGEMENTGOALCONFIG_BMICONDITIONCONFIGS_STARTVALUE = "managementGoalConfig.bmiConditionConfigs.startValue";
    public static final String FIELD_MANAGEMENTGOALCONFIG_BMICONDITIONCONFIGS_INCLUDESTARTVALUE = "managementGoalConfig.bmiConditionConfigs.includeStartValue";
    public static final String FIELD_MANAGEMENTGOALCONFIG_BMICONDITIONCONFIGS_ENDVALUE = "managementGoalConfig.bmiConditionConfigs.endValue";
    public static final String FIELD_MANAGEMENTGOALCONFIG_BMICONDITIONCONFIGS_INCLUDEENDVALUE = "managementGoalConfig.bmiConditionConfigs.includeEndValue";
    public static final String FIELD_MANAGEMENTGOALCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS = "managementGoalConfig.bmiConditionConfigs.configDetails";
    public static final String FIELD_TFDCONFIG = "tfdConfig";
    public static final String FIELD_TFDCONFIG_CONFIGDETAIL = "tfdConfig.configDetail";
    public static final String FIELD_TFDCONFIG_CONFIGDETAIL_TIMECONFIGS = "tfdConfig.configDetail.timeConfigs";
    public static final String FIELD_TFDCONFIG_CONFIGDETAIL_TIMECONFIGS_EXERCISELEVEL = "tfdConfig.configDetail.timeConfigs.exerciseLevel";
    public static final String FIELD_TFDCONFIG_CONFIGDETAIL_TIMECONFIGS_MINGRADE = "tfdConfig.configDetail.timeConfigs.minGrade";
    public static final String FIELD_TFDCONFIG_CONFIGDETAIL_TIMECONFIGS_MAXGRADE = "tfdConfig.configDetail.timeConfigs.maxGrade";
    public static final String FIELD_TFDCONFIG_CONFIGDETAIL_TIMECONFIGS_WARMUPSTRETCHRULE = "tfdConfig.configDetail.timeConfigs.warmupStretchRule";
    public static final String FIELD_TFDCONFIG_CONFIGDETAIL_FREQUENCYCONFIGS = "tfdConfig.configDetail.frequencyConfigs";
    public static final String FIELD_TFDCONFIG_CONFIGDETAIL_FREQUENCYCONFIGS_EXERCISELEVEL = "tfdConfig.configDetail.frequencyConfigs.exerciseLevel";
    public static final String FIELD_TFDCONFIG_CONFIGDETAIL_FREQUENCYCONFIGS_MINGRADE = "tfdConfig.configDetail.frequencyConfigs.minGrade";
    public static final String FIELD_TFDCONFIG_CONFIGDETAIL_FREQUENCYCONFIGS_MAXGRADE = "tfdConfig.configDetail.frequencyConfigs.maxGrade";
    public static final String FIELD_TFDCONFIG_CONFIGDETAIL_DIFFICULTYCONFIGS = "tfdConfig.configDetail.difficultyConfigs";
    public static final String FIELD_TFDCONFIG_CONFIGDETAIL_DIFFICULTYCONFIGS_EXERCISELEVEL = "tfdConfig.configDetail.difficultyConfigs.exerciseLevel";
    public static final String FIELD_TFDCONFIG_CONFIGDETAIL_DIFFICULTYCONFIGS_MINGRADE = "tfdConfig.configDetail.difficultyConfigs.minGrade";
    public static final String FIELD_TFDCONFIG_CONFIGDETAIL_DIFFICULTYCONFIGS_MAXGRADE = "tfdConfig.configDetail.difficultyConfigs.maxGrade";
    public static final String FIELD_TFDCONFIG_BMICONDITIONCONFIGS = "tfdConfig.bmiConditionConfigs";
    public static final String FIELD_TFDCONFIG_BMICONDITIONCONFIGS_STARTVALUE = "tfdConfig.bmiConditionConfigs.startValue";
    public static final String FIELD_TFDCONFIG_BMICONDITIONCONFIGS_INCLUDESTARTVALUE = "tfdConfig.bmiConditionConfigs.includeStartValue";
    public static final String FIELD_TFDCONFIG_BMICONDITIONCONFIGS_ENDVALUE = "tfdConfig.bmiConditionConfigs.endValue";
    public static final String FIELD_TFDCONFIG_BMICONDITIONCONFIGS_INCLUDEENDVALUE = "tfdConfig.bmiConditionConfigs.includeEndValue";
    public static final String FIELD_TFDCONFIG_BMICONDITIONCONFIGS_CONFIGDETAIL = "tfdConfig.bmiConditionConfigs.configDetail";
    public static final String FIELD_TFDCONFIG_BMICONDITIONCONFIGS_CONFIGDETAIL_TIMECONFIGS = "tfdConfig.bmiConditionConfigs.configDetail.timeConfigs";
    public static final String FIELD_TFDCONFIG_BMICONDITIONCONFIGS_CONFIGDETAIL_TIMECONFIGS_EXERCISELEVEL = "tfdConfig.bmiConditionConfigs.configDetail.timeConfigs.exerciseLevel";
    public static final String FIELD_TFDCONFIG_BMICONDITIONCONFIGS_CONFIGDETAIL_TIMECONFIGS_MINGRADE = "tfdConfig.bmiConditionConfigs.configDetail.timeConfigs.minGrade";
    public static final String FIELD_TFDCONFIG_BMICONDITIONCONFIGS_CONFIGDETAIL_TIMECONFIGS_MAXGRADE = "tfdConfig.bmiConditionConfigs.configDetail.timeConfigs.maxGrade";
    public static final String FIELD_TFDCONFIG_BMICONDITIONCONFIGS_CONFIGDETAIL_TIMECONFIGS_WARMUPSTRETCHRULE = "tfdConfig.bmiConditionConfigs.configDetail.timeConfigs.warmupStretchRule";
    public static final String FIELD_TFDCONFIG_BMICONDITIONCONFIGS_CONFIGDETAIL_FREQUENCYCONFIGS = "tfdConfig.bmiConditionConfigs.configDetail.frequencyConfigs";
    public static final String FIELD_TFDCONFIG_BMICONDITIONCONFIGS_CONFIGDETAIL_FREQUENCYCONFIGS_EXERCISELEVEL = "tfdConfig.bmiConditionConfigs.configDetail.frequencyConfigs.exerciseLevel";
    public static final String FIELD_TFDCONFIG_BMICONDITIONCONFIGS_CONFIGDETAIL_FREQUENCYCONFIGS_MINGRADE = "tfdConfig.bmiConditionConfigs.configDetail.frequencyConfigs.minGrade";
    public static final String FIELD_TFDCONFIG_BMICONDITIONCONFIGS_CONFIGDETAIL_FREQUENCYCONFIGS_MAXGRADE = "tfdConfig.bmiConditionConfigs.configDetail.frequencyConfigs.maxGrade";
    public static final String FIELD_TFDCONFIG_BMICONDITIONCONFIGS_CONFIGDETAIL_DIFFICULTYCONFIGS = "tfdConfig.bmiConditionConfigs.configDetail.difficultyConfigs";
    public static final String FIELD_TFDCONFIG_BMICONDITIONCONFIGS_CONFIGDETAIL_DIFFICULTYCONFIGS_EXERCISELEVEL = "tfdConfig.bmiConditionConfigs.configDetail.difficultyConfigs.exerciseLevel";
    public static final String FIELD_TFDCONFIG_BMICONDITIONCONFIGS_CONFIGDETAIL_DIFFICULTYCONFIGS_MINGRADE = "tfdConfig.bmiConditionConfigs.configDetail.difficultyConfigs.minGrade";
    public static final String FIELD_TFDCONFIG_BMICONDITIONCONFIGS_CONFIGDETAIL_DIFFICULTYCONFIGS_MAXGRADE = "tfdConfig.bmiConditionConfigs.configDetail.difficultyConfigs.maxGrade";
    public static final String FIELD_METCONFIG = "metConfig";
    public static final String FIELD_METCONFIG_CONFIGDETAILS = "metConfig.configDetails";
    public static final String FIELD_METCONFIG_CONFIGDETAILS_EXERCISELEVEL = "metConfig.configDetails.exerciseLevel";
    public static final String FIELD_METCONFIG_CONFIGDETAILS_METINFOLIST = "metConfig.configDetails.metInfoList";
    public static final String FIELD_METCONFIG_CONFIGDETAILS_METINFOLIST_EXERCISETYPE = "metConfig.configDetails.metInfoList.exerciseType";
    public static final String FIELD_METCONFIG_CONFIGDETAILS_METINFOLIST_MINMETVIDEOLIMITGRADE = "metConfig.configDetails.metInfoList.minMetVideoLimitGrade";
    public static final String FIELD_METCONFIG_CONFIGDETAILS_METINFOLIST_MAXMETVIDEOLIMITGRADE = "metConfig.configDetails.metInfoList.maxMetVideoLimitGrade";
    public static final String FIELD_METCONFIG_CONFIGDETAILS_METINFOLIST_MINMETTIMELIMITGRADE = "metConfig.configDetails.metInfoList.minMetTimeLimitGrade";
    public static final String FIELD_METCONFIG_CONFIGDETAILS_METINFOLIST_MAXMETTIMELIMITGRADE = "metConfig.configDetails.metInfoList.maxMetTimeLimitGrade";
    public static final String FIELD_METCONFIG_BMICONDITIONCONFIGS = "metConfig.bmiConditionConfigs";
    public static final String FIELD_METCONFIG_BMICONDITIONCONFIGS_STARTVALUE = "metConfig.bmiConditionConfigs.startValue";
    public static final String FIELD_METCONFIG_BMICONDITIONCONFIGS_INCLUDESTARTVALUE = "metConfig.bmiConditionConfigs.includeStartValue";
    public static final String FIELD_METCONFIG_BMICONDITIONCONFIGS_ENDVALUE = "metConfig.bmiConditionConfigs.endValue";
    public static final String FIELD_METCONFIG_BMICONDITIONCONFIGS_INCLUDEENDVALUE = "metConfig.bmiConditionConfigs.includeEndValue";
    public static final String FIELD_METCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS = "metConfig.bmiConditionConfigs.configDetails";
    public static final String FIELD_METCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_EXERCISELEVEL = "metConfig.bmiConditionConfigs.configDetails.exerciseLevel";
    public static final String FIELD_METCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_METINFOLIST = "metConfig.bmiConditionConfigs.configDetails.metInfoList";
    public static final String FIELD_METCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_METINFOLIST_EXERCISETYPE = "metConfig.bmiConditionConfigs.configDetails.metInfoList.exerciseType";
    public static final String FIELD_METCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_METINFOLIST_MINMETVIDEOLIMITGRADE = "metConfig.bmiConditionConfigs.configDetails.metInfoList.minMetVideoLimitGrade";
    public static final String FIELD_METCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_METINFOLIST_MAXMETVIDEOLIMITGRADE = "metConfig.bmiConditionConfigs.configDetails.metInfoList.maxMetVideoLimitGrade";
    public static final String FIELD_METCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_METINFOLIST_MINMETTIMELIMITGRADE = "metConfig.bmiConditionConfigs.configDetails.metInfoList.minMetTimeLimitGrade";
    public static final String FIELD_METCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_METINFOLIST_MAXMETTIMELIMITGRADE = "metConfig.bmiConditionConfigs.configDetails.metInfoList.maxMetTimeLimitGrade";
    public static final String FIELD_ACTIONCONFIG = "actionConfig";
    public static final String FIELD_ACTIONCONFIG_CONFIGDETAILS = "actionConfig.configDetails";
    public static final String FIELD_ACTIONCONFIG_CONFIGDETAILS_EXERCISELEVEL = "actionConfig.configDetails.exerciseLevel";
    public static final String FIELD_ACTIONCONFIG_CONFIGDETAILS_RULEINFOLIST = "actionConfig.configDetails.ruleInfoList";
    public static final String FIELD_ACTIONCONFIG_CONFIGDETAILS_RULEINFOLIST_CURRENTRULENUM = "actionConfig.configDetails.ruleInfoList.currentRuleNum";
    public static final String FIELD_ACTIONCONFIG_CONFIGDETAILS_RULEINFOLIST_NEXTRULENUM = "actionConfig.configDetails.ruleInfoList.nextRuleNum";
    public static final String FIELD_ACTIONCONFIG_CONFIGDETAILS_RULEINFOLIST_WARMUPPLANNUM = "actionConfig.configDetails.ruleInfoList.warmupPlanNum";
    public static final String FIELD_ACTIONCONFIG_CONFIGDETAILS_RULEINFOLIST_WARMUPRULETYPE = "actionConfig.configDetails.ruleInfoList.warmupRuleType";
    public static final String FIELD_ACTIONCONFIG_CONFIGDETAILS_RULEINFOLIST_WARMUPRULEVALUE = "actionConfig.configDetails.ruleInfoList.warmupRuleValue";
    public static final String FIELD_ACTIONCONFIG_CONFIGDETAILS_RULEINFOLIST_TRAININGPLANNUM = "actionConfig.configDetails.ruleInfoList.trainingPlanNum";
    public static final String FIELD_ACTIONCONFIG_CONFIGDETAILS_RULEINFOLIST_TRAININGRULETYPE = "actionConfig.configDetails.ruleInfoList.trainingRuleType";
    public static final String FIELD_ACTIONCONFIG_CONFIGDETAILS_RULEINFOLIST_TRAININGRULEVALUE = "actionConfig.configDetails.ruleInfoList.trainingRuleValue";
    public static final String FIELD_ACTIONCONFIG_CONFIGDETAILS_RULEINFOLIST_TRAININGCIRCULATIONCOUNT = "actionConfig.configDetails.ruleInfoList.trainingCirculationCount";
    public static final String FIELD_ACTIONCONFIG_CONFIGDETAILS_RULEINFOLIST_RESTMINGRADE = "actionConfig.configDetails.ruleInfoList.restMinGrade";
    public static final String FIELD_ACTIONCONFIG_CONFIGDETAILS_RULEINFOLIST_RESTMAXGRADE = "actionConfig.configDetails.ruleInfoList.restMaxGrade";
    public static final String FIELD_ACTIONCONFIG_CONFIGDETAILS_RULEINFOLIST_STRETCHPLANNUM = "actionConfig.configDetails.ruleInfoList.stretchPlanNum";
    public static final String FIELD_ACTIONCONFIG_CONFIGDETAILS_RULEINFOLIST_STRETCHRULETYPE = "actionConfig.configDetails.ruleInfoList.stretchRuleType";
    public static final String FIELD_ACTIONCONFIG_CONFIGDETAILS_RULEINFOLIST_STRETCHRULEVALUE = "actionConfig.configDetails.ruleInfoList.stretchRuleValue";
    public static final String FIELD_ACTIONCONFIG_CONFIGDETAILS_RULEINFOLIST_SYSTEMEXERCISETYPES = "actionConfig.configDetails.ruleInfoList.systemExerciseTypes";
    public static final String FIELD_ACTIONCONFIG_BMICONDITIONCONFIGS = "actionConfig.bmiConditionConfigs";
    public static final String FIELD_ACTIONCONFIG_BMICONDITIONCONFIGS_STARTVALUE = "actionConfig.bmiConditionConfigs.startValue";
    public static final String FIELD_ACTIONCONFIG_BMICONDITIONCONFIGS_INCLUDESTARTVALUE = "actionConfig.bmiConditionConfigs.includeStartValue";
    public static final String FIELD_ACTIONCONFIG_BMICONDITIONCONFIGS_ENDVALUE = "actionConfig.bmiConditionConfigs.endValue";
    public static final String FIELD_ACTIONCONFIG_BMICONDITIONCONFIGS_INCLUDEENDVALUE = "actionConfig.bmiConditionConfigs.includeEndValue";
    public static final String FIELD_ACTIONCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS = "actionConfig.bmiConditionConfigs.configDetails";
    public static final String FIELD_ACTIONCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_EXERCISELEVEL = "actionConfig.bmiConditionConfigs.configDetails.exerciseLevel";
    public static final String FIELD_ACTIONCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_RULEINFOLIST = "actionConfig.bmiConditionConfigs.configDetails.ruleInfoList";
    public static final String FIELD_ACTIONCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_RULEINFOLIST_CURRENTRULENUM = "actionConfig.bmiConditionConfigs.configDetails.ruleInfoList.currentRuleNum";
    public static final String FIELD_ACTIONCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_RULEINFOLIST_NEXTRULENUM = "actionConfig.bmiConditionConfigs.configDetails.ruleInfoList.nextRuleNum";
    public static final String FIELD_ACTIONCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_RULEINFOLIST_WARMUPPLANNUM = "actionConfig.bmiConditionConfigs.configDetails.ruleInfoList.warmupPlanNum";
    public static final String FIELD_ACTIONCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_RULEINFOLIST_WARMUPRULETYPE = "actionConfig.bmiConditionConfigs.configDetails.ruleInfoList.warmupRuleType";
    public static final String FIELD_ACTIONCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_RULEINFOLIST_WARMUPRULEVALUE = "actionConfig.bmiConditionConfigs.configDetails.ruleInfoList.warmupRuleValue";
    public static final String FIELD_ACTIONCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_RULEINFOLIST_TRAININGPLANNUM = "actionConfig.bmiConditionConfigs.configDetails.ruleInfoList.trainingPlanNum";
    public static final String FIELD_ACTIONCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_RULEINFOLIST_TRAININGRULETYPE = "actionConfig.bmiConditionConfigs.configDetails.ruleInfoList.trainingRuleType";
    public static final String FIELD_ACTIONCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_RULEINFOLIST_TRAININGRULEVALUE = "actionConfig.bmiConditionConfigs.configDetails.ruleInfoList.trainingRuleValue";
    public static final String FIELD_ACTIONCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_RULEINFOLIST_TRAININGCIRCULATIONCOUNT = "actionConfig.bmiConditionConfigs.configDetails.ruleInfoList.trainingCirculationCount";
    public static final String FIELD_ACTIONCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_RULEINFOLIST_RESTMINGRADE = "actionConfig.bmiConditionConfigs.configDetails.ruleInfoList.restMinGrade";
    public static final String FIELD_ACTIONCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_RULEINFOLIST_RESTMAXGRADE = "actionConfig.bmiConditionConfigs.configDetails.ruleInfoList.restMaxGrade";
    public static final String FIELD_ACTIONCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_RULEINFOLIST_STRETCHPLANNUM = "actionConfig.bmiConditionConfigs.configDetails.ruleInfoList.stretchPlanNum";
    public static final String FIELD_ACTIONCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_RULEINFOLIST_STRETCHRULETYPE = "actionConfig.bmiConditionConfigs.configDetails.ruleInfoList.stretchRuleType";
    public static final String FIELD_ACTIONCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_RULEINFOLIST_STRETCHRULEVALUE = "actionConfig.bmiConditionConfigs.configDetails.ruleInfoList.stretchRuleValue";
    public static final String FIELD_ACTIONCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_RULEINFOLIST_SYSTEMEXERCISETYPES = "actionConfig.bmiConditionConfigs.configDetails.ruleInfoList.systemExerciseTypes";
    public static final String FIELD_VIDEOFORBIDACTIONLABELCONFIG = "videoForbidActionLabelConfig";
    public static final String FIELD_VIDEOFORBIDACTIONLABELCONFIG_CONFIGDETAIL = "videoForbidActionLabelConfig.configDetail";
    public static final String FIELD_VIDEOFORBIDACTIONLABELCONFIG_BMICONDITIONCONFIGS = "videoForbidActionLabelConfig.bmiConditionConfigs";
    public static final String FIELD_VIDEOFORBIDACTIONLABELCONFIG_BMICONDITIONCONFIGS_STARTVALUE = "videoForbidActionLabelConfig.bmiConditionConfigs.startValue";
    public static final String FIELD_VIDEOFORBIDACTIONLABELCONFIG_BMICONDITIONCONFIGS_INCLUDESTARTVALUE = "videoForbidActionLabelConfig.bmiConditionConfigs.includeStartValue";
    public static final String FIELD_VIDEOFORBIDACTIONLABELCONFIG_BMICONDITIONCONFIGS_ENDVALUE = "videoForbidActionLabelConfig.bmiConditionConfigs.endValue";
    public static final String FIELD_VIDEOFORBIDACTIONLABELCONFIG_BMICONDITIONCONFIGS_INCLUDEENDVALUE = "videoForbidActionLabelConfig.bmiConditionConfigs.includeEndValue";
    public static final String FIELD_VIDEOFORBIDACTIONLABELCONFIG_BMICONDITIONCONFIGS_CONFIGDETAIL = "videoForbidActionLabelConfig.bmiConditionConfigs.configDetail";
    public static final String FIELD_VIDEOATTENTIONITEMCONFIG = "videoAttentionItemConfig";
    public static final String FIELD_VIDEOATTENTIONITEMCONFIG_CONFIGDETAILS = "videoAttentionItemConfig.configDetails";
    public static final String FIELD_VIDEOATTENTIONITEMCONFIG_CONFIGDETAILS_LEVEL = "videoAttentionItemConfig.configDetails.level";
    public static final String FIELD_VIDEOATTENTIONITEMCONFIG_CONFIGDETAILS_CONTENT = "videoAttentionItemConfig.configDetails.content";
    public static final String FIELD_VIDEOATTENTIONITEMCONFIG_BMICONDITIONCONFIGS = "videoAttentionItemConfig.bmiConditionConfigs";
    public static final String FIELD_VIDEOATTENTIONITEMCONFIG_BMICONDITIONCONFIGS_STARTVALUE = "videoAttentionItemConfig.bmiConditionConfigs.startValue";
    public static final String FIELD_VIDEOATTENTIONITEMCONFIG_BMICONDITIONCONFIGS_INCLUDESTARTVALUE = "videoAttentionItemConfig.bmiConditionConfigs.includeStartValue";
    public static final String FIELD_VIDEOATTENTIONITEMCONFIG_BMICONDITIONCONFIGS_ENDVALUE = "videoAttentionItemConfig.bmiConditionConfigs.endValue";
    public static final String FIELD_VIDEOATTENTIONITEMCONFIG_BMICONDITIONCONFIGS_INCLUDEENDVALUE = "videoAttentionItemConfig.bmiConditionConfigs.includeEndValue";
    public static final String FIELD_VIDEOATTENTIONITEMCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS = "videoAttentionItemConfig.bmiConditionConfigs.configDetails";
    public static final String FIELD_VIDEOATTENTIONITEMCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_LEVEL = "videoAttentionItemConfig.bmiConditionConfigs.configDetails.level";
    public static final String FIELD_VIDEOATTENTIONITEMCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_CONTENT = "videoAttentionItemConfig.bmiConditionConfigs.configDetails.content";
    public static final String FIELD_SYSTEMFORBIDACTIONLABELCONFIG = "systemForbidActionLabelConfig";
    public static final String FIELD_SYSTEMFORBIDACTIONLABELCONFIG_CONFIGDETAIL = "systemForbidActionLabelConfig.configDetail";
    public static final String FIELD_SYSTEMFORBIDACTIONLABELCONFIG_BMICONDITIONCONFIGS = "systemForbidActionLabelConfig.bmiConditionConfigs";
    public static final String FIELD_SYSTEMFORBIDACTIONLABELCONFIG_BMICONDITIONCONFIGS_STARTVALUE = "systemForbidActionLabelConfig.bmiConditionConfigs.startValue";
    public static final String FIELD_SYSTEMFORBIDACTIONLABELCONFIG_BMICONDITIONCONFIGS_INCLUDESTARTVALUE = "systemForbidActionLabelConfig.bmiConditionConfigs.includeStartValue";
    public static final String FIELD_SYSTEMFORBIDACTIONLABELCONFIG_BMICONDITIONCONFIGS_ENDVALUE = "systemForbidActionLabelConfig.bmiConditionConfigs.endValue";
    public static final String FIELD_SYSTEMFORBIDACTIONLABELCONFIG_BMICONDITIONCONFIGS_INCLUDEENDVALUE = "systemForbidActionLabelConfig.bmiConditionConfigs.includeEndValue";
    public static final String FIELD_SYSTEMFORBIDACTIONLABELCONFIG_BMICONDITIONCONFIGS_CONFIGDETAIL = "systemForbidActionLabelConfig.bmiConditionConfigs.configDetail";
    public static final String FIELD_SYSTEMATTENTIONITEMCONFIG = "systemAttentionItemConfig";
    public static final String FIELD_SYSTEMATTENTIONITEMCONFIG_CONFIGDETAILS = "systemAttentionItemConfig.configDetails";
    public static final String FIELD_SYSTEMATTENTIONITEMCONFIG_CONFIGDETAILS_LEVEL = "systemAttentionItemConfig.configDetails.level";
    public static final String FIELD_SYSTEMATTENTIONITEMCONFIG_CONFIGDETAILS_CONTENT = "systemAttentionItemConfig.configDetails.content";
    public static final String FIELD_SYSTEMATTENTIONITEMCONFIG_BMICONDITIONCONFIGS = "systemAttentionItemConfig.bmiConditionConfigs";
    public static final String FIELD_SYSTEMATTENTIONITEMCONFIG_BMICONDITIONCONFIGS_STARTVALUE = "systemAttentionItemConfig.bmiConditionConfigs.startValue";
    public static final String FIELD_SYSTEMATTENTIONITEMCONFIG_BMICONDITIONCONFIGS_INCLUDESTARTVALUE = "systemAttentionItemConfig.bmiConditionConfigs.includeStartValue";
    public static final String FIELD_SYSTEMATTENTIONITEMCONFIG_BMICONDITIONCONFIGS_ENDVALUE = "systemAttentionItemConfig.bmiConditionConfigs.endValue";
    public static final String FIELD_SYSTEMATTENTIONITEMCONFIG_BMICONDITIONCONFIGS_INCLUDEENDVALUE = "systemAttentionItemConfig.bmiConditionConfigs.includeEndValue";
    public static final String FIELD_SYSTEMATTENTIONITEMCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS = "systemAttentionItemConfig.bmiConditionConfigs.configDetails";
    public static final String FIELD_SYSTEMATTENTIONITEMCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_LEVEL = "systemAttentionItemConfig.bmiConditionConfigs.configDetails.level";
    public static final String FIELD_SYSTEMATTENTIONITEMCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_CONTENT = "systemAttentionItemConfig.bmiConditionConfigs.configDetails.content";
    public static final String FIELD_SYSTEMREMINDDESCRIPTIONCONFIG = "systemRemindDescriptionConfig";
    public static final String FIELD_SYSTEMREMINDDESCRIPTIONCONFIG_CONFIGDETAILS = "systemRemindDescriptionConfig.configDetails";
    public static final String FIELD_SYSTEMREMINDDESCRIPTIONCONFIG_CONFIGDETAILS_ATHLETICABILITY = "systemRemindDescriptionConfig.configDetails.athleticAbility";
    public static final String FIELD_SYSTEMREMINDDESCRIPTIONCONFIG_CONFIGDETAILS_EXERCISETYPE = "systemRemindDescriptionConfig.configDetails.exerciseType";
    public static final String FIELD_SYSTEMREMINDDESCRIPTIONCONFIG_CONFIGDETAILS_DESCRIPTION = "systemRemindDescriptionConfig.configDetails.description";
    public static final String FIELD_SYSTEMREMINDDESCRIPTIONCONFIG_CONFIGDETAILS_HEARTSTART = "systemRemindDescriptionConfig.configDetails.heartStart";
    public static final String FIELD_SYSTEMREMINDDESCRIPTIONCONFIG_CONFIGDETAILS_HEARTEND = "systemRemindDescriptionConfig.configDetails.heartEnd";
    public static final String FIELD_SYSTEMREMINDDESCRIPTIONCONFIG_BMICONDITIONCONFIGS = "systemRemindDescriptionConfig.bmiConditionConfigs";
    public static final String FIELD_SYSTEMREMINDDESCRIPTIONCONFIG_BMICONDITIONCONFIGS_STARTVALUE = "systemRemindDescriptionConfig.bmiConditionConfigs.startValue";
    public static final String FIELD_SYSTEMREMINDDESCRIPTIONCONFIG_BMICONDITIONCONFIGS_INCLUDESTARTVALUE = "systemRemindDescriptionConfig.bmiConditionConfigs.includeStartValue";
    public static final String FIELD_SYSTEMREMINDDESCRIPTIONCONFIG_BMICONDITIONCONFIGS_ENDVALUE = "systemRemindDescriptionConfig.bmiConditionConfigs.endValue";
    public static final String FIELD_SYSTEMREMINDDESCRIPTIONCONFIG_BMICONDITIONCONFIGS_INCLUDEENDVALUE = "systemRemindDescriptionConfig.bmiConditionConfigs.includeEndValue";
    public static final String FIELD_SYSTEMREMINDDESCRIPTIONCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS = "systemRemindDescriptionConfig.bmiConditionConfigs.configDetails";
    public static final String FIELD_SYSTEMREMINDDESCRIPTIONCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_ATHLETICABILITY = "systemRemindDescriptionConfig.bmiConditionConfigs.configDetails.athleticAbility";
    public static final String FIELD_SYSTEMREMINDDESCRIPTIONCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_EXERCISETYPE = "systemRemindDescriptionConfig.bmiConditionConfigs.configDetails.exerciseType";
    public static final String FIELD_SYSTEMREMINDDESCRIPTIONCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_DESCRIPTION = "systemRemindDescriptionConfig.bmiConditionConfigs.configDetails.description";
    public static final String FIELD_SYSTEMREMINDDESCRIPTIONCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_HEARTSTART = "systemRemindDescriptionConfig.bmiConditionConfigs.configDetails.heartStart";
    public static final String FIELD_SYSTEMREMINDDESCRIPTIONCONFIG_BMICONDITIONCONFIGS_CONFIGDETAILS_HEARTEND = "systemRemindDescriptionConfig.bmiConditionConfigs.configDetails.heartEnd";


}
