package com.jiankangyouyi.cloud.motorplan.model.entity.mongo.component.v3;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.List;

/**
 * 梅脱和休息条件配置
 * @author ：wangyalei
 * @date ：2022/4/28 11:28 上午
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class MetRestConfig {

    /**
     * 配置详情
     */
    private List<ConfigDetail> configDetails;
    /**
     * BMI 条件配置
     */
    private List<BmiConditionConfig> bmiConditionConfigs;


    /**
     * BMI 条件配置
     */
    @Data
    @Builder
    @AllArgsConstructor
    @NoArgsConstructor
    public static class BmiConditionConfig{
        /**
         * 开始值
         */
        private Double startValue;
        /**
         * 是否包含开始值
         */
        private Boolean includeStartValue;
        /**
         * 结束值
         */
        private Double endValue;
        /**
         * 是否包含结束值
         */
        private Boolean includeEndValue;
        /**
         * 配置详情
         */
        private List<ConfigDetail> configDetails;
    }


    /**
     * 梅脱和休息条件信息
     */
    @Data
    @Builder
    @AllArgsConstructor
    @NoArgsConstructor
    public static class MetRestInfo {
        /**
         * 运动类型
         */
        private String exerciseType;
        /**
         * 最小梅脱视频约束等级
         */
        private Integer minMetVideoLimitGrade;
        /**
         * 最大梅脱视频约束等级
         */
        private Integer maxMetVideoLimitGrade;
        /**
         * 最小梅脱时间约束等级
         */
        private Integer minMetTimeLimitGrade;
        /**
         * 最大梅脱时间约束等级
         */
        private Integer maxMetTimeLimitGrade;
        /**
         * 最小休息规则等级
         */
        private Integer minRestRuleGrade;
        /**
         * 最大休息规则等级
         */
        private Integer maxRestRuleGrade;
    }


    /**
     * 配置详情
     */
    @Data
    @Builder
    @AllArgsConstructor
    @NoArgsConstructor
    public static class ConfigDetail {
        /**
         * 运动能力
         */
        private Integer athleticAbility;
        /**
         * 梅脱信息
         */
        private List<MetRestInfo> metRestInfos;
    }

}
