package com.jiankangyouyi.cloud.motorplan.model.entity.mongo.component.v3;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.List;

/**
 * 时间-频率-难度配置
 * @author ：wangyalei
 * @date ：2022/4/28 10:44 上午
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class TFDConfig {
    /**
     * 配置详情
     */
    private ConfigDetail configDetail;
    /**
     * BMI 条件配置
     */
    private List<BmiConditionConfig> bmiConditionConfigs;

    /**
     * 配置详情
     */
    @Data
    @Builder
    @AllArgsConstructor
    @NoArgsConstructor
    public static class ConfigDetail {
        /**
         * 时间配置
         */
        private List<TimeConfig> timeConfigs;
        /**
         * 频率配置
         */
        private List<FrequencyConfig> frequencyConfigs;
        /**
         * 难度配置
         */
        private List<DifficultyConfig> difficultyConfigs;


    }

    /**
     * BMI 条件配置
     */
    @Data
    @Builder
    @AllArgsConstructor
    @NoArgsConstructor
    public static class BmiConditionConfig{
        /**
         * 开始值
         */
        private Double startValue;
        /**
         * 是否包含开始值
         */
        private Boolean includeStartValue;
        /**
         * 结束值
         */
        private Double endValue;
        /**
         * 是否包含结束值
         */
        private Boolean includeEndValue;
        /**
         * 配置详情
         */
        private ConfigDetail configDetail;
    }


    /**
     * 时间配置
     */
    @Data
    @Builder
    @AllArgsConstructor
    @NoArgsConstructor
    public static class TimeConfig{
        /**
         * 运动水平
         */
        private Integer exerciseLevel;
        /**
         * 最小等级
         */
        private Integer minGrade;
        /**
         * 最大等级
         */
        private Integer maxGrade;
        /**
         * 热身拉伸规则
         */
        private ActionTimeConfig.WarmupStretchRule warmupStretchRule;
    }

    /**
     * 频率配置
     */
    @Data
    @Builder
    @AllArgsConstructor
    @NoArgsConstructor
    public static class FrequencyConfig{
        /**
         * 运动水平
         */
        private Integer exerciseLevel;
        /**
         * 最小等级
         */
        private Integer minGrade;
        /**
         * 最大等级
         */
        private Integer maxGrade;

    }

    /**
     * 难度配置
     */
    @Data
    @Builder
    @AllArgsConstructor
    @NoArgsConstructor
    public static class DifficultyConfig{
        /**
         * 运动水平
         */
        private Integer exerciseLevel;
        /**
         * 最小等级
         */
        private Integer minGrade;
        /**
         * 最大等级
         */
        private Integer maxGrade;

    }


}
