package com.jiankangyouyi.cloud.motorplan.model.vo;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.jiankangyouyi.cloud.core.util.json.serialize.QiniuKeyToUrlJsonSerialize;
import com.jiankangyouyi.cloud.motorplan.api.model.dto.response.component.SystemExerciseInfo;
import com.jiankangyouyi.cloud.motorplan.api.model.dto.response.component.ActionExplainInfo;
import com.jiankangyouyi.cloud.motorplan.model.entity.mongo.component.v3.ActionVideoDetailInfo;
import com.jiankangyouyi.cloud.motorplan.model.entity.mongo.component.v3.ExerciseConfigInfo;
import com.jiankangyouyi.cloud.motorplan.model.entity.mongo.component.v3.TrainingAndRestVideoInfo;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.List;

/**
 * @author ：wangyalei
 * @date ：Created in 2021/7/20 2:11 下午
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class ExerciseCoursePlanCreateTestToolVO {
    /**
     * 课程Id
     */
    private String courseId;
    /**
     * 用户BMI
     */
    private Double bmi;
    /**
     * 健康/亚健康人群 true 是 false 否
     */
    private Boolean healthyPerson;
    /**
     * 疾病类型
     */
    private String diseaseType;
    /**
     * 风险等级
     */
    private String riskLevel;
    /**
     * 用户信息
     */
    private UserInfo userInfo;
    /**
     * 当前方案热身时间值 /分
     */
    private Integer projectWarmupTime;
    /**
     * 当前方案拉伸时间值 /分
     */
    private Integer projectStretchTime;
    /**
     * 当前方案最小训练时间 /分
     */
    private Integer projectMinTrainTime;
    /**
     * 当前方案最大训练时间 /分
     */
    private Integer projectMaxTrainTime;
    /**
     * 动作个数
     */
    private Integer actionCount;
    /**
     * 课程时长 /分
     */
    private Integer courseDurationMinute;
    /**
     * 课程时长 /秒
     */
    private Integer courseDurationSecond;
    /**
     * 课程热量
     */
    private Double courseHeat;
    /**
     * 运动频率描述
     */
    private String exerciseFrequencyDesc;
    /**
     * 课程使用的运动器材
     */
    private String exerciseEquipment;
    /**
     * 视频课程禁忌动作
     */
    private String forbidActionProperty;
    /**
     * 系统课程禁忌动作属性
     */
    private String systemForbidActionProperty;
    /**
     * 注意事项
     */
    private List<String> attentionItems;
    /**
     * 运动目标
     */
    private List<String> exerciseAims;
    /**
     * 动作讲解
     */
    private List<ActionExplainInfo> actionExplains;
    /**
     * 热身动作总时间 /ms
     */
    private Long warmupTotalTime;
    /**
     * 热身动作产生总热量
     */
    private Double warmupTotalHeat;
    /**
     * 热身动作视频列表
     */
    private List<ActionVideoDetailInfo> warmupVideos;
    /**
     * 训练动作总时间 /ms
     */
    private Long trainingTotalTime;
    /**
     * 训练动作产生总热量
     */
    private Double trainingTotalHeat;
    /**
     * 训练动作视频+休息视频列表
     */
    private List<TrainingAndRestVideoInfo> trainingAndRestVideos;
    /**
     * 拉伸动作总时间 /ms
     */
    private Long stretchTotalTime;
    /**
     * 拉伸动作产生总热量
     */
    private Double stretchTotalHeat;
    /**
     * 拉伸动作视频列表
     */
    private List<ActionVideoDetailInfo> stretchVideos;
    /**
     * 休息视频总时间 /ms
     */
    private Long restVideoTotalTime;
    /**
     * 休息视频个数
     */
    private Integer restVideoCount;
    /**
     * 课程封面图
     */
    @JsonSerialize(using = QiniuKeyToUrlJsonSerialize.class)
    private String courseImage;
    /**
     * 课程视频 1080 分辨率   m3u8 文件地址
     */
    private String courseVideoM3u8P1080;
    /**
     * 课程视频 720 分辨率   m3u8 文件地址
     */
    private String courseVideoM3u8P720;
    /**
     * 课程视频 480 分辨率   m3u8 文件地址
     */
    private String courseVideoM3u8P480;
    /**
     * 系统运动信息（非视频课程方案）
     */
    private SystemExerciseInfo systemExerciseInfo;

    /**
     * 用户信息
     */
    @Data
    @Builder
    public static class UserInfo {
        /**
         * 身高 /cm
         */
        private Integer height;
        /**
         * 体重 /kg
         */
        private Double weight;
        /**
         * 出生日期 yyyy-MM-dd
         */
        private String birthday;
        /**
         * 性别 0、未知 1、男 2、女
         */
        private String gender;
        /**
         * 运动能力 低 中 高
         */
        private String athleticAbility;
        /**
         * 健康/亚健康人群 true 是 、  false 否
         */
        private Boolean healthyPerson;
        /**
         * 疾病信息
         */
        private List<DiseaseInfo> diseaseInfos;
        /**
         * 用户选择的动作禁忌
         */
        private String actionTaboos;
        /**
         * 用户身体运动评估状态 {@link com.jiankangyouyi.cloud.motorplan.enums.BodyExerciseEvaluationStatusEnum}
         */
        private String bodyExerciseEvaluationStatus;
        /**
         * 分娩日期 / yyyy-MM-dd
         */
        private String deliveryDate;
        /**
         * 用户选择的教练性别 1、男 2、女
         */
        private String coachGender;
        /**
         * 运动配置信息 （运动v2.4新增，之前的数据没有该字段信息，用到时需做兼容或特殊处理）
         */
        private ExerciseConfigInfo exerciseConfigInfo;
    }

    /**
     * 疾病信息
     */
    @Data
    @Builder
    public static class DiseaseInfo {
        /**
         * 疾病类型
         */
        private String diseaseType;
        /**
         * 风险等级
         */
        private String riskLevel;
    }
}
